@@ -1,6 +1,4 @@
-/*
- * $Id: events.c,v 1.12 2000/12/18 19:41:48 amai Exp $
- */
+/* $Id: events.c,v 1.16 2001/06/09 09:25:49 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -36,37 +34,32 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#include "mwm.h"
+#include <LTconfig.h>
 
-#ifdef ISC
-#include <sys/bsdtypes.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
 #endif
-
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#ifdef TIME_WITH_SYS_TIME
-#include <time.h>
-#endif
-#endif
-#ifdef HAVE_SYS_WAIT_H
-#include <sys/wait.h>
-#endif
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
 #endif
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
 
-#include <X11/extensions/shape.h>
-
 #include <Xm/XmosP.h>
 #if XmVERSION >= 2
 #include <XmI/XmI.h>
 #endif
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+
+#include <X11/extensions/shape.h>
+
+#include "mwm.h"
+
 
 /*
  * shorthand defines
@@ -143,7 +136,11 @@ color_map_notify(ScreenInfo *scr, MwmWindow *win, XEvent *event)
     if (!win)
 	return;
 
+#ifdef __cplusplus
+    if (cevent->c_new)
+#else
     if (cevent->new)
+#endif
     {
 	XGetWindowAttributes(dpy, win->w, &(win->attr));
 	if (win == scr->mwm_colormap && win->number_cmap_windows == 0)
@@ -162,7 +159,11 @@ color_map_notify(ScreenInfo *scr, MwmWindow *win, XEvent *event)
 	if (XFindContext(dpy, cevent->window,
 			 MwmContext, (XPointer *)&win) == XCNOENT)
 	    win = NULL;
+#ifdef __cplusplus
+	if ((win) && (cevent->c_new))
+#else
 	if ((win) && (cevent->new))
+#endif
 	{
 	    XGetWindowAttributes(dpy, win->w, &(win->attr));
 	    if (win == scr->mwm_colormap &&
