@@ -33,19 +33,17 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#include "mwm.h"
+
+#include <LTconfig.h>
 
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#ifdef TIME_WITH_SYS_TIME
-#include <time.h>
-#endif
-#endif
+
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+
+#include "mwm.h"
 
 #include <X11/keysym.h>
 
@@ -681,18 +679,19 @@ MENU_FindHotKey(MenuItem *it, KeySym key)
  * create a new menu root
  */
 MenuRoot *
-MENU_Create(char *name)
+MENU_Create(const char *name)
 {
     MenuRoot *tmp;
 
-    tmp = (MenuRoot *) XtMalloc(sizeof(MenuRoot));
-    tmp->name = name;
-    tmp->first = NULL;
-    tmp->last = NULL;
-    tmp->items = 0;
-    tmp->width = 0;
+    tmp  = (MenuRoot *) XtMalloc(sizeof(MenuRoot));
+    tmp->name   = XtNewString(name);
+    tmp->first  = NULL;
+    tmp->last   = NULL;
+    tmp->items  = 0;
+    tmp->width  = 0;
     tmp->width2 = 0;
-    tmp->w = None;
+    tmp->w      = None;
+
     return (tmp);
 }
 
@@ -902,7 +901,7 @@ MENU_Realize(ScreenInfo *scr, MenuRoot * mr)
 			  CopyFromParent, (unsigned int)InputOutput,
 			  (Visual *)CopyFromParent,
 			  valuemask, &attributes);
-    XSaveContext(dpy, mr->w, MenuContext, (_Xconst char *)mr);
+    XSaveContext(dpy, mr->w, MenuContext, (XPointer)mr);
 }
 
 /*
