@@ -1,3 +1,4 @@
+/* $Id: screens.c,v 1.10 2001/06/22 19:06:04 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -33,15 +34,22 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#include "mwm.h"
+#include <LTconfig.h>
 
 #include <stdio.h>
 
-#if 0
-/* Unfortunately X11 forgot about non-case-sensitive filesystems which
+#include <X11/keysym.h>
+
+#include <Xm/XmP.h>
+#include <Xm/MwmUtil.h>
+#include "mwm.h"
+
+
+/* amai: Unfortunately X11 forgot about non-case-sensitive filesystems which
    may have problems to store both "X11/bitmaps/Stipple" and
    "X11/bitmaps/stipple".
    So we inline the few lines here instead. */
+#if 0
 #include <X11/bitmaps/stipple>
 #else
 #define stipple_width 16
@@ -50,10 +58,6 @@ static char stipple_bits[] = {
    0x55, 0x55, 0xee, 0xee, 0x55, 0x55, 0xba, 0xbb};
 #endif /* #if 0 */
 
-#include <X11/keysym.h>
-
-#include <Xm/XmP.h>
-
 
 extern Boolean debugging;
 
@@ -1262,6 +1266,7 @@ SCREEN_Initialize(ScreenInfo *scr)
 
     PROP_SetPriorityColors(scr);
 
+    RES_GetScreenDefaults(scr);
     RES_GetComponentDefaults(scr);
 
     MWM_SetErrorHandler(REDIRECT);
