@@ -1,3 +1,4 @@
+/* $Id: mwm.c,v 1.27 2001/06/22 19:06:04 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -31,18 +32,17 @@
 /***********************************************************************
  * The rest of it is all my fault -- MLM
  *
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-/* $Id: mwm.c,v 1.22 2000/12/21 09:53:15 amai Exp $ */
-
-#include "mwm.h"
+#include <LTconfig.h>
 
 #include <stdlib.h>
-#include <stddef.h>
 #include <stdio.h>
 #include <string.h>
+#include <signal.h>
+
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
@@ -52,29 +52,26 @@
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#ifdef TIME_WITH_SYS_TIME
-#include <time.h>
-#endif
-#endif
-#ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-#ifdef __EMX__
-#include <netdb.h>
-#endif
 #ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
 #endif
-#include <signal.h>
 #ifdef HAVE_GETRLIMIT
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
 #include <sys/resource.h>
 #endif
 
+#ifdef __EMX__
+#include <netdb.h>
+#endif
+
+#include <X11/Intrinsic.h>
 #include <X11/Shell.h>
 #include <X11/Xproto.h>
 
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
 #include <Xm/XmosP.h>
 #include <Xm/DisplayP.h>
 #include <Xm/ScreenP.h>
@@ -83,43 +80,42 @@
 #include <XmI/XmI.h>
 #endif
 
+#include "mwm.h"
+
+
 #ifndef HAVE_GETHOSTNAME
 /* our fallback implementation (gethostname.c) */
 extern int gethostname (char *name, size_t len);
 #endif
 
 
-static int SetEnvironment(const char *key, const char *value);
-
-#ifdef HAVE_PUTENV
-static int
+extern int
 SetEnvironment(const char *key, const char *value)
+#ifdef HAVE_PUTENV
 {
- char *str;
- int len, rc;
+  char *str;
+  int len, rc;
  
- len=strlen(key)+strlen(value)+2;
- str=(char *)malloc(len);
- strcpy(str, key);
- strcat(str, "=");
- strcat(str, value);
- rc=putenv(str);
- /* do not free 'str' here! */
- return rc;
+  len=strlen(key)+strlen(value)+2;
+  str=(char *)malloc(len);
+  strcpy(str, key);
+  strcat(str, "=");
+  strcat(str, value);
+  rc=putenv(str);
+  /* do not free 'str' here! */
+  return rc;
 }
 #else
 #ifdef HAVE_SETENV
-static int
-SetEnvironment(const char *key, const char *value)
 {
- int rc;
- int overwrite=1;
+  int rc;
+  int overwrite=1;
 
- rc=setenv(key, value, overwrite);
- return rc;
+  rc=setenv(key, value, overwrite);
+  return rc;
 }
 #else
-#error You lose (neither putenv ()  nor setenv() available!)
+#error You lose (neither putenv() nor setenv() are available!)
 #endif /* #ifdef HAVE_SETENV */
 #endif /* #ifdef HAVE_PUTENV */
 
@@ -273,6 +269,14 @@ initialize_mwm( void)
 		exit(1);
 	    }
 
+	/*TODO: only default screen names are supported
+	 *   since '-screens' mwm command line option is not implemented yet
+	 *		A.R.
+	 */
+	    /* By default, the screen number is used for the screen name. */
+	    scr->screen_name = (String)XtMalloc(12);
+	    sprintf(scr->screen_name, "%lu", scr->screen);
+
 	    SCREEN_Initialize(scr);
 
 	    Mwm.screen_info[i] = scr;
@@ -295,6 +299,14 @@ initialize_mwm( void)
 	    exit(1);
 	}
 
+	/*TODO: only default screen names are supported
+	 *   since '-screens' mwm command line option is not implemented yet
+	 *		A.R.
+	 */
+	/* By default, the screen number is used for the screen name. */
+	scr->screen_name = (String)XtMalloc(12);
+	sprintf(scr->screen_name, "%lu", scr->screen);
+
 	SCREEN_Initialize(scr);
 
 	Mwm.screen_info[0] = scr;
@@ -374,6 +386,24 @@ MWM_Done(int restart, const char *command)
     }
 }
 
+
+/*
+ * ReapChildren - wait() for all dead child processes
+ */
+void ReapChildren(void)
+{
+#ifdef HAVE_WAITPID
+    while ((waitpid(-1, NULL, WNOHANG)) > 0);
+#else
+#ifdef HAVE_WAIT3
+    while ((wait3(NULL, WNOHANG, NULL)) > 0);
+#else
+#error You lose: neither waitpid() nor wait3() is available!
+#endif
+#endif
+}
+
+
 /*
  * main - start of mwm
  */
