@@ -1,108 +1,108 @@
 
 /*  A Bison parser, made from mwmparse.y
- by  GNU Bison version 1.25
-  */
+    by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
-#define	ALT_TOK	258
-#define	APP_TOK	259
-#define	BACK_TOK	260
-#define	BORDER_TOK	261
-#define	BTN1_CLICK2_TOK	262
-#define	BTN1_CLICK_TOK	263
-#define	BTN1_DOWN_TOK	264
-#define	BTN1_UP_TOK	265
-#define	BTN2_CLICK2_TOK	266
-#define	BTN2_CLICK_TOK	267
-#define	BTN2_DOWN_TOK	268
-#define	BTN2_UP_TOK	269
-#define	BTN3_CLICK2_TOK	270
-#define	BTN3_CLICK_TOK	271
-#define	BTN3_DOWN_TOK	272
-#define	BTN3_UP_TOK	273
-#define	BTN4_CLICK2_TOK	274
-#define	BTN4_CLICK_TOK	275
-#define	BTN4_DOWN_TOK	276
-#define	BTN4_UP_TOK	277
-#define	BTN5_CLICK2_TOK	278
-#define	BTN5_CLICK_TOK	279
-#define	BTN5_DOWN_TOK	280
-#define	BTN5_UP_TOK	281
-#define	BUTTONS_TOK	282
-#define	CTRL_TOK	283
-#define	FBEEP_TOK	284
-#define	FCIRCLE_DOWN_TOK	285
-#define	FCIRCLE_UP_TOK	286
-#define	FEXEC_TOK	287
-#define	FFOCUS_COLOR_TOK	288
-#define	FFOCUS_KEY_TOK	289
-#define	FKILL_TOK	290
-#define	FLOWER_TOK	291
-#define	FMAXIMIZE_TOK	292
-#define	FMENU_TOK	293
-#define	FMINIMIZE_TOK	294
-#define	FMOVE_TOK	295
-#define	FNEXT_CMAP_TOK	296
-#define	FNEXT_KEY_TOK	297
-#define	FNOP_TOK	298
-#define	FNORMALIZE_TOK	299
-#define	FNORMANDRAISE_TOK	300
-#define	FPACK_ICONS_TOK	301
-#define	FPASS_KEYS_TOK	302
-#define	FPOST_WMENU_TOK	303
-#define	FPREV_CMAP_TOK	304
-#define	FPREV_KEY_TOK	305
-#define	FQUIT_MWM_TOK	306
-#define	FRAISE_LOWER_TOK	307
-#define	FRAISE_TOK	308
-#define	FRAME_TOK	309
-#define	FREE_FAMILY_TOK	310
-#define	FREFRESH_TOK	311
-#define	FREFRESH_WIN_TOK	312
-#define	FRESIZE_TOK	313
-#define	FRESTART_TOK	314
-#define	FRESTOREANDRAISE_TOK	315
-#define	FRESTORE_TOK	316
-#define	FSCREEN_TOK	317
-#define	FSEND_MSG_TOK	318
-#define	FSEPARATOR_TOK	319
-#define	FSET_BEHAVIOR_TOK	320
-#define	FTITLE_TOK	321
-#define	FWINDOWLIST_TOK	322
-#define	FDESK_TOK	323
-#define	FTOGGLE_PAGE_TOK	324
-#define	FGOTO_PAGE_TOK	325
-#define	ICON_TOK	326
-#define	KEY_TOK	327
-#define	KEYS_TOK	328
-#define	LOCK_TOK	329
-#define	MENU_TOK	330
-#define	MENUB_TOK	331
-#define	MINIMIZEB_TOK	332
-#define	MAXIMIZEB_TOK	333
-#define	MOD1_TOK	334
-#define	MOD2_TOK	335
-#define	MOD3_TOK	336
-#define	MOD4_TOK	337
-#define	MOD5_TOK	338
-#define	NEXT_TOK	339
-#define	PREV_TOK	340
-#define	ROOT_TOK	341
-#define	SHIFT_TOK	342
-#define	TITLE_TOK	343
-#define	TRANSIENT_TOK	344
-#define	WINDOW_TOK	345
-#define	WITHIN_TOK	346
-#define	STRING_TOK	347
+#define	ALT_TOK	257
+#define	APP_TOK	258
+#define	BACK_TOK	259
+#define	BORDER_TOK	260
+#define	BTN1_CLICK2_TOK	261
+#define	BTN1_CLICK_TOK	262
+#define	BTN1_DOWN_TOK	263
+#define	BTN1_UP_TOK	264
+#define	BTN2_CLICK2_TOK	265
+#define	BTN2_CLICK_TOK	266
+#define	BTN2_DOWN_TOK	267
+#define	BTN2_UP_TOK	268
+#define	BTN3_CLICK2_TOK	269
+#define	BTN3_CLICK_TOK	270
+#define	BTN3_DOWN_TOK	271
+#define	BTN3_UP_TOK	272
+#define	BTN4_CLICK2_TOK	273
+#define	BTN4_CLICK_TOK	274
+#define	BTN4_DOWN_TOK	275
+#define	BTN4_UP_TOK	276
+#define	BTN5_CLICK2_TOK	277
+#define	BTN5_CLICK_TOK	278
+#define	BTN5_DOWN_TOK	279
+#define	BTN5_UP_TOK	280
+#define	BUTTONS_TOK	281
+#define	CTRL_TOK	282
+#define	FBEEP_TOK	283
+#define	FCIRCLE_DOWN_TOK	284
+#define	FCIRCLE_UP_TOK	285
+#define	FEXEC_TOK	286
+#define	FFOCUS_COLOR_TOK	287
+#define	FFOCUS_KEY_TOK	288
+#define	FKILL_TOK	289
+#define	FLOWER_TOK	290
+#define	FMAXIMIZE_TOK	291
+#define	FMENU_TOK	292
+#define	FMINIMIZE_TOK	293
+#define	FMOVE_TOK	294
+#define	FNEXT_CMAP_TOK	295
+#define	FNEXT_KEY_TOK	296
+#define	FNOP_TOK	297
+#define	FNORMALIZE_TOK	298
+#define	FNORMANDRAISE_TOK	299
+#define	FPACK_ICONS_TOK	300
+#define	FPASS_KEYS_TOK	301
+#define	FPOST_WMENU_TOK	302
+#define	FPREV_CMAP_TOK	303
+#define	FPREV_KEY_TOK	304
+#define	FQUIT_MWM_TOK	305
+#define	FRAISE_LOWER_TOK	306
+#define	FRAISE_TOK	307
+#define	FRAME_TOK	308
+#define	FREE_FAMILY_TOK	309
+#define	FREFRESH_TOK	310
+#define	FREFRESH_WIN_TOK	311
+#define	FRESIZE_TOK	312
+#define	FRESTART_TOK	313
+#define	FRESTOREANDRAISE_TOK	314
+#define	FRESTORE_TOK	315
+#define	FSCREEN_TOK	316
+#define	FSEND_MSG_TOK	317
+#define	FSEPARATOR_TOK	318
+#define	FSET_BEHAVIOR_TOK	319
+#define	FTITLE_TOK	320
+#define	FWINDOWLIST_TOK	321
+#define	FDESK_TOK	322
+#define	FTOGGLE_PAGE_TOK	323
+#define	FGOTO_PAGE_TOK	324
+#define	ICON_TOK	325
+#define	KEY_TOK	326
+#define	KEYS_TOK	327
+#define	LOCK_TOK	328
+#define	MENU_TOK	329
+#define	MENUB_TOK	330
+#define	MINIMIZEB_TOK	331
+#define	MAXIMIZEB_TOK	332
+#define	MOD1_TOK	333
+#define	MOD2_TOK	334
+#define	MOD3_TOK	335
+#define	MOD4_TOK	336
+#define	MOD5_TOK	337
+#define	NEXT_TOK	338
+#define	PREV_TOK	339
+#define	ROOT_TOK	340
+#define	SHIFT_TOK	341
+#define	TITLE_TOK	342
+#define	TRANSIENT_TOK	343
+#define	WINDOW_TOK	344
+#define	WITHIN_TOK	345
+#define	STRING_TOK	346
 
 #line 1 "mwmparse.y"
 
 /**
  *
- * $Id: mwmparse.y,v 1.24 2000/09/21 16:04:37 amai Exp $
+ * $Id: mwmparse.y,v 1.31 2001/08/02 19:45:28 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -121,20 +121,25 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-#include "mwm.h"
+
+#include "LTconfig.h"
 
 #include <stdlib.h>
 #include <stdarg.h>
+#include <stdio.h>
+#include <string.h>
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
 #ifdef HAVE_PWD_H
 #include <pwd.h>
 #endif
-#include <sys/types.h>
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -143,6 +148,12 @@
 #include <X11/Xlibint.h>    /* for __XOS2RedirRoot() */
 #endif
 
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+
+#include "mwm.h"
+
+
 /*
  * this is OS dependent, but this should catch most
  */
@@ -167,7 +178,7 @@ extern int	verbose;
 static int lineno;
 
 
-#line 226 "mwmparse.y"
+#line 238 "mwmparse.y"
 typedef union {
     char	*string;
     int		number;
@@ -206,7 +217,7 @@ typedef union {
 #define	YYFLAG		-32768
 #define	YYNTBASE	102
 
-#define YYTRANSLATE(x) ((unsigned)(x) <= 347 ? yytranslate[x] : 131)
+#define YYTRANSLATE(x) ((unsigned)(x) <= 346 ? yytranslate[x] : 131)
 
 static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -234,16 +245,16 @@ static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-     2,     2,     2,     2,     2,     1,     2,     3,     4,     5,
-     6,     7,     8,     9,    10,    11,    12,    13,    14,    15,
-    16,    17,    18,    19,    20,    21,    22,    23,    24,    25,
-    26,    27,    28,    29,    30,    31,    32,    33,    34,    35,
-    36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
-    46,    47,    48,    49,    50,    51,    52,    53,    54,    55,
-    56,    57,    58,    59,    60,    61,    62,    63,    64,    65,
-    66,    67,    68,    69,    70,    71,    72,    73,    74,    75,
-    76,    77,    78,    79,    80,    81,    82,    83,    84,    85,
-    86,    87,    88,    89,    90,    91,    92
+     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
+     7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
+    17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
+    27,    28,    29,    30,    31,    32,    33,    34,    35,    36,
+    37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
+    47,    48,    49,    50,    51,    52,    53,    54,    55,    56,
+    57,    58,    59,    60,    61,    62,    63,    64,    65,    66,
+    67,    68,    69,    70,    71,    72,    73,    74,    75,    76,
+    77,    78,    79,    80,    81,    82,    83,    84,    85,    86,
+    87,    88,    89,    90,    91,    92
 };
 
 #if YYDEBUG != 0
@@ -302,20 +313,20 @@ static const short yyrhs[] = {   102,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   252,   253,   256,   257,   258,   261,   280,   283,   284,   290,
-   293,   399,   418,   421,   422,   428,   431,   483,   488,   494,
-   495,   501,   504,   606,   608,   612,   614,   618,   620,   622,
-   624,   626,   628,   630,   632,   634,   636,   638,   642,   647,
-   654,   659,   666,   668,   672,   674,   676,   678,   680,   682,
-   684,   686,   688,   692,   698,   704,   710,   716,   722,   728,
-   734,   740,   746,   752,   758,   764,   770,   776,   782,   788,
-   794,   800,   806,   812,   821,   823,   825,   833,   837,   847,
-   851,   856,   861,   866,   871,   876,   881,   886,   891,   896,
-   901,   906,   911,   916,   921,   926,   931,   936,   941,   946,
-   951,   956,   961,   966,   971,   976,   981,   986,   991,   996,
-  1001,  1006,  1011,  1016,  1021,  1026,  1031,  1036,  1041,  1049,
-  1051,  1055,  1057,  1059,  1061,  1063,  1065,  1067,  1069,  1071,
-  1073,  1076
+   264,   265,   268,   269,   270,   273,   292,   295,   296,   302,
+   305,   411,   430,   433,   434,   440,   443,   495,   500,   506,
+   507,   513,   516,   618,   620,   624,   626,   630,   632,   634,
+   636,   638,   640,   642,   644,   646,   648,   650,   654,   659,
+   666,   671,   678,   680,   684,   686,   688,   690,   692,   694,
+   696,   698,   700,   704,   710,   716,   722,   728,   734,   740,
+   746,   752,   758,   764,   770,   776,   782,   788,   794,   800,
+   806,   812,   818,   824,   833,   835,   837,   845,   849,   859,
+   863,   868,   873,   878,   883,   888,   893,   898,   903,   908,
+   913,   918,   923,   928,   933,   938,   943,   948,   953,   958,
+   963,   968,   973,   978,   983,   988,   993,   998,  1003,  1008,
+  1013,  1018,  1023,  1028,  1033,  1038,  1043,  1048,  1053,  1061,
+  1063,  1067,  1069,  1071,  1073,  1075,  1077,  1079,  1081,  1083,
+  1085,  1088
 };
 #endif
 
@@ -525,6 +536,7 @@ static const short yycheck[] = {     3,
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
 #line 3 "/usr/share/bison.simple"
+/* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -541,47 +553,72 @@ static const short yycheck[] = {     3,
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
-#ifndef alloca
-#ifdef __GNUC__
-#define alloca __builtin_alloca
-#else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
-#include <alloca.h>
-#else /* not sparc */
-#if defined (MSDOS) && !defined (__TURBOC__)
-#include <malloc.h>
-#else /* not MSDOS, or __TURBOC__ */
-#if defined(_AIX)
-#include <malloc.h>
- #pragma alloca
-#else /* not MSDOS, __TURBOC__, or _AIX */
-#ifdef __hpux
-#ifdef __cplusplus
-extern "C" {
-void *alloca (unsigned int);
-};
-#else /* not __cplusplus */
-void *alloca ();
-#endif /* not __cplusplus */
-#endif /* __hpux */
-#endif /* not _AIX */
-#endif /* not MSDOS, or __TURBOC__ */
-#endif /* not sparc.  */
-#endif /* not GNU C.  */
-#endif /* alloca not defined.  */
-
 /* This is the parser code that is written into each bison parser
   when the %semantic_parser declaration is not specified in the grammar.
   It was written by Richard Stallman by simplifying the hairy parser
   used when %semantic_parser is specified.  */
 
+#ifndef YYPARSE_RETURN_TYPE
+#define YYPARSE_RETURN_TYPE int
+#endif
+
+
+#ifndef YYSTACK_USE_ALLOCA
+#ifdef alloca
+#define YYSTACK_USE_ALLOCA
+#else /* alloca not defined */
+#ifdef __GNUC__
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#else /* not GNU C.  */
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
+#define YYSTACK_USE_ALLOCA
+#include <alloca.h>
+#else /* not sparc */
+/* We think this test detects Watcom and Microsoft C.  */
+/* This used to test MSDOS, but that is a bad idea
+   since that symbol is in the user namespace.  */
+#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
+#if 0 /* No need for malloc.h, which pollutes the namespace;
+	 instead, just don't use alloca.  */
+#include <malloc.h>
+#endif
+#else /* not MSDOS, or __TURBOC__ */
+#if defined(_AIX)
+/* I don't know what this was needed for, but it pollutes the namespace.
+   So I turned it off.   rms, 2 May 1997.  */
+/* #include <malloc.h>  */
+ #pragma alloca
+#define YYSTACK_USE_ALLOCA
+#else /* not MSDOS, or __TURBOC__, or _AIX */
+#if 0
+#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
+		 and on HPUX 10.  Eventually we can turn this on.  */
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#endif /* __hpux */
+#endif
+#endif /* not _AIX */
+#endif /* not MSDOS, or __TURBOC__ */
+#endif /* not sparc */
+#endif /* not GNU C */
+#endif /* alloca not defined */
+#endif /* YYSTACK_USE_ALLOCA not defined */
+
+#ifdef YYSTACK_USE_ALLOCA
+#define YYSTACK_ALLOC alloca
+#else
+#define YYSTACK_ALLOC malloc
+#endif
+
 /* Note: there must be only one dollar sign in this file.
    It is replaced by the list of actions, each action
    as one case of the switch.  */
@@ -590,8 +627,8 @@ void *alloca ();
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		-2
 #define YYEOF		0
-#define YYACCEPT	return(0)
-#define YYABORT 	return(1)
+#define YYACCEPT	goto yyacceptlab
+#define YYABORT 	goto yyabortlab
 #define YYERROR		goto yyerrlab1
 /* Like YYERROR except do call yyerror.
    This remains here temporarily to ease the
@@ -672,16 +709,12 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
-
-#ifndef YYPARSE_RETURN_TYPE
-#define YYPARSE_RETURN_TYPE int
-#endif
-
-/* Prevent warning if -Wstrict-prototypes.  */
-#ifdef __GNUC__
-YYPARSE_RETURN_TYPE yyparse (void);
-#endif
 
+/* Define __yy_memcpy.  Note that the size argument
+   should be passed with type unsigned int, because that is what the non-GCC
+   definitions require.  With GCC, __builtin_memcpy takes an arg
+   of type size_t, but it can handle unsigned int.  */
+
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
@@ -693,7 +726,7 @@ static void
 __yy_memcpy (to, from, count)
      char *to;
      char *from;
-     int count;
+     unsigned int count;
 {
   register char *f = from;
   register char *t = to;
@@ -708,10 +741,10 @@ __yy_memcpy (to, from, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (char *to, char *from, int count)
+__yy_memcpy (char *to, char *from, unsigned int count)
 {
-  register char *f = from;
   register char *t = to;
+  register char *f = from;
   register int i = count;
 
   while (i-- > 0)
@@ -721,7 +754,7 @@ __yy_memcpy (char *to, char *from, int count)
 #endif
 #endif
 
-#line 196 "/usr/share/bison.simple"
+#line 222 "/usr/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -742,6 +775,17 @@ __yy_memcpy (char *to, char *from, int count)
 #define YYPARSE_PARAM_DECL
 #endif /* not YYPARSE_PARAM */
 
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+#ifdef YYPARSE_PARAM
+YYPARSE_RETURN_TYPE
+yyparse (void *);
+#else
+YYPARSE_RETURN_TYPE
+yyparse (void);
+#endif
+#endif
+
 YYPARSE_RETURN_TYPE
 yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
@@ -770,6 +814,9 @@ yyparse(YYPARSE_PARAM_ARG)
 #endif
 
   int yystacksize = YYINITDEPTH;
+#ifndef YYSTACK_USE_ALLOCA
+  int yyfree_stacks = 0;
+#endif
 
 #ifdef YYPURE
   int yychar;
@@ -854,18 +901,34 @@ yynewstate:
       if (yystacksize >= YYMAXDEPTH)
 	{
 	  yyerror("parser stack overflow");
+#ifndef YYSTACK_USE_ALLOCA
+	  if (yyfree_stacks)
+	    {
+	      free (yyss);
+	      free (yyvs);
+#ifdef YYLSP_NEEDED
+	      free (yyls);
+#endif
+	    }
+#endif	    
 	  return 2;
 	}
       yystacksize *= 2;
       if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
-      yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
-      __yy_memcpy ((char *)yyss, (char *)yyss1, size * sizeof (*yyssp));
-      yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
-      __yy_memcpy ((char *)yyvs, (char *)yyvs1, size * sizeof (*yyvsp));
+#ifndef YYSTACK_USE_ALLOCA
+      yyfree_stacks = 1;
+#endif
+      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
+      __yy_memcpy ((char *)yyss, (char *)yyss1,
+		   size * (unsigned int) sizeof (*yyssp));
+      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
+      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
+		   size * (unsigned int) sizeof (*yyvsp));
 #ifdef YYLSP_NEEDED
-      yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
-      __yy_memcpy ((char *)yyls, (char *)yyls1, size * sizeof (*yylsp));
+      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
+      __yy_memcpy ((char *)yyls, (char *)yyls1,
+		   size * (unsigned int) sizeof (*yylsp));
 #endif
 #endif /* no yyoverflow */
 
@@ -1026,16 +1089,16 @@ yyreduce:
   switch (yyn) {
 
 case 6:
-#line 262 "mwmparse.y"
+#line 274 "mwmparse.y"
 {
 			    if (!skip_test) {
 				if (button_bind_found == False) {
-				    if (strcmp(yyvsp[0].string, Mwm.button_bindings) == 0)
+				    if (strcmp(yyvsp[0].string, pscr->button_bindings) == 0)
 					button_bind_match = True;
 				    else
 					button_bind_match = False;
 				}
-				else if (strcmp(yyvsp[0].string, Mwm.button_bindings) == 0) {
+				else if (strcmp(yyvsp[0].string, pscr->button_bindings) == 0) {
 				    yyerror("Ignoring duplicate button bindings");
 				    button_bind_match = False;
 				}
@@ -1047,7 +1110,7 @@ case 6:
 			;
     break;}
 case 9:
-#line 285 "mwmparse.y"
+#line 297 "mwmparse.y"
 {
 			    yyerror("Invalid button binding");
 			    yyerrok;
@@ -1055,7 +1118,7 @@ case 9:
 			;
     break;}
 case 11:
-#line 294 "mwmparse.y"
+#line 306 "mwmparse.y"
 {
 			    int contexts = yyvsp[-1].number;
 			    int mods, func;
@@ -1161,16 +1224,16 @@ case 11:
 			;
     break;}
 case 12:
-#line 400 "mwmparse.y"
+#line 412 "mwmparse.y"
 {
 			    if (!skip_test) {
 				if (key_bind_found == False) {
-				    if (strcmp(yyvsp[0].string, Mwm.key_bindings) == 0)
+				    if (strcmp(yyvsp[0].string, pscr->key_bindings) == 0)
 					key_bind_match = True;
 				    else
 					key_bind_match = False;
 				}
-				else if (strcmp(yyvsp[0].string, Mwm.key_bindings) == 0) {
+				else if (strcmp(yyvsp[0].string, pscr->key_bindings) == 0) {
 				    yyerror("Ignoring duplicate key bindings");
 					key_bind_match = False;
 				}
@@ -1182,7 +1245,7 @@ case 12:
 			;
     break;}
 case 15:
-#line 423 "mwmparse.y"
+#line 435 "mwmparse.y"
 {
 			    yyerror("Invalid key binding");
 			    yyerrok;
@@ -1190,7 +1253,7 @@ case 15:
 			;
     break;}
 case 17:
-#line 432 "mwmparse.y"
+#line 444 "mwmparse.y"
 {
 			    FuncKey        *tmp = NULL;
 			    KeySym          keysym;
@@ -1242,20 +1305,20 @@ case 17:
 			;
     break;}
 case 18:
-#line 484 "mwmparse.y"
+#line 496 "mwmparse.y"
 {
 			    num_items = 0;
 			    cur_menu = MENU_Create(yyvsp[0].string);
 			;
     break;}
 case 19:
-#line 489 "mwmparse.y"
+#line 501 "mwmparse.y"
 {
 			    MENU_Add(pscr, cur_menu);
 			;
     break;}
 case 21:
-#line 496 "mwmparse.y"
+#line 508 "mwmparse.y"
 {
 			    yyerror("Invalid menu item");
 			    yyerrok;
@@ -1263,7 +1326,7 @@ case 21:
 			;
     break;}
 case 23:
-#line 505 "mwmparse.y"
+#line 517 "mwmparse.y"
 {
 			    MenuItem *tmp;
 			    int width, width2;
@@ -1365,139 +1428,139 @@ case 23:
 			;
     break;}
 case 24:
-#line 607 "mwmparse.y"
+#line 619 "mwmparse.y"
 { yyval.hotkey = yyvsp[0].hotkey; ;
     break;}
 case 25:
-#line 609 "mwmparse.y"
+#line 621 "mwmparse.y"
 { yyval.hotkey.modifiers = 0; yyval.hotkey.key = 0; ;
     break;}
 case 26:
-#line 613 "mwmparse.y"
+#line 625 "mwmparse.y"
 { yyval.number = yyvsp[-2].number | yyvsp[0].number; ;
     break;}
 case 27:
-#line 615 "mwmparse.y"
+#line 627 "mwmparse.y"
 { yyval.number = yyvsp[0].number; ;
     break;}
 case 28:
-#line 619 "mwmparse.y"
+#line 631 "mwmparse.y"
 { yyval.number = C_ROOT; ;
     break;}
 case 29:
-#line 621 "mwmparse.y"
+#line 633 "mwmparse.y"
 { yyval.number = C_ICON; ;
     break;}
 case 30:
-#line 623 "mwmparse.y"
+#line 635 "mwmparse.y"
 { yyval.number = C_MENUB; ;
     break;}
 case 31:
-#line 625 "mwmparse.y"
+#line 637 "mwmparse.y"
 { yyval.number = C_MINIMIZEB; ;
     break;}
 case 32:
-#line 627 "mwmparse.y"
+#line 639 "mwmparse.y"
 { yyval.number = C_MAXIMIZEB; ;
     break;}
 case 33:
-#line 629 "mwmparse.y"
+#line 641 "mwmparse.y"
 { yyval.number = C_WINDOW|C_FRAME|C_TITLE|C_LALL|C_RALL|C_ICON; ;
     break;}
 case 34:
-#line 631 "mwmparse.y"
+#line 643 "mwmparse.y"
 { yyval.number = C_TITLE; ;
     break;}
 case 35:
-#line 633 "mwmparse.y"
+#line 645 "mwmparse.y"
 { yyval.number = C_FRAME|C_TITLE|C_LALL|C_RALL; ;
     break;}
 case 36:
-#line 635 "mwmparse.y"
+#line 647 "mwmparse.y"
 { yyval.number = C_FRAME; ;
     break;}
 case 37:
-#line 637 "mwmparse.y"
+#line 649 "mwmparse.y"
 { yyval.number = C_WINDOW; ;
     break;}
 case 38:
-#line 639 "mwmparse.y"
+#line 651 "mwmparse.y"
 { yyerror("Invalid context"); yyval.number = 0; ;
     break;}
 case 39:
-#line 643 "mwmparse.y"
+#line 655 "mwmparse.y"
 {
 			    yyval.button = yyvsp[-1].button;
 			    yyval.button.modifiers = yyvsp[-3].modifiers;
 			;
     break;}
 case 40:
-#line 648 "mwmparse.y"
+#line 660 "mwmparse.y"
 {
 			    yyval.button = yyvsp[-1].button;
 			    yyval.button.modifiers = 0;
 			;
     break;}
 case 41:
-#line 655 "mwmparse.y"
+#line 667 "mwmparse.y"
 {
 			    yyval.hotkey.modifiers = yyvsp[-4].modifiers;
 			    yyval.hotkey.key = XStringToKeysym(yyvsp[0].string);
 			;
     break;}
 case 42:
-#line 660 "mwmparse.y"
+#line 672 "mwmparse.y"
 {
 			    yyval.hotkey.modifiers = 0;
 			    yyval.hotkey.key = XStringToKeysym(yyvsp[0].string);
 			;
     break;}
 case 43:
-#line 667 "mwmparse.y"
+#line 679 "mwmparse.y"
 { yyval.modifiers = yyvsp[-1].modifiers | yyvsp[0].modifiers; ;
     break;}
 case 44:
-#line 669 "mwmparse.y"
+#line 681 "mwmparse.y"
 { yyval.modifiers = yyvsp[0].modifiers; ;
     break;}
 case 45:
-#line 673 "mwmparse.y"
+#line 685 "mwmparse.y"
 { yyval.modifiers = ControlMask; ;
     break;}
 case 46:
-#line 675 "mwmparse.y"
+#line 687 "mwmparse.y"
 { yyval.modifiers = ShiftMask; ;
     break;}
 case 47:
-#line 677 "mwmparse.y"
+#line 689 "mwmparse.y"
 { yyval.modifiers = pscr->alt_mask; ;
     break;}
 case 48:
-#line 679 "mwmparse.y"
+#line 691 "mwmparse.y"
 { yyval.modifiers = LockMask; ;
     break;}
 case 49:
-#line 681 "mwmparse.y"
+#line 693 "mwmparse.y"
 { yyval.modifiers = Mod1Mask; ;
     break;}
 case 50:
-#line 683 "mwmparse.y"
+#line 695 "mwmparse.y"
 { yyval.modifiers = Mod2Mask; ;
     break;}
 case 51:
-#line 685 "mwmparse.y"
+#line 697 "mwmparse.y"
 { yyval.modifiers = Mod3Mask; ;
     break;}
 case 52:
-#line 687 "mwmparse.y"
+#line 699 "mwmparse.y"
 { yyval.modifiers = Mod4Mask; ;
     break;}
 case 53:
-#line 689 "mwmparse.y"
+#line 701 "mwmparse.y"
 { yyval.modifiers = Mod5Mask; ;
     break;}
 case 54:
-#line 693 "mwmparse.y"
+#line 705 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1505,7 +1568,7 @@ case 54:
 			;
     break;}
 case 55:
-#line 699 "mwmparse.y"
+#line 711 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1513,7 +1576,7 @@ case 55:
 			;
     break;}
 case 56:
-#line 705 "mwmparse.y"
+#line 717 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1521,7 +1584,7 @@ case 56:
 			;
     break;}
 case 57:
-#line 711 "mwmparse.y"
+#line 723 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1529,7 +1592,7 @@ case 57:
 			;
     break;}
 case 58:
-#line 717 "mwmparse.y"
+#line 729 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1537,7 +1600,7 @@ case 58:
 			;
     break;}
 case 59:
-#line 723 "mwmparse.y"
+#line 735 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1545,7 +1608,7 @@ case 59:
 			;
     break;}
 case 60:
-#line 729 "mwmparse.y"
+#line 741 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1553,7 +1616,7 @@ case 60:
 			;
     break;}
 case 61:
-#line 735 "mwmparse.y"
+#line 747 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1561,7 +1624,7 @@ case 61:
 			;
     break;}
 case 62:
-#line 741 "mwmparse.y"
+#line 753 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1569,7 +1632,7 @@ case 62:
 			;
     break;}
 case 63:
-#line 747 "mwmparse.y"
+#line 759 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1577,7 +1640,7 @@ case 63:
 			;
     break;}
 case 64:
-#line 753 "mwmparse.y"
+#line 765 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1585,7 +1648,7 @@ case 64:
 			;
     break;}
 case 65:
-#line 759 "mwmparse.y"
+#line 771 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1593,7 +1656,7 @@ case 65:
 			;
     break;}
 case 66:
-#line 765 "mwmparse.y"
+#line 777 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1601,7 +1664,7 @@ case 66:
 			;
     break;}
 case 67:
-#line 771 "mwmparse.y"
+#line 783 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1609,7 +1672,7 @@ case 67:
 			;
     break;}
 case 68:
-#line 777 "mwmparse.y"
+#line 789 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1617,7 +1680,7 @@ case 68:
 			;
     break;}
 case 69:
-#line 783 "mwmparse.y"
+#line 795 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1625,7 +1688,7 @@ case 69:
 			;
     break;}
 case 70:
-#line 789 "mwmparse.y"
+#line 801 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1633,7 +1696,7 @@ case 70:
 			;
     break;}
 case 71:
-#line 795 "mwmparse.y"
+#line 807 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1641,7 +1704,7 @@ case 71:
 			;
     break;}
 case 72:
-#line 801 "mwmparse.y"
+#line 813 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1649,7 +1712,7 @@ case 72:
 			;
     break;}
 case 73:
-#line 807 "mwmparse.y"
+#line 819 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1657,7 +1720,7 @@ case 73:
 			;
     break;}
 case 74:
-#line 813 "mwmparse.y"
+#line 825 "mwmparse.y"
 {
 			    yyerror("Invalid button event name");
 			    yyval.button.button = 0;
@@ -1666,15 +1729,15 @@ case 74:
 			;
     break;}
 case 75:
-#line 822 "mwmparse.y"
+#line 834 "mwmparse.y"
 { yyval.label.type = IS_STRING; yyval.label.string = yyvsp[0].string; ;
     break;}
 case 76:
-#line 824 "mwmparse.y"
+#line 836 "mwmparse.y"
 { yyval.label.type = IS_BITMAP; yyval.label.string = yyvsp[0].string; ;
     break;}
 case 77:
-#line 826 "mwmparse.y"
+#line 838 "mwmparse.y"
 {
 			    yyerror("Invalid label");
 			    yyval.label.type = IS_STRING;
@@ -1682,11 +1745,11 @@ case 77:
 			;
     break;}
 case 78:
-#line 834 "mwmparse.y"
+#line 846 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 79:
-#line 838 "mwmparse.y"
+#line 850 "mwmparse.y"
 {
 			    if (strlen(yyvsp[0].string) != 1) {
 				yyerror("Invalid mnemonic specification");
@@ -1698,277 +1761,277 @@ case 79:
 			;
     break;}
 case 80:
-#line 848 "mwmparse.y"
+#line 860 "mwmparse.y"
 { yyval.key = 0; ;
     break;}
 case 81:
-#line 852 "mwmparse.y"
+#line 864 "mwmparse.y"
 {
 			    yyval.function.func = F_BEEP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 82:
-#line 857 "mwmparse.y"
+#line 869 "mwmparse.y"
 {
 			    yyval.function.func = F_CIRCULATE_DOWN;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 83:
-#line 862 "mwmparse.y"
+#line 874 "mwmparse.y"
 {
 			    yyval.function.func = F_CIRCULATE_UP;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 84:
-#line 867 "mwmparse.y"
+#line 879 "mwmparse.y"
 {
 			    yyval.function.func = F_EXEC;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 85:
-#line 872 "mwmparse.y"
+#line 884 "mwmparse.y"
 {
 			    yyval.function.func = F_EXEC;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 86:
-#line 877 "mwmparse.y"
+#line 889 "mwmparse.y"
 {
 			    yyval.function.func = F_FOCUS_COLOR;
 			    yyval.function.arg = "";
 			;
     break;}
 case 87:
-#line 882 "mwmparse.y"
+#line 894 "mwmparse.y"
 {
 			    yyval.function.func = F_FOCUS_KEY;
 			    yyval.function.arg = "";
 			;
     break;}
 case 88:
-#line 887 "mwmparse.y"
+#line 899 "mwmparse.y"
 {
 			    yyval.function.func = F_CLOSE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 89:
-#line 892 "mwmparse.y"
+#line 904 "mwmparse.y"
 {
 			    yyval.function.func = F_LOWER;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 90:
-#line 897 "mwmparse.y"
+#line 909 "mwmparse.y"
 {
 			    yyval.function.func = F_MAXIMIZE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 91:
-#line 902 "mwmparse.y"
+#line 914 "mwmparse.y"
 {
 			    yyval.function.func = F_POPUP;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 92:
-#line 907 "mwmparse.y"
+#line 919 "mwmparse.y"
 {
 			    yyval.function.func = F_ICONIFY;
 			    yyval.function.arg = "";
 			;
     break;}
 case 93:
-#line 912 "mwmparse.y"
+#line 924 "mwmparse.y"
 {
 			    yyval.function.func = F_MOVE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 94:
-#line 917 "mwmparse.y"
+#line 929 "mwmparse.y"
 {
 			    yyval.function.func = F_NEXT_CMAP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 95:
-#line 922 "mwmparse.y"
+#line 934 "mwmparse.y"
 {
 			    yyval.function.func = F_NEXT_KEY;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 96:
-#line 927 "mwmparse.y"
+#line 939 "mwmparse.y"
 {
 			    yyval.function.func = F_NOP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 97:
-#line 932 "mwmparse.y"
+#line 944 "mwmparse.y"
 {
 			    yyval.function.func = F_NORMALIZE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 98:
-#line 937 "mwmparse.y"
+#line 949 "mwmparse.y"
 {
 			    yyval.function.func = F_NORM_AND_RAISE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 99:
-#line 942 "mwmparse.y"
+#line 954 "mwmparse.y"
 {
 			    yyval.function.func = F_PACK_ICONS;
 			    yyval.function.arg = "";
 			;
     break;}
 case 100:
-#line 947 "mwmparse.y"
+#line 959 "mwmparse.y"
 {
 			    yyval.function.func = F_PASS_KEYS;
 			    yyval.function.arg = "";
 			;
     break;}
 case 101:
-#line 952 "mwmparse.y"
+#line 964 "mwmparse.y"
 {
 			    yyval.function.func = F_W_POPUP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 102:
-#line 957 "mwmparse.y"
+#line 969 "mwmparse.y"
 {
 			    yyval.function.func = F_PREV_CMAP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 103:
-#line 962 "mwmparse.y"
+#line 974 "mwmparse.y"
 {
 			    yyval.function.func = F_PREV_KEY;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 104:
-#line 967 "mwmparse.y"
+#line 979 "mwmparse.y"
 {
 			    yyval.function.func = F_QUIT;
 			    yyval.function.arg = "";
 			;
     break;}
 case 105:
-#line 972 "mwmparse.y"
+#line 984 "mwmparse.y"
 {
 			    yyval.function.func = F_RAISE;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 106:
-#line 977 "mwmparse.y"
+#line 989 "mwmparse.y"
 {
 			    yyval.function.func = F_RAISELOWER;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 107:
-#line 982 "mwmparse.y"
+#line 994 "mwmparse.y"
 {
 			    yyval.function.func = F_REFRESH;
 			    yyval.function.arg = "";
 			;
     break;}
 case 108:
-#line 987 "mwmparse.y"
+#line 999 "mwmparse.y"
 {
 			    yyval.function.func = F_REFRESH_WIN;
 			    yyval.function.arg = "";
 			;
     break;}
 case 109:
-#line 992 "mwmparse.y"
+#line 1004 "mwmparse.y"
 {
 			    yyval.function.func = F_RESIZE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 110:
-#line 997 "mwmparse.y"
+#line 1009 "mwmparse.y"
 {
 			    yyval.function.func = F_ICONIFY;
 			    yyval.function.arg = "";
 			;
     break;}
 case 111:
-#line 1002 "mwmparse.y"
+#line 1014 "mwmparse.y"
 {
 			    yyval.function.func = F_RESTORE_AND_RAISE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 112:
-#line 1007 "mwmparse.y"
+#line 1019 "mwmparse.y"
 {
 			    yyval.function.func = F_RESTART;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 113:
-#line 1012 "mwmparse.y"
+#line 1024 "mwmparse.y"
 {
 			    yyval.function.func = F_SCREEN;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 114:
-#line 1017 "mwmparse.y"
+#line 1029 "mwmparse.y"
 {
 			    yyval.function.func = F_SEND_MSG;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 115:
-#line 1022 "mwmparse.y"
+#line 1034 "mwmparse.y"
 {
 			    yyval.function.func = F_NOP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 116:
-#line 1027 "mwmparse.y"
+#line 1039 "mwmparse.y"
 {
 			    yyval.function.func = F_SET_BEHAVIOR;
 			    yyval.function.arg = "";
 			;
     break;}
 case 117:
-#line 1032 "mwmparse.y"
+#line 1044 "mwmparse.y"
 {
 			    yyval.function.func = F_TITLE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 118:
-#line 1037 "mwmparse.y"
+#line 1049 "mwmparse.y"
 {
 			    yyval.function.func = F_WINDOWLIST;
 			    yyval.function.arg = "";
 			;
     break;}
 case 119:
-#line 1042 "mwmparse.y"
+#line 1054 "mwmparse.y"
 {
 			    yyerror("Invalid mnemonic, accelerator, or function");
 			    yyval.function.func = F_NOP;
@@ -1976,60 +2039,60 @@ case 119:
 			;
     break;}
 case 120:
-#line 1050 "mwmparse.y"
+#line 1062 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 121:
-#line 1052 "mwmparse.y"
+#line 1064 "mwmparse.y"
 { yyval.string = ""; ;
     break;}
 case 122:
-#line 1056 "mwmparse.y"
+#line 1068 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 123:
-#line 1058 "mwmparse.y"
+#line 1070 "mwmparse.y"
 { yyval.string = "ROOT"; ;
     break;}
 case 124:
-#line 1060 "mwmparse.y"
+#line 1072 "mwmparse.y"
 { yyval.string = "WINDOW"; ;
     break;}
 case 125:
-#line 1062 "mwmparse.y"
+#line 1074 "mwmparse.y"
 { yyval.string = "TRANSIENT"; ;
     break;}
 case 126:
-#line 1064 "mwmparse.y"
+#line 1076 "mwmparse.y"
 { yyval.string = "ICON"; ;
     break;}
 case 127:
-#line 1066 "mwmparse.y"
+#line 1078 "mwmparse.y"
 { yyval.string = "WITHIN"; ;
     break;}
 case 128:
-#line 1068 "mwmparse.y"
+#line 1080 "mwmparse.y"
 { yyval.string = "FREE_FAMILY"; ;
     break;}
 case 129:
-#line 1070 "mwmparse.y"
+#line 1082 "mwmparse.y"
 { yyval.string = "NEXT"; ;
     break;}
 case 130:
-#line 1072 "mwmparse.y"
+#line 1084 "mwmparse.y"
 { yyval.string = "PREV"; ;
     break;}
 case 131:
-#line 1074 "mwmparse.y"
+#line 1086 "mwmparse.y"
 { yyval.string = "BACK"; ;
     break;}
 case 132:
-#line 1077 "mwmparse.y"
+#line 1089 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 498 "/usr/share/bison.simple"
+#line 554 "/usr/share/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2224,17 +2287,45 @@ yyerrhandle:
 
   yystate = yyn;
   goto yynewstate;
+
+ yyacceptlab:
+  /* YYACCEPT comes here.  */
+#ifndef YYSTACK_USE_ALLOCA
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+#endif
+  return 0;
+
+ yyabortlab:
+  /* YYABORT comes here.  */
+#ifndef YYSTACK_USE_ALLOCA
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+#endif    
+  return 1;
 }
-#line 1079 "mwmparse.y"
+#line 1091 "mwmparse.y"
 
 
 /*
  * these to variables are used by the parser to control input
  */
 #define MAX_UNGET	1024
-static char *curpos;
-static char *endpos;
-static char *input_buf;
+static const char *curpos;
+static const char *endpos;
+static const char *input_buf;
 static char unget[MAX_UNGET];
 static int upos = 0;
 
@@ -2261,7 +2352,7 @@ yyerror(char *fmt, ...) {
  * find the config file
  */
 static Boolean
-find_config_file2(char *the_file) {
+find_config_file2(const char *the_file) {
     if (verbose)
 	printf("Checking for config file '%s'\n", the_file);
     if (access(the_file, R_OK) == 0)
@@ -2271,7 +2362,7 @@ find_config_file2(char *the_file) {
 
 
 static Boolean
-find_config_file3(char *buf, char *cfile) {
+find_config_file3(char *buf, const char *cfile) {
     char *lang, *ptr;
 
     /* Shall overrun check be done for each strcat()??? */
@@ -2301,7 +2392,7 @@ find_config_file3(char *buf, char *cfile) {
 
 
 static Boolean
-find_config_file(char *buf, char *cfile) {
+find_config_file(char *buf, const char *cfile) {
     char *home;
 
     home = getenv("HOME");
