@@ -1,3 +1,4 @@
+/* $Id: resize.c,v 1.6 2001/06/09 09:25:49 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -33,9 +34,16 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#include "mwm.h"
+#include <LTconfig.h>
 
 #include <stdio.h>
+#include <string.h>
+
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+
+#include "mwm.h"
+
 
 static int dragx;		/* all these variables are used */
 static int dragy;		/* in resize operations */
