@@ -1,3 +1,4 @@
+/* $Id: windows.c,v 1.20 2001/06/09 09:25:49 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -42,7 +43,10 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#include "mwm.h"
+
+#include <LTconfig.h>
+
+#include <stdio.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -51,6 +55,11 @@
 #include <X11/Intrinsic.h>
 #include <X11/extensions/shape.h>
 
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+
+#include "mwm.h"
+
 /*
  * some macros used by the constraint code
  */
@@ -280,29 +289,29 @@ save_context(MwmWindow *tmp_win)
 {
     int i;
 
-    XSaveContext(dpy, tmp_win->w, MwmContext, (_Xconst char *)tmp_win);
-    XSaveContext(dpy, tmp_win->frame, MwmContext, (_Xconst char *)tmp_win);
-    XSaveContext(dpy, tmp_win->parent, MwmContext, (_Xconst char *)tmp_win);
+    XSaveContext(dpy, tmp_win->w, MwmContext, (XPointer)tmp_win);
+    XSaveContext(dpy, tmp_win->frame, MwmContext, (XPointer)tmp_win);
+    XSaveContext(dpy, tmp_win->parent, MwmContext, (XPointer)tmp_win);
     if (tmp_win->decorations & MWM_DECOR_TITLE)
     {
 	XSaveContext(dpy, tmp_win->title, MwmContext,
-		     (_Xconst char *)tmp_win);
+		     (XPointer)tmp_win);
 	if (tmp_win->menub != None)
 	    XSaveContext(dpy, tmp_win->menub, MwmContext,
-			 (_Xconst char *)tmp_win);
+			 (XPointer)tmp_win);
 	if (tmp_win->minimizeb != None)
 	    XSaveContext(dpy, tmp_win->minimizeb, MwmContext,
-			 (_Xconst char *)tmp_win);
+			 (XPointer)tmp_win);
 	if (tmp_win->maximizeb != None)
 	    XSaveContext(dpy, tmp_win->maximizeb, MwmContext,
-			 (_Xconst char *)tmp_win);
+			 (XPointer)tmp_win);
     }
     if (tmp_win->decorations & MWM_DECOR_BORDER)
     {
 	for (i = 0; i < 4; i++)
 	{
 	    XSaveContext(dpy, tmp_win->sides[i],
-			 MwmContext, (_Xconst char *)tmp_win);
+			 MwmContext, (XPointer)tmp_win);
 	}
     }
     if (tmp_win->decorations & MWM_DECOR_RESIZEH)
@@ -310,7 +319,7 @@ save_context(MwmWindow *tmp_win)
 	for (i = 0; i < 4; i++)
 	{
 	    XSaveContext(dpy, tmp_win->corners[i],
-			 MwmContext, (_Xconst char *)tmp_win);
+			 MwmContext, (XPointer)tmp_win);
 	}
     }
 }
@@ -700,15 +709,15 @@ add_window(ScreenInfo *scr, Window w)
 
     tmp_win->w = w;
 
-    tmp_win->class.res_name = NoName;
-    tmp_win->class.res_class = NoName;
-    XGetClassHint(dpy, tmp_win->w, &tmp_win->class);
-    if (tmp_win->class.res_name == NULL)
-	tmp_win->class.res_name = NoName;
-    if (tmp_win->class.res_class == NULL)
-	tmp_win->class.res_class = NoName;
+    tmp_win->classhint.res_name = NoName;
+    tmp_win->classhint.res_class = NoName;
+    XGetClassHint(dpy, tmp_win->w, &tmp_win->classhint);
+    if (tmp_win->classhint.res_name == NULL)
+	tmp_win->classhint.res_name = NoName;
+    if (tmp_win->classhint.res_class == NULL)
+	tmp_win->classhint.res_class = NoName;
 
-    RES_GetClientDefaults(scr, tmp_win, tmp_win->class.res_name, tmp_win->class.res_class);
+    RES_GetClientDefaults(scr, tmp_win, tmp_win->classhint.res_name, tmp_win->classhint.res_class);
 
     if (XGetGeometry(dpy, tmp_win->w, &JunkRoot, &JunkX, &JunkY,
 		     &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) == 0)
@@ -802,7 +811,7 @@ add_window(ScreenInfo *scr, Window w)
     XSetWindowBorderWidth(dpy, tmp_win->w, 0);
 
     if (tmp_win->icon_label == NULL)
-	tmp_win->icon_label = tmp_win->class.res_name;
+	tmp_win->icon_label = tmp_win->classhint.res_name;
     tmp_win->icon_active_label = tmp_win->name;
 
     tmp_win->flags &= ~ICONIFIED;
@@ -1095,7 +1104,7 @@ WIN_ReleaseWindows(ScreenInfo *scr)
 }
 
 /*
- * find the MwmWindow strcture associated with a Window
+ * find the MwmWindow structure associated with a Window
  */
 MwmWindow *
 WIN_WindowToStruct(ScreenInfo *scr, Window target)
@@ -1920,10 +1929,10 @@ WIN_DestroyWindow(ScreenInfo *scr, MwmWindow *tmp)
 
     if (tmp->wmhints)
 	XFree((char *)tmp->wmhints);
-    if (tmp->class.res_name && tmp->class.res_name != NoName)
-	XFree((char *)tmp->class.res_name);
-    if (tmp->class.res_class && tmp->class.res_class != NoName)
-	XFree((char *)tmp->class.res_class);
+    if (tmp->classhint.res_name && tmp->classhint.res_name != NoName)
+	XFree((char *)tmp->classhint.res_name);
+    if (tmp->classhint.res_class && tmp->classhint.res_class != NoName)
+	XFree((char *)tmp->classhint.res_class);
     if (tmp->mwm_hints)
 	XFree((char *)tmp->mwm_hints);
     if (tmp->mwm_menu)
