@@ -1,8 +1,9 @@
 /**
  *
- * $Id: glue.c,v 1.5 1999/05/28 20:43:08 danny Exp $
+ * $Id: glue.c,v 1.8 2001/06/05 20:26:54 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -28,23 +29,23 @@
 
 #include <LTconfig.h>
 
+#include <stdlib.h>
+#include <stdio.h>
+#include <ctype.h>
+
+#include <X11/Xlib.h>
+
 #include "FakeWidget.h"
 #include "glue.h"
 #include "uil.h"
-#include <stdlib.h>
-#include <ctype.h>
-#include <X11/Xlib.h>
 #include "MrmTypes.h"
+#include "main.h"
 
-extern FILE *outFile;
 
 void Check(void);
 
 #define StripQuotes(s) {s++;s[strlen(s)-1] = 0;}
 
-extern FakeWidgetList WidgetTable;
-extern ExpressionList GlobalSymbolTable;
-extern ExpressionList LocalSymbolTable;
 
 /***
  ***        c is a child widget of the widget currently being defind in w.
@@ -265,7 +266,7 @@ InsertString(char *sl, char *s)
 	s = temp;
     }
 
-    Char8VectorAppend(StringList, Store(s));
+    Char8VectorAppend(StringList, __MrmStore(s));
 
     return (char *)StringList;
 }
@@ -337,7 +338,7 @@ expr_STRING(char *st, char *cs, int CompoundString)
 
 	    if (*st != '\\')
 	    {
-		Exit(LOC, "String ERROR\n");
+		__MrmExit(LOC, "String ERROR\n");
 	    }
 	    st++;
 	}
