@@ -1,8 +1,9 @@
 /**
  *
- * $Id: TextP.h,v 1.4 2000/01/09 20:23:25 hennessy Exp $
+ * $Id: TextP.h,v 1.7 2001/05/14 18:35:21 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,24 +23,18 @@
  *
  **/
 
-#ifndef XM_TEXT_P_H
-#define XM_TEXT_P_H
+#ifndef _XM_TEXTP_H
+#define _XM_TEXTP_H
 
 #include <Xm/PrimitiveP.h>
 #include <Xm/Text.h>
 #include <Xm/TextOutP.h>
 #include <Xm/TextInP.h>
-#include <limits.h> /* for INT_MAX */
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#define	DBG(a)	XdbDebug(__FILE__, NULL, "%s\n", a)
-#define DBGW(a) XdbDebug(__FILE__, (Widget)w, "%s\n", a)
-#define DBG1(a,b) XdbDebug(__FILE__, (Widget)w, "%s: %d\n", a, (int)b)
-#define DBG2(a,b,c) XdbDebug(__FILE__, (Widget)w, "%s: %d\n", a, (int)b,(int)c)
-
 typedef struct _InputRec *Input;
 typedef struct _OutputRec *Output;
 
@@ -235,6 +230,8 @@ extern void _XmTextDelete(XmTextWidget w, XEvent *ev,
 		XmTextPosition start, XmTextPosition end);
 extern void _XmTextSetTopCharacter ( Widget w, XmTextPosition position);
 extern LineNum _XmTextNumLines( XmTextWidget widget);
+void _XmTextInvalidate(XmTextWidget w, XmTextPosition position,
+		       XmTextPosition topos, long delta);
 
 #define Text_Source(w) (((XmTextWidget)(w))->text.source)
 #define Text_ActivateCallback(w) (((XmTextWidget)(w))->text.activate_callback)
@@ -305,5 +302,4 @@ extern LineNum _XmTextNumLines( XmTextWidget widget);
 };
 #endif
 
-#endif /* XM_TEXT_P_H */
-
+#endif /* _XM_TEXTP_H */
