@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ToggleBP.h,v 1.4 1998/07/04 21:27:26 danny Exp $
- * 
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.0/Xm/ToggleBP.h,v 1.7 2001/06/17 10:23:57 amai Exp $
+ *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,8 +24,8 @@
  **/
 
 
-#ifndef XM_TOGGLEB_P_H
-#define XM_TOGGLEB_P_H
+#ifndef _XM_TOGGLEBP_H
+#define _XM_TOGGLEBP_H
 
 #include <Xm/ToggleB.h>
 #include <Xm/LabelP.h>
@@ -38,12 +39,14 @@ typedef struct {
     Boolean visible;
     Dimension spacing;
     Dimension indicator_dim;
-    Boolean indicator_set;     /* indicator state while armed ??? */
+    Boolean indicator_set;
     Pixmap on_pixmap;
     Pixmap insen_pixmap;
-    Boolean set;               /* button state */
-    Boolean visual_set;                /* visual state */
-    Boolean ind_on;            /* do we draw the indicator ?*/
+    Boolean set;		/* button state */
+    Boolean visual_set;		/* visual state */
+
+    unsigned char ind_on;	/* type changed in 2.0 */
+
     unsigned char fill_on_select;
     Pixel select_color;
 
@@ -54,6 +57,11 @@ typedef struct {
     XtCallbackList arm_CB;
     XtCallbackList disarm_CB;
     Boolean Armed;
+
+/* 2.0 novelties */
+    Dimension		detail_shadow_thickness;
+    Pixmap		indeterminate_pixmap;
+    unsigned char	toggle_mode;
 } XmToggleButtonPart;
 
 /* Define the full instance record */
@@ -84,8 +92,15 @@ extern XmToggleButtonClassRec xmToggleButtonClassRec;
 /* Only for use in RowColumn */
 extern void _XmToggleButtonSetState(Widget, Boolean, Boolean);
 
+#define	TB_DetailShadowThickness(w)	\
+		(((XmToggleButtonWidget)(w))->toggle.detail_shadow_thickness)
+#define	TB_IndeterminatePixmap(w)	\
+		(((XmToggleButtonWidget)(w))->toggle.indeterminate_pixmap)
+#define	TB_ToggleMode(w)	\
+		(((XmToggleButtonWidget)(w))->toggle.toggle_mode)
+
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* XM_TOGGLEB_P_H */
+#endif /* _XM_TOGGLEBP_H */
