@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.10 2000/09/22 20:35:14 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.13 2001/07/27 18:55:20 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.10 2000/09/22 20:35:14 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.13 2001/07/27 18:55:20 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -429,7 +429,7 @@ secondary_object_create(Widget request, Widget new_w,
     XmWidgetExtData ed;
     int size;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "IconGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -578,7 +578,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "IconG InitializePrehook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "IconG InitializePrehook\n"));
 }
 
 static void
@@ -587,7 +587,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "IconG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "IconG InitializePosthook\n"));
 
     /* don't let the null fool you */
 #if 0
@@ -613,7 +613,7 @@ _XmCalcIconGDimensions(Widget w)
 Dimension TextHeight, TextWidth;
 unsigned int IconHeight, IconWidth;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmCalcIconGDimensions\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmCalcIconGDimensions\n"));
     if (_XmStringIsXmString((XmString)IG_LabelString(w)))
     {
 	IG_LabelString(w) = (XmString)_XmStringCreate((XmString)IG_LabelString(w));
@@ -623,7 +623,7 @@ unsigned int IconHeight, IconWidth;
 		    (_XmString) IG_LabelString(w),
 		    &TextWidth,
 		    &TextHeight);
-    DEBUGOUT(XdbDebug(__FILE__, w, "\t Text width %d height %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "\t Text width %d height %d\n",
     		TextWidth, TextHeight));
 
     {
@@ -639,7 +639,7 @@ unsigned int IconHeight, IconWidth;
 		 &IconWidth, &IconHeight,
 		 &tmp, &Depth);
     }
-    DEBUGOUT(XdbDebug(__FILE__, w, "\t Icon width %d height %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "\t Icon width %d height %d\n",
     		IconWidth, IconHeight));
 
     XtWidth(w) = TextWidth + IconWidth
@@ -647,7 +647,7 @@ unsigned int IconHeight, IconWidth;
 	    + G_HighlightThickness(w));
     XtHeight(w) = TextHeight > IconHeight ? TextHeight : IconHeight
 	    + 2 * G_HighlightThickness(w);
-    DEBUGOUT(XdbDebug(__FILE__, w, "\t width %d height %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "\t width %d height %d\n",
     		XtWidth(w), XtHeight(w)));
 }
 
@@ -655,7 +655,7 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -664,7 +664,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     /* get the default fontlist if the label was created without one. */
     /* this should come from the renderTable (whatever that is??) FIXME */
@@ -865,7 +865,7 @@ destroy(Widget w)
 static void
 resize(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w,"resize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w,"resize\n"));
 
     if (!XmIsLabelGadget(w))
     {
@@ -992,7 +992,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -1004,7 +1004,7 @@ set_values(Widget old, Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
 #if 0
     if (IG_ArmColor(new_w) != IG_ArmColor(old))
@@ -1228,7 +1228,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "GetValuesHook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "GetValuesHook\n"));
 }
 
 static void
@@ -1241,7 +1241,7 @@ expose(Widget w, XEvent *event, Region region)
     XRectangle cliprect;
     GC myGC;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "expose\n"));
     /*
      * I'm getting paranoid - Danny - see testXm/filesb/test3
      */
@@ -1267,7 +1267,7 @@ expose(Widget w, XEvent *event, Region region)
 	2 * (/*G_ShadowThickness(w) +*/ G_HighlightThickness(w));
 
     XSetClipRectangles(XtDisplay(w), myGC, 0, 0, &cliprect, 1, Unsorted);
-    DEBUGOUT(XdbDebug(__FILE__, w, "cliprect x %d y %d width %d height %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "cliprect x %d y %d width %d height %d\n",
     		cliprect.x, cliprect.y,
     		cliprect.width, cliprect.height));
 
@@ -1344,8 +1344,8 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
 #define	Wants(x)	(proposed->request_mode & x)
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "query_geometry %s\n",
-		      XdbWidgetGeometry2String(proposed)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry %s\n",
+		      _LtDebugWidgetGeometry2String(proposed)));
 
     wd = XtWidth(w);
     ht = XtHeight(w);
@@ -1364,7 +1364,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     a.width = XtWidth(w);
     a.height = XtHeight(w);
     a.request_mode = CWWidth | CWHeight;
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "IconGadget queried for size: reporting %d %d %08x\n",
 		      XtWidth(w), XtHeight(w), answer));
 
@@ -1460,7 +1460,7 @@ Activate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XButtonEvent *ev = (XButtonEvent *)event;
     XtExposeProc exp = XtClass(w)->core_class.expose;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Activate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Activate\n"));
 
     if (IG_Armed(w) == False)
     {
@@ -1507,7 +1507,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
     Widget w = (Widget)data;
     XtExposeProc exp = XtClass(w)->core_class.expose;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Activate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Activate\n"));
 
     if (IG_Armed(w) == False)
     {
@@ -1537,7 +1537,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
 static void
 ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
 
     Arm(w, event, params, num_params);
 
@@ -1556,7 +1556,7 @@ EnterWindow(Widget w,
     XtExposeProc exp = XtClass(w)->core_class.expose;
     */
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "EnterWindow()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "EnterWindow()\n"));
 
 #if 0
     if (!IN_MENU(w))
@@ -1670,7 +1670,7 @@ ButtonUp(Widget w, XEvent *event, String *params, Cardinal *num_params)
     Boolean validButton, poppedUp;
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ButtonUp()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonUp()\n"));
 
     /* queue events until the next button event */
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
@@ -1853,14 +1853,14 @@ Help(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 {
-    DEBUGOUT(XdbDebug(__FILE__, gadget, "input_dispatch\n"));
+    DEBUGOUT(_LtDebug(__FILE__, gadget, "input_dispatch\n"));
 #if 0
     Cardinal num_params = 0;
 
     switch (event_mask)
     {
     case XmARM_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got arm event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got arm event\n"));
 #if 0
 	if (IN_MENU(gadget))
 	{
@@ -1890,7 +1890,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmACTIVATE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got activate event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got activate event\n"));
 	/*
 	 * The test below is expanded so it also checks for the Shell.
 	 * In tearoff menus, the shell will be a TransientShell, thus we'll
@@ -1925,17 +1925,17 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmENTER_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got an enter window\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got an enter window\n"));
 	EnterWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmLEAVE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got a leave window\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got a leave window\n"));
 	LeaveWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmMOTION_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got a motion event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got a motion event\n"));
 	break;
 
     case XmFOCUS_IN_EVENT:
