@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.29 2000/11/10 10:42:39 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.39 2001/08/06 15:50:11 dannybackx Exp $
  *
  * Copyright (C) 1997-1998 Free Software Foundation, Inc.
- * Copyright (C) 1998-2000 LessTif Development Team
+ * Copyright  1998, 1999, 2000, 2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.29 2000/11/10 10:42:39 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.39 2001/08/06 15:50:11 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -113,6 +113,11 @@ static XtResource resources[] =
 	sizeof(unsigned char), Offset(arrow_layout),
 	XmRImmediate, (XtPointer)XmARROWS_END
     },
+    {
+	XmNarrowOrientation, XmCArrowOrientation, XmRArrowOrientation,
+	sizeof(unsigned char), Offset(arrow_orientation),
+	XmRImmediate, (XtPointer)XmARROWS_VERTICAL
+    },
     {
 	XmNarrowSize, XmCArrowSize, XmRArrowSize,
 	sizeof(Dimension), Offset(arrow_size),
@@ -199,6 +204,9 @@ static XtActionsRec actions[] =
 	{"SpinBoxFocusOut",	SpinBoxFocusOut}
 };
 
+/*
+ * Constraint resources, i.e. resources magically added to all XmSpinBox children.
+ */
 #define Offset(field) XtOffsetOf(XmSpinBoxConstraintRec, spinBox.field)
 static XtResource ConstraintResources[] = {
     {
@@ -236,6 +244,11 @@ static XtResource ConstraintResources[] = {
 	sizeof(int), Offset(position),
 	XmRImmediate, (XtPointer)0
     },
+    {
+	XmNpositionType, XmCPositionType, XmRChar,
+	sizeof(unsigned char), Offset(position_type),
+	XmRImmediate, (XtPointer)XmPOSITION_VALUE
+    },
     {
 	XmNspinBoxChildType, XmCSpinBoxChildType, XmRSpinBoxChildType,
 	sizeof(unsigned char), Offset(sb_child_type),
@@ -245,7 +258,12 @@ static XtResource ConstraintResources[] = {
 	XmNvalues, XmCValues, XmRXmStringTable,
 	sizeof(XmStringTable), Offset(values),
 	XmRImmediate, (XtPointer)NULL
-    }
+    },
+    {
+	XmNpositionType, XmCPositionType, XmRChar,
+	sizeof(unsigned char), Offset(position_type),
+	XmRImmediate, (XtPointer)XmPOSITION_INDEX
+    },
 };
 
 /* FIX ME - this should go in other files */
@@ -412,8 +430,10 @@ class_initialize(void)
 {
     _XmSpinBoxCoreClassExtRec.record_type = XmQmotif;
 
-    XmeTraitSet(xmSpinBoxWidgetClass, XmQTnavigator, &_XmSPBNavigatorTraitRec);
-    XmeTraitSet(xmSpinBoxWidgetClass, XmQTnavigator, &_XmSPBNavigatorTraitRec);
+    XmeTraitSet((XtPointer)xmSpinBoxWidgetClass, XmQTnavigator,
+                (XtPointer)&_XmSPBNavigatorTraitRec);
+    XmeTraitSet((XtPointer)xmSpinBoxWidgetClass, XmQTnavigator,
+                (XtPointer)&_XmSPBNavigatorTraitRec);
 }
 
 static void
@@ -452,11 +472,11 @@ initialize(Widget request, Widget nw,
 {
 	XmScrollFrameTrait	t;
 
-	DEBUGOUT(XdbDebug(__FILE__, nw,
+	DEBUGOUT(_LtDebug(__FILE__, nw,
 		      "SpinBox initialize: w/h %d %d\n",
 		      XtWidth(nw), XtHeight(nw)));
 #if 0
-	DEBUGOUT(XdbPrintArgList(__FILE__, nw, args, *num_args, False));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
 	SPB_TextW(nw) = NULL;
@@ -470,7 +490,7 @@ initialize(Widget request, Widget nw,
 	}
 
 	/* Find out if our parent is a ScrollFrame */
-	t = (XmScrollFrameTrait) XmeTraitGet(XtClass(XtParent(nw)),
+	t = (XmScrollFrameTrait) XmeTraitGet((XtPointer)XtClass(XtParent(nw)),
 					XmQTscrollFrame);
 	if (t) {
 		t->init(XtParent(nw), _XmSPBTraitMoveCB, nw);	/* ??? FIX ME */
@@ -489,7 +509,7 @@ SetValues(Widget old, Widget request, Widget nw,
     Boolean	need_refresh = False,
 		need_layout = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, nw, "SetValues()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, nw, "SetValues()\n"));
 
 #define	NE(x)	(x(old) != x(nw))
 
@@ -505,8 +525,8 @@ SetValues(Widget old, Widget request, Widget nw,
     if (NE(SPB_UpX) || NE(SPB_UpY)
      || NE(SPB_UpWidth) || NE(SPB_UpHeight)
      || NE(SPB_DownX) || NE(SPB_DownY)
-     || NE(SPB_DownWidth) || NE(SPB_DownHeight))
-		;
+     || NE(SPB_DownWidth) || NE(SPB_DownHeight)) {
+    }
 
     if (need_layout) {
 	Layout(nw, NULL);
@@ -520,7 +540,8 @@ SetValues(Widget old, Widget request, Widget nw,
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Expose\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Expose up %d %d down %d %d\n",
+		SPB_UpX(w), SPB_UpY(w), SPB_DownX(w), SPB_DownY(w)));
 
 	_XmRedisplayGadgets(w, event, region);
 
@@ -533,7 +554,7 @@ expose(Widget w, XEvent *event, Region region)
 			SPB_UpWidth(w),
 			SPB_UpHeight(w),
 			SPB_DetailShadowThickness(w),
-			XmARROW_RIGHT);
+			(SPB_ArrowOrientation(w) == XmARROWS_HORIZONTAL) ? XmARROW_RIGHT : XmARROW_UP);
 	XmeDrawArrow(XtDisplay(w), XtWindow(w),
 			MGR_BottomShadowGC(w),
 			MGR_TopShadowGC(w),
@@ -543,13 +564,13 @@ expose(Widget w, XEvent *event, Region region)
 			SPB_DownWidth(w),
 			SPB_DownHeight(w),
 			SPB_DetailShadowThickness(w),
-			XmARROW_LEFT);
+			(SPB_ArrowOrientation(w) == XmARROWS_HORIZONTAL) ? XmARROW_LEFT : XmARROW_DOWN);
 }
 
 static void
 resize(Widget w)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Resize\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Resize\n"));
 }
 
 /*
@@ -563,26 +584,28 @@ ConstraintInitialize(Widget request, Widget nw,
 {
     Widget sb = XtParent(nw);
 
-	DEBUGOUT(XdbDebug2(__FILE__, sb, nw, "ConstraintInitialize\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sb, nw, "ConstraintInitialize\n"));
 #if 0
-	DEBUGOUT(XdbPrintArgList(__FILE__, nw, args, *num_args, False));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
-		if (SPBC_Numeric(nw))
-			DEBUGOUT(XdbDebug(__FILE__, nw,
+		if (SPBC_Numeric(nw)) {
+			DEBUGOUT(_LtDebug(__FILE__, nw,
 				"ConstraintInitialize(XmNUMERIC) min %d max %d inc %d\n",
 				SPBC_Minimum(nw),
 				SPBC_Maximum(nw),
 				SPBC_Increment(nw) ));
-		else
-			DEBUGOUT(XdbDebug(__FILE__, nw,
+		}
+		else {
+			DEBUGOUT(_LtDebug(__FILE__, nw,
 				"ConstraintInitialize(XmSTRING) num_values %d\n",
 				SPBC_NumValues(nw)));
+		}
 
 	if (SPBC_ArrowSensitivity(nw) == XmARROWS_DEFAULT_SENSITIVITY)
 		SPBC_ArrowSensitivity(nw) = SPB_DefaultSensitivity(sb);
 
-	if (XmeTraitGet(XtClass(nw), XmQTaccessTextual))
+	if (XmeTraitGet((XtPointer)XtClass(nw), XmQTaccessTextual))
 		_XmSpinBoxShowValue(sb, nw);
 }
 
@@ -593,9 +616,9 @@ ConstraintSetValues(Widget curr, Widget req, Widget nw,
 	Widget	sb = XtParent(nw);
 	Boolean	r = False;
 
-	DEBUGOUT(XdbDebug2(__FILE__, sb, nw, "ConstraintSetValues\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sb, nw, "ConstraintSetValues\n"));
 #if 0
-	DEBUGOUT(XdbPrintArgList(__FILE__, nw, args, *num_args, False));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
 #define	NE(x)	(x(curr) != x(nw))
@@ -627,7 +650,7 @@ static void
 PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 				Dimension *wid, Dimension *ht)
 {
-	int		i;
+	Cardinal i;
 	Position	xx, yy;
 	Dimension	hh = 0;
 
@@ -642,28 +665,18 @@ PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 				hh = XtHeight(child);
 
 			xx += XtWidth(child) + SPB_Spacing(w);
-			DEBUGOUT(XdbDebug2(__FILE__, w, child,
+			DEBUGOUT(_LtDebug2(__FILE__, w, child,
 				"PreferredSize: add width %d\n",
 				XtWidth(child)));
 	}
 
-	SPB_DownX(w) = xx;
-	SPB_DownY(w) = yy;
-	SPB_DownWidth(w) = SPB_ArrowSize(w);
-	SPB_DownHeight(w) = SPB_ArrowSize(w);
-
 	xx += SPB_DownWidth(w) + SPB_Spacing(w);
-
-	SPB_UpX(w) = xx;
-	SPB_UpY(w) = yy;
-	SPB_UpWidth(w) = SPB_ArrowSize(w);
-	SPB_UpHeight(w) = SPB_ArrowSize(w);
 	xx += SPB_UpWidth(w) + SPB_MarginWidth(w);
 
 	*wid = xx;
 	*ht = hh + 2 * SPB_MarginHeight(w);;
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	"PreferredSize => %d %d (ArrowSize %d MarginWidth %d"
 	" MarginHeight %d Spacing %d)\n",
 		*wid, *ht,
@@ -675,15 +688,26 @@ PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 /*
  * Layout is primarily influenced by
  *	SPB_ArrowLayout (XmARROWS_BEGINNING, XmARROWS_END, XmARROWS_SPLIT).
+ *
+ * FIX ME
+ *	XmNarrowOrientation (XmARROWS_VERTICAL, XmARROWS_HORIZONTAL).
+ *	ArrowLayout XmARROWS_FLAT_BEGINNING, XmARROWS_FLAT_END missing.
  */
 static void
 Layout(Widget w, Widget instig)
 {
-	int		i;
+	Cardinal i;
 	Position	xx, yy;
 	Dimension	hh = 0;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "XmSpinBox Layout\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmSpinBox Layout %s\n",
+		(SPB_ArrowLayout(w) == XmARROWS_BEGINNING) ? "XmARROWS_BEGINNING" :
+		(SPB_ArrowLayout(w) == XmARROWS_END) ? "XmARROWS_END" :
+		(SPB_ArrowLayout(w) == XmARROWS_SPLIT) ? "XmARROWS_SPLIT" :
+		(SPB_ArrowLayout(w) == XmARROWS_FLAT_BEGINNING) ? "XmARROWS_FLAT_BEGINNING" :
+		(SPB_ArrowLayout(w) == XmARROWS_FLAT_END) ? "XmARROWS_FLAT_END" :
+		"??"
+	));
 
 	for (i=0; i<MGR_NumChildren(w); i++)
 	    if (XtHeight(MGR_Children(w)[i]) > hh)
@@ -712,10 +736,11 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-				XtX(child) = xx;
-				XtY(child) = SPB_MarginHeight(w);
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
 
-				xx += XtWidth(child) + SPB_Spacing(w);
+			xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 		break;
@@ -727,10 +752,11 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-				XtX(child) = xx;
-				XtY(child) = SPB_MarginHeight(w);
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
 
-				xx += XtWidth(child) + SPB_Spacing(w);
+			xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 	    SPB_DownX(w) = xx;
@@ -757,22 +783,84 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-				XtX(child) = xx;
-				XtY(child) = SPB_MarginHeight(w);
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
 
-				xx += XtWidth(child) + SPB_Spacing(w);
+			xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 	    SPB_UpX(w) = xx;
 	    SPB_UpY(w) = yy;
 	    SPB_UpWidth(w) = SPB_ArrowSize(w);
 	    SPB_UpHeight(w) = SPB_ArrowSize(w);
+	    break;
+	case XmARROWS_FLAT_BEGINNING:				/* FIX ME */
+	    SPB_DownX(w) = SPB_MarginWidth(w);
+	    SPB_DownY(w) = yy;
+	    SPB_DownWidth(w) = SPB_ArrowSize(w);
+	    SPB_DownHeight(w) = SPB_ArrowSize(w);
+
+	    xx = SPB_MarginWidth(w) + SPB_Spacing(w) + SPB_DownWidth(w);
+
+	    SPB_UpX(w) = xx;
+	    SPB_UpY(w) = yy;
+	    SPB_UpWidth(w) = SPB_ArrowSize(w);
+	    SPB_UpHeight(w) = SPB_ArrowSize(w);
+
+	    xx += SPB_MarginWidth(w) + SPB_Spacing(w) + SPB_UpWidth(w) + SPB_ArrowSize(w);
+
+	    for (i=0; i<MGR_NumChildren(w); i++)
+		if (XtIsManaged(MGR_Children(w)[i])) {
+			Widget	child = MGR_Children(w)[i];
+
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
+
+			xx += XtWidth(child) + SPB_Spacing(w);
+		}
+
+	    break;
+	case XmARROWS_FLAT_END:				/* FIX ME */
+	    xx = SPB_MarginWidth(w);
+
+	    for (i=0; i<MGR_NumChildren(w); i++)
+		if (XtIsManaged(MGR_Children(w)[i])) {
+			Widget	child = MGR_Children(w)[i];
+
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
+
+			xx += XtWidth(child) + SPB_Spacing(w);
+		}
+
+	    SPB_DownX(w) = xx;
+	    SPB_DownY(w) = yy;
+	    SPB_DownWidth(w) = SPB_ArrowSize(w);
+	    SPB_DownHeight(w) = SPB_ArrowSize(w);
+
+	    xx += SPB_MarginWidth(w) + SPB_ArrowSize(w) + SPB_Spacing(w);
+
+	    SPB_UpX(w) = xx;
+	    SPB_UpY(w) = yy;
+	    SPB_UpWidth(w) = SPB_ArrowSize(w);
+	    SPB_UpHeight(w) = SPB_ArrowSize(w);
+	    break;
 	}
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	    "SpinBoxLayout: down at %d %d up at %d %d, spb size %d %d\n",
 	    SPB_DownX(w), SPB_DownY(w), SPB_UpX(w), SPB_UpY(w),
 	    XtWidth(w), XtHeight(w)));
+	 for (i=0; i<MGR_NumChildren(w); i++) {
+		if (XtIsManaged(MGR_Children(w)[i])) {
+			Widget	child = MGR_Children(w)[i];
+			DEBUGOUT(_LtDebug2(__FILE__, w, child, "x %d y %d sz %d %d\n",
+				XtX(child), XtY(child), XtWidth(child), XtHeight(child)));
+		}
+	}
 }
 
 static XtGeometryResult
@@ -783,7 +871,7 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
 #define	Wants(x)	((geo.request_mode & x) == x)
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry\n"));
 
     geo = *proposed;
 
@@ -797,16 +885,16 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
     if (Wants(CWHeight) && (geo.height != answer->height))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry => No.\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => No.\n"));
 	return XtGeometryNo;
     }
     if (Wants(CWWidth) && (geo.width != answer->width))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry => No.\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => No.\n"));
 	return XtGeometryNo;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry => Yes.\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => Yes.\n"));
     return XtGeometryYes;
 }
 
@@ -815,7 +903,7 @@ GeometryManager(Widget w,
 		 XtWidgetGeometry *request,
 		 XtWidgetGeometry *reply)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "GeometryManager\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "GeometryManager\n"));
 
 	/* FIX ME */
 
@@ -829,17 +917,17 @@ ChangeManaged(Widget w)
 	XtWidgetGeometry	geo;
 	XtGeometryResult	r;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "ChangeManaged\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged\n"));
 
 	/* Make sure that our size is right */
 	PreferredSize(w, NULL, NULL, &geo.width, &geo.height);
 	geo.request_mode = CWWidth | CWHeight;
 
 	r = _XmMakeGeometryRequest(w, &geo);
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 		"ChangeManaged Geometry Request %s -> %s\n",
-		XdbWidgetGeometry2String(&geo),
-		XdbGeometryResult2String(r)));
+		_LtDebugWidgetGeometry2String(&geo),
+		_LtDebugGeometryResult2String(r)));
 
 	if (r == XtGeometryYes) {
 		/* FIX ME */
@@ -883,7 +971,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 	tw = SPB_TextW(w);
 
 	if (tw == NULL) {
-		DEBUGOUT(XdbDebug(__FILE__, w, "SpinBModify: no text widget\n"));
+		DEBUGOUT(_LtDebug(__FILE__, w, "SpinBModify: no text widget\n"));
 		return;
 	}
 
@@ -925,7 +1013,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 		s = _XmSpinBoxNumericString(tw);
 		xms = XmStringCreateSimple(s);
 
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 			"SpinBModify(NUMERIC) %d [%d,%d]\n",
 			SPBC_Position(tw), SPBC_Minimum(tw), SPBC_Maximum(tw)));
 	} else {
@@ -953,7 +1041,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 
 		xms = XmStringCopy(SPBC_Values(tw)[SPBC_Position(tw)]);
 
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 			"SpinBModify(STRING) %d [%d,%d]\n",
 			SPBC_Position(tw), 0, SPBC_NumValues(tw)));
 	}
@@ -991,7 +1079,7 @@ _XmSpinBoxTimer(XtPointer client, XtIntervalId *timerid)
 {
 	Widget	spb = (Widget)client;
 
-	DEBUGOUT(XdbDebug(__FILE__, spb, "_XmSpinBoxTimer\n"));
+	DEBUGOUT(_LtDebug(__FILE__, spb, "_XmSpinBoxTimer\n"));
 
 	if (SPB_UpArrowPressed(spb))
 			SpinBModify(spb, NULL, XmCR_SPIN_NEXT);
@@ -1007,7 +1095,7 @@ SpinBArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
 	Widget	tw;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBArm at %d %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBArm at %d %d\n",
 		event->xbutton.x, event->xbutton.y));
 
 	if ((tw = SPB_TextW(w)) == NULL)
@@ -1068,7 +1156,7 @@ SpinBArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 SpinBDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBDisarm\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBDisarm\n"));
 
 	if (SPB_TimerId(w))
 		XtRemoveTimeOut(SPB_TimerId(w));
@@ -1081,37 +1169,37 @@ SpinBDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 SpinBFirst(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBFirst\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBFirst\n"));
 }
 
 static void
 SpinBLast(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBLast\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBLast\n"));
 }
 
 static void
 SpinBLeft(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBLeft\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBLeft\n"));
 }
 
 static void
 SpinBRight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBRight\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBRight\n"));
 }
 
 static void
 SpinBNext(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBNext\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBNext\n"));
 }
 
 static void
 SpinBPrior(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBPrior\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBPrior\n"));
 }
 
 static void
@@ -1119,7 +1207,7 @@ _XmSpinBoxChildFocus(Widget w, XtPointer client, XtPointer call)
 {
 	Widget	spb = (Widget)client;
 
-	DEBUGOUT(XdbDebug2(__FILE__, spb, w, "_XmSpinBoxChildFocus\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, spb, w, "_XmSpinBoxChildFocus\n"));
 
 	SPB_TextW(spb) = w;
 }
@@ -1129,17 +1217,17 @@ InsertChild(Widget w)
 {
     Widget	spb = XtParent(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, (Widget)spb, w, "SpinBox InsertChild\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)spb, w, "SpinBox InsertChild\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->composite_class.insert_child) (w);
 #undef superclass
 
-	if (XmeTraitGet(XtClass(w), XmQTaccessTextual)) {
+	if (XmeTraitGet((XtPointer)XtClass(w), XmQTaccessTextual)) {
 #if 0
 		Arg		a;
 
-		DEBUGOUT(XdbDebug2(__FILE__, spb, w,
+		DEBUGOUT(_LtDebug2(__FILE__, spb, w,
 			"Adding accelerators to child\n"));
 
 		XtSetArg(a, XmNtranslations,
@@ -1189,12 +1277,13 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 	XmString	xms;
 	XmAccessTextualTrait	trait;
 
-	DEBUGOUT(XdbDebug(__FILE__, spb, "_XmSpinBoxShowValue\n"));
+	DEBUGOUT(_LtDebug(__FILE__, spb, "_XmSpinBoxShowValue\n"));
 
 	if (spb == NULL || t == NULL)
 		return;
 
-	trait = (XmAccessTextualTrait)XmeTraitGet(XtClass(t), XmQTaccessTextual);
+	trait = (XmAccessTextualTrait)XmeTraitGet((XtPointer)XtClass(t),
+	                                           XmQTaccessTextual);
 
 	if (trait == NULL) {
 	    _XmError(t, "_XmSpinBoxShowValue: no trait XmQTaccessTextual\n");
@@ -1223,7 +1312,7 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 			XmTextSetString(t, s);
 			XtFree(s);
 		} else
-			trait->setValue(t, xms, XmFORMAT_XmSTRING);
+			trait->setValue(t, (XtPointer)xms, XmFORMAT_XmSTRING);
 		/* Do *not* free xms */
 	}
 
@@ -1232,19 +1321,19 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 static void
 SpinBoxEnter(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBoxEnter\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxEnter\n"));
 }
 
 static void
 SpinBoxFocusIn(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBoxFocusIn\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxFocusIn\n"));
 }
 
 static void
 SpinBoxFocusOut(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBoxFocusOut\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxFocusOut\n"));
 }
 
 /*
@@ -1256,7 +1345,7 @@ _XmSPBTraitChangeMoveCB(Widget nav,
 			XtPointer closure,
 			Boolean setUnset)
 {
-	DEBUGOUT(XdbDebug(__FILE__, nav,
+	DEBUGOUT(_LtDebug(__FILE__, nav,
 		"_XmSPBTraitChangeMoveCB (%s)\n",
 		setUnset ? "set" : "unset"));
 
@@ -1271,7 +1360,7 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 {
 	Widget	tw;
 
-	DEBUGOUT(XdbDebug(__FILE__, nav, "_XmSPBTraitSetValue\n"));
+	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitSetValue\n"));
 
 	tw = SPB_TextW(nav);
 	if (tw == NULL)
@@ -1300,7 +1389,7 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 static int
 _XmSPBTraitGetValue(Widget nav, XmNavigatorData navigatorData)
 {
-	DEBUGOUT(XdbDebug(__FILE__, nav, "_XmSPBTraitGetValue\n"));
+	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitGetValue\n"));
 	return 0;
 }
 
@@ -1310,7 +1399,7 @@ _XmSPBTraitGetValue(Widget nav, XmNavigatorData navigatorData)
 static void
 _XmSPBTraitMoveCB(Widget nav, XtPointer client, XtPointer call)
 {
-	DEBUGOUT(XdbDebug(__FILE__, nav, "_XmSPBTraitMoveCB\n"));
+	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitMoveCB\n"));
 
 	/*
 	 * This gets called when a navigator (e.g. Notebook) that we're
