@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.13 2000/11/07 12:45:23 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.16 2001/07/27 18:55:21 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2000 LessTif Development Team
+ * Copyright (C) 1997-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.13 2000/11/07 12:45:23 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.16 2001/07/27 18:55:21 dannybackx Exp $";
 
 /*
  * This file contains a poor man's implementation of traits.
@@ -125,12 +125,12 @@ XmeTraitGet(XtPointer obj, XrmQuark trait)
 	WidgetClass	super;
 
 	if (obj == NULL || trait == 0) {
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "XmeTraitGet(NULL)\n"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "XmeTraitGet(NULL)\n"));
 		_XmInitTraits();
 		return NULL;
 	}
 
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "XmeTraitGet(%s,%s)\n",
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmeTraitGet(%s,%s)\n",
 			((WidgetClass)obj)->core_class.class_name,
 			XrmQuarkToString(trait)));
 
@@ -185,12 +185,12 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 	int	i, j;
 
 	if (obj == NULL || trait == 0) {
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "XmeTraitSet(NULL)\n"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "XmeTraitSet(NULL)\n"));
 		_XmInitTraits();
 		return False;
 	}
 
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "XmeTraitSet(%s,%s)\n",
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmeTraitSet(%s,%s)\n",
 			((WidgetClass)obj)->core_class.class_name,
 			XrmQuarkToString(trait)));
 
@@ -204,9 +204,9 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 		    _traits[i].num += NUM_TRAITS;
 		    if (_traits[i].traits) {
 		    	_traits[i].traits = (_XmTraitRec *) XtRealloc(
-			(XtPointer)_traits[i].traits,
+			(char *)_traits[i].traits,
 			sizeof(_XmTraitRec) * _traits[i].num);
-			XdbDebug(__FILE__, NULL,
+			_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: _traits[%d].traits = %p,"
 				" size %d = %d * %d\n",
 				i, _traits[i].traits,
@@ -216,7 +216,7 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 		    } else {
 		    	_traits[i].traits = (_XmTraitRec *) XtCalloc(
 				_traits[i].num, sizeof(_XmTraitRec));
-			XdbDebug(__FILE__, NULL,
+			_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: _traits[%d].traits = %p,"
 				" size %d = %d * %d\n",
 				i, _traits[i].traits,
@@ -235,7 +235,7 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 			 * Code for supporting this is in XmeTraitGet */
 			_traits[i].traits[j].traitrec = rec;
 
-			XdbDebug(__FILE__, NULL,
+			_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: overwrite _traits[%d]."
 				"traits[%d].traitrec\n",
 				i, j);
@@ -248,9 +248,9 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 		    _traits[i].num += NUM_TRAITS;
 		    if (_traits[i].traits) {
 			_traits[i].traits = (_XmTraitRec *) XtRealloc(
-			(XtPointer)_traits[i].traits,
+			(char *)_traits[i].traits,
 			sizeof(_XmTraitRec) * _traits[i].num);
-			XdbDebug(__FILE__, NULL,
+			_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: _traits[%d].traits = %p,"
 				" size %d = %d * %d\n",
 				i, _traits[i].traits,
@@ -260,7 +260,7 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 		    } else {
 			_traits[i].traits = (_XmTraitRec *) XtCalloc(
 				_traits[i].num, sizeof(_XmTraitRec));
-			XdbDebug(__FILE__, NULL,
+			_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: _traits[%d].traits = %p,"
 				" size %d = %d * %d\n",
 				i, _traits[i].traits,
@@ -275,11 +275,11 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 		_traits[i].traits[j].traitrec = rec;
 		_traits[i].traits[j+1].trait = NULLQUARK;
 
-		XdbDebug(__FILE__, NULL,
+		_LtDebug(__FILE__, NULL,
 			"XmeTraitSet: write _traits[%d]."
 			"traits[%d].traitrec\n",
 			i, j);
-		XdbDebug(__FILE__, NULL,
+		_LtDebug(__FILE__, NULL,
 			"XmeTraitSet: write _traits[%d]."
 			"traits[%d].traitrec\n",
 			i, j+1);
@@ -294,12 +294,12 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 		_max_traits += NUM_WIDGET_CLASSES;
 		if (_traits) {
 		    _traits = (struct _XmTraitWidgetList *)
-			XtRealloc((XtPointer)_traits,
+			XtRealloc((char *)_traits,
 			_max_traits * sizeof(struct _XmTraitWidgetList));
 		} else {
 		    _traits = (struct _XmTraitWidgetList *) XtCalloc(
 			_max_traits, sizeof(struct _XmTraitWidgetList));
-		    XdbDebug(__FILE__, NULL,
+		    _LtDebug(__FILE__, NULL,
 			"XmeTraitSet: _traits = %p, size %d = %d * %d\n",
 			_traits,
 			_max_traits * sizeof(struct _XmTraitWidgetList),
@@ -308,14 +308,14 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 		}
 	}
 
-	XdbDebug(__FILE__, NULL, "XmeTraitSet: set _traits[%d]\n", i);
+	_LtDebug(__FILE__, NULL, "XmeTraitSet: set _traits[%d]\n", i);
 
-	_traits[i].wc = obj;
+	_traits[i].wc = (WidgetClass)obj;
 	_traits[i].num = 0;
 	_traits[i].traits = NULL;
 	_num_traits++;
 
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "Recursive Call : ")); /* no \n */
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "Recursive Call : ")); /* no \n */
 
 	return XmeTraitSet(obj, trait, rec);	/* Recursive call */
 }
@@ -324,11 +324,11 @@ extern void
 _XmInitTraits(void)
 {
 	if (XmQTaccessTextual) {
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmInitTraits() 2nd time\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmInitTraits() 2nd time\n"));
 	    return;
 	}
 
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmInitTraits()\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmInitTraits()\n"));
 
 	XmQTaccessTextual = XrmStringToQuark("XmQTaccessTextual");
 	XmQTactivatable = XrmStringToQuark("XmQTactivatable");
