@@ -1,9 +1,9 @@
 /**
  *
- * $Id: DragBS.c,v 1.31 2000/10/04 11:53:28 amai Exp $
+ * $Id: DragBS.c,v 1.40 2001/07/27 18:51:55 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DragBS.c,v 1.31 2000/10/04 11:53:28 amai Exp $";
+static const char rcsid[] = "$Id: DragBS.c,v 1.40 2001/07/27 18:51:55 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -58,6 +58,12 @@ static const char rcsid[] = "$Id: DragBS.c,v 1.31 2000/10/04 11:53:28 amai Exp $
  * have access to the X server.
  */
 
+/* amai: Hmm, well for now it's just for convenience to help on debugging.
+ * it used to be 100000L 
+ */
+#define PROP_LENGTH 200000L
+
+
 /*
  * these are used for protected sections
  */
@@ -78,6 +84,7 @@ static XContext displayToDW = None;
 static XContext displayToAtoms = None;
 static XContext displayToTargets = None;
 
+
 /*
  * basic atoms that must be agreed on
  */
@@ -130,6 +137,7 @@ static char *motifAtoms[] =
     _XA_XM_TEXT_I_S_PROP
 };
 
+
 static int
 DWError(Display *display, XErrorEvent *event)
 {
@@ -138,6 +146,7 @@ DWError(Display *display, XErrorEvent *event)
     return 0;
 }
 
+
 /*
  * create the drag window
  */
@@ -148,7 +157,7 @@ create_drag_window(Display *display)
     XSetWindowAttributes attr;
 
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:create_drag_window(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:create_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     attr.override_redirect = True;
@@ -165,6 +174,7 @@ create_drag_window(Display *display)
     return win;
 }
 
+
 /*
  * see if the drag window property can be found on the root window
  */
@@ -179,7 +189,7 @@ read_drag_window(Display *display)
     Window win = None;
 
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_drag_window(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     old_handler = XSetErrorHandler(DWError);
@@ -189,14 +199,15 @@ read_drag_window(Display *display)
     mw = XmInternAtom(display, _XA_MOTIF_DRAG_WINDOW, False);
 
     if (XGetWindowProperty(display, DefaultRootWindow(display),
-			   mw, 0L, 100000L,
+			   mw, 0L, PROP_LENGTH,
 			   False, AnyPropertyType,
 			   &atype, &aformat, &nitems, &bafter, &prop)
 	== Success && atype == XA_WINDOW && aformat == 32 && nitems == 1)
     {
 	win = *((Window *)prop);
     }
-
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - bafter=%i\n",
+		      __FILE__, __LINE__, bafter));
     if (prop)
     {
 	XFree((char *)prop);
@@ -206,18 +217,19 @@ read_drag_window(Display *display)
 
     if (error_flag)
     {
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - None\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - None\n",
 		      __FILE__, __LINE__));
 
 	return None;
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - %p\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_drag_window(%d) - %p\n",
 		      __FILE__, __LINE__, win));
 
     return win;
 }
 
+
 /*
  * set the drag window property on the root window
  */
@@ -226,7 +238,7 @@ write_drag_window(Display *display, Window *win)
 {
     Atom mw;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:write_drag_window(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:write_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     mw = XmInternAtom(display, _XA_MOTIF_DRAG_WINDOW, False);
@@ -235,6 +247,7 @@ write_drag_window(Display *display, Window *win)
 		    XA_WINDOW, 32, PropModeReplace, (unsigned char *)win, 1);
 }
 
+
 /*
  * lookup (program local) the value of the drag window
  */
@@ -243,7 +256,7 @@ get_drag_window(Display *display)
 {
     Window win;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_drag_window(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToDW == None)
@@ -254,25 +267,26 @@ get_drag_window(Display *display)
     if (XFindContext(display, DefaultRootWindow(display),
 		     displayToDW, (XPointer *)&win) == XCSUCCESS)
     {
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_drag_window(%d) - %p\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_drag_window(%d) - %p\n",
 		      __FILE__, __LINE__, win));
 
 	return win;
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_drag_window(%d) - None\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_drag_window(%d) - None\n",
 		      __FILE__, __LINE__));
 
     return None;
 }
 
+
 /*
  * cache (program local) the value of the drag window
  */
 static void
 set_drag_window(Display *display, Window win)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:set_drag_window(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:set_drag_window(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToDW == None)
@@ -288,16 +302,17 @@ set_drag_window(Display *display, Window win)
     }
 
     XSaveContext(display, DefaultRootWindow(display),
-		 displayToDW, (_Xconst char *)win);
+		 displayToDW, (XPointer)win);
 }
 
+
 /*
  * catch window errors when fetching or setting the DRAG_WINDOW properties
  */
 static int
 protect_handler(Display *display, XErrorEvent *event)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:protect_handler(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:protect_handler(%d)\n",
 		      __FILE__, __LINE__));
 
     if (event->error_code == BadWindow &&
@@ -317,13 +332,14 @@ protect_handler(Display *display, XErrorEvent *event)
     return (*oldErrorHandler) (display, event);
 }
 
+
 /*
  * begin catching window errors
  */
 static void
 begin_protection(Display *display, Window win)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:begin_protection(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:begin_protection(%d)\n",
 		      __FILE__, __LINE__));
 
     bad_window = False;
@@ -335,13 +351,14 @@ begin_protection(Display *display, Window win)
     errorWindow = win;
 }
 
+
 /*
  * end catching window errors
  */
 static void
 end_protection(Display *display)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:end_protection(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:end_protection(%d)\n",
 		      __FILE__, __LINE__));
 
     XSync(display, False);
@@ -351,17 +368,19 @@ end_protection(Display *display)
     oldErrorHandler = NULL;
 }
 
+
 /*
  * read from a drag buffer (sort of)
+ * probably for Motif BC (binary compatibility?!)
  */
-int
+extern int
 _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
 		  char *retbuf, int bufsize)
 {
     int rsize, eaten;
     int size;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmReadDragBuffer(%d) - read_string %s size %i\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmReadDragBuffer(%d) - read_string %s size %i\n",
 		      __FILE__, __LINE__,
 		      read_string ? "True" : "False",
 		      bufsize));
@@ -370,13 +389,20 @@ _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
     {
 	rsize = bmgr->name_size;
 	eaten = bmgr->name_start - bmgr->names;
-	if (rsize <= eaten)
-	{
-		size = eaten - rsize;
-		if (size > bufsize)
-			size = bufsize;
-	} else
-		size = bufsize;
+
+	if (eaten>rsize) {
+	  /* amai: in my understanding this is a major problem and
+	     should never happen */
+	  _XmWarning(NULL, "%s(%i): eaten=%i > rsize=%i\n",
+	             __FILE__, __LINE__, eaten, rsize);
+          /* abort(); */
+          size=0;
+	}
+	else {
+	   size = rsize-eaten;
+  	   if (size > bufsize)
+              size = bufsize;
+        }
 	memcpy(retbuf, bmgr->name_start, size);
 	bmgr->name_start += size;
 	return size;
@@ -384,30 +410,41 @@ _XmReadDragBuffer(XmDndBufMgr bmgr, Boolean read_string,
     else
     {
 	rsize = bmgr->atom_size;
-	eaten = bmgr->atom_start - bmgr->atoms;
-	if (rsize <= eaten)
-	{
-		size = eaten - rsize;
-		if (size > bufsize)
-			size = bufsize;
-	} else
-		size = bufsize;
+	eaten = (int)(bmgr->atom_start - bmgr->atoms);
+
+	if (eaten>rsize) {
+	  /* amai: in my understanding this is a major problem and
+	     should never happen */
+	  _XmWarning(NULL, "%s(%i): eaten=%i > rsize=%i\n",
+	             __FILE__, __LINE__, eaten, rsize);
+          /* abort(); */
+          size=0;
+	}
+	else {
+	   size = rsize-eaten;
+	   if (size > bufsize)
+              size = bufsize;
+        }
+        /* fprintf(stderr, "rsize=%i, eaten=%i, bufsize=%i, size=%i\n",
+                rsize, eaten, bufsize, size); */
 	memcpy(retbuf, bmgr->atom_start, size);
 	bmgr->atom_start += size;
 	return size;
     }
 }
 
+
 /*
  * write to a drag buffer (sort of)
+ * probably for Motif BC (binary compatibility?!)
  */
-int
+extern int
 _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
 		   char *data, int size)
 {
     int increase_needed;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmWriteDragBuffer(%d) write_string %s size %i\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmWriteDragBuffer(%d) write_string %s size %i\n",
 		      __FILE__, __LINE__,
 		      write_string ? "True" : "False",
 		      size));
@@ -465,6 +502,7 @@ _XmWriteDragBuffer(XmDndBufMgr bmgr, Boolean write_string,
     }
 }
 
+
 /*
  * get the ATOM_PAIRS.  They may or may not already exist
  */
@@ -483,7 +521,7 @@ read_atom_pairs(Display *display)
     unsigned long nitems, bafter;
     unsigned char *prop = NULL;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d)\n",
 		      __FILE__, __LINE__));
 
     pa = XmInternAtom(display, _XA_MOTIF_DRAG_ATOM_PAIRS, False);
@@ -492,19 +530,18 @@ read_atom_pairs(Display *display)
 
     begin_protection(display, win);
 
-    if (XGetWindowProperty(display, win, pa, 0L, 100000L,
+    if (XGetWindowProperty(display, win, pa, 0L, PROP_LENGTH,
 			   False, pa,
 			   &atype, &aformat, &nitems, &bafter,
 			   (unsigned char **)&pairs) == Success &&
 	nitems >= 8 && pairs != NULL)
     {
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - got property\n",
-		      __FILE__, __LINE__));
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - got property, bafter=%i\n",
+		      __FILE__, __LINE__, bafter));
 
 	gotit = True;
 	prop = (unsigned char *)pairs;
     }
-
     end_protection(display);
 
     if (bad_window)
@@ -525,7 +562,7 @@ read_atom_pairs(Display *display)
 	    XFree((char *)prop);
 	}
 
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - did not get property\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - did not get property\n",
 		      __FILE__, __LINE__));
 
 	return False;
@@ -543,7 +580,7 @@ read_atom_pairs(Display *display)
 	SWAP4BYTES(pairs->data_size);
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - %i pairs\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - %i pairs\n",
 		      __FILE__, __LINE__,
 		      pairs->num_pairs));
 
@@ -569,7 +606,7 @@ read_atom_pairs(Display *display)
 
 	    _XmReadDragBuffer(&bmgr, True, buf, pair.namelen);
 
-	    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - intern %s\n",
+	    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - intern %s\n",
 		      __FILE__, __LINE__,
 		      buf));
 
@@ -585,6 +622,7 @@ read_atom_pairs(Display *display)
     return gotit;
 }
 
+
 /*
  * if the ATOM_PAIRS didn't exist, put them on the drag window
  */
@@ -600,7 +638,7 @@ write_atom_pairs(Display *display)
     int i;
     Window win;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:write_atom_pairs(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:write_atom_pairs(%d)\n",
 		      __FILE__, __LINE__));
 
     pair_rec.byte_order = _XmByteOrder();
@@ -668,6 +706,7 @@ write_atom_pairs(Display *display)
     }
 }
 
+
 /*
  * fetch the cached atoms table
  */
@@ -676,7 +715,7 @@ get_atoms_table(Display *display)
 {
     XmDndAtomsTable tbl = NULL;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_atoms_table(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToAtoms == (XContext)0)
@@ -693,6 +732,7 @@ get_atoms_table(Display *display)
     return tbl;
 }
 
+
 /*
  * cache the atoms table
  */
@@ -701,7 +741,7 @@ set_atoms_table(Display *display, XmDndAtomsTable table)
 {
     XmDndAtomsTable atoms;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:set_atoms_table(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:set_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToAtoms == (XContext)0)
@@ -720,15 +760,16 @@ set_atoms_table(Display *display, XmDndAtomsTable table)
     }
 
     XSaveContext(display, DefaultRootWindow(display),
-		 displayToAtoms, (_Xconst char *)table);
+		 displayToAtoms, (XPointer)table);
 }
 
+
 static XmDndAtomsTable
 create_default_atoms_table(Display *display)
 {
     XmDndAtomsTable tbl;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:create_default_atoms_table(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:create_default_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     tbl = (XmDndAtomsTable) XtMalloc(sizeof(XmDndAtomsTableRec));
@@ -745,6 +786,7 @@ create_default_atoms_table(Display *display)
     return tbl;
 }
 
+
 static Boolean
 read_atoms_table(Display *display, XmDndAtomsTable tbl)
 {
@@ -757,7 +799,7 @@ read_atoms_table(Display *display, XmDndAtomsTable tbl)
     XmDndAtomsTableEntryRec atom_ent;
     XmDndBufMgrRec bmgr;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_atoms_table(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     da = XmInternAtom(display, _XA_MOTIF_DRAG_ATOMS, False);
@@ -766,12 +808,14 @@ read_atoms_table(Display *display, XmDndAtomsTable tbl)
 
     begin_protection(display, win);
 
-    if (XGetWindowProperty(display, win, da, 0L, 100000L,
+    if (XGetWindowProperty(display, win, da, 0L, PROP_LENGTH,
 			   False, da,
 			   &atype, &aformat, &nitems, &bafter,
 			   (unsigned char **)&atoms) == Success &&
 	nitems >= 8)
     {
+        DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_atom_pairs(%d) - got property, bafter=%i\n",
+		      __FILE__, __LINE__, bafter));    
 	got_it = True;
     }
 
@@ -848,6 +892,7 @@ read_atoms_table(Display *display, XmDndAtomsTable tbl)
     return True;
 }
 
+
 /*
  * write the atoms table out to the drag window
  */
@@ -861,7 +906,7 @@ write_atoms_table(Display *display, XmDndAtomsTable tbl)
     int i;
     Window win;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:write_atoms_table(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:write_atoms_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (tbl == NULL)
@@ -916,6 +961,7 @@ write_atoms_table(Display *display, XmDndAtomsTable tbl)
     }
 }
 
+
 /*
  * fetch the cached atoms table
  */
@@ -924,7 +970,7 @@ get_targets_table(Display *display)
 {
     XmDndTargetsTable targets = NULL;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_targets_table(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_targets_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (displayToTargets == (XContext)0)
@@ -935,18 +981,19 @@ get_targets_table(Display *display)
     if (XFindContext(display, DefaultRootWindow(display),
 		     displayToTargets, (XPointer *)&targets) != XCSUCCESS)
     {
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_targets_table(%d) - NULL\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_targets_table(%d) - NULL\n",
 		      __FILE__, __LINE__));
 
 	return NULL;
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:get_targets_table(%d) - %p\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:get_targets_table(%d) - %p\n",
 		      __FILE__, __LINE__, targets));
 
     return targets;
 }
 
+
 /*
  * cache the atoms table
  */
@@ -955,7 +1002,7 @@ set_targets_table(Display *display, XmDndTargetsTable table)
 {
     XmDndTargetsTable targets;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:set_targets_table(%d) - %p\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:set_targets_table(%d) - %p\n",
 		      __FILE__, __LINE__, table));
 
     if (displayToTargets == (XContext)0)
@@ -977,9 +1024,10 @@ set_targets_table(Display *display, XmDndTargetsTable table)
     }
 
     XSaveContext(display, DefaultRootWindow(display),
-		 displayToTargets, (_Xconst char *)table);
+		 displayToTargets, (XPointer)table);
 }
 
+
 /*
  * create the default target table
  */
@@ -988,7 +1036,7 @@ create_default_targets_table(Display *display)
 {
     XmDndTargetsTable tbl;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:create_default_targets_table(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:create_default_targets_table(%d)\n",
 		      __FILE__, __LINE__));
 
     tbl = (XmDndTargetsTable)XtMalloc(sizeof(XmDndTargetsTableRec));
@@ -1009,6 +1057,7 @@ create_default_targets_table(Display *display)
     return tbl;
 }
 
+
 static Boolean
 read_targets_table(Display *display, XmDndTargetsTable tbl)
 {
@@ -1021,7 +1070,7 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
     XmDndBufMgrRec bmgr;
     CARD16 nents;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_targets_table(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_targets_table(%d)\n",
 		      __FILE__, __LINE__));
 
     ta = XmInternAtom(display, _XA_MOTIF_DRAG_TARGETS, False);
@@ -1030,12 +1079,15 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
 
     begin_protection(display, win);
 
-    if (XGetWindowProperty(display, win, ta, 0L, 100000L,
+    if (XGetWindowProperty(display, win, ta, 0L, PROP_LENGTH,
 			   False, ta,
 			   &atype, &aformat, &nitems, &bafter,
 			   (unsigned char **)&targets) == Success &&
 	nitems >= 8)
     {
+        DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_targets_table(%d) bafter=%i\n",
+		      __FILE__, __LINE__, bafter));
+
 	got_it = True;
     }
 
@@ -1054,7 +1106,7 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
 	    XFree((XPointer)targets);
 	}
 
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_targets_table(%d) - False\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_targets_table(%d) - False\n",
 		      __FILE__, __LINE__));
 
 	return False;
@@ -1126,7 +1178,7 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
 	}
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:read_targets_table(%d) - True %p\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:read_targets_table(%d) - True %p\n",
 		      __FILE__, __LINE__, tbl));
 
     if (targets)
@@ -1136,6 +1188,7 @@ read_targets_table(Display *display, XmDndTargetsTable tbl)
     return True;
 }
 
+
 static void
 write_targets_table(Display *display, XmDndTargetsTable tbl)
 {
@@ -1147,7 +1200,7 @@ write_targets_table(Display *display, XmDndTargetsTable tbl)
     Window win;
     CARD16 nents;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:write_targets_table(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:write_targets_table(%d)\n",
 		      __FILE__, __LINE__));
 
     if (tbl == NULL)
@@ -1205,18 +1258,19 @@ write_targets_table(Display *display, XmDndTargetsTable tbl)
     }
 }
 
+
 /*
  * fetch and/or set the ATOM_PAIRS.  This is triggered at least once
  * by the first call to XmInternAtom().
  */
-void
+extern void
 _XmInitAtomPairs(Display *display)
 {
     Window win;
     char *dstr;
     Display *d;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmInitAtomPairs(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmInitAtomPairs(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((win = read_drag_window(display)) == None)
@@ -1264,10 +1318,11 @@ _XmInitAtomPairs(Display *display)
     }
 }
 
+
 /*
  * intialize the DRAG_TARGETS table, and the DRAG_ATOMS table
  */
-void
+extern void
 _XmInitTargetsTable(Display *display)
 {
     Window win;
@@ -1276,7 +1331,7 @@ _XmInitTargetsTable(Display *display)
     XmDndAtomsTable atoms;
     XmDndTargetsTable targets;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmInitTargetsTable(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmInitTargetsTable(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((win = read_drag_window(display)) == None)
@@ -1350,16 +1405,17 @@ _XmInitTargetsTable(Display *display)
     }
 }
 
+
 /*
  * called from DropSMgr's CreateInfo method.
  */
-Cardinal
+extern Cardinal
 _XmIndexToTargets(Widget shell, Cardinal t_index, Atom **targetsRtn)
 {
     Display *dpy = XtDisplay(shell);
     XmDndTargetsTable targets;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmIndexToTargets(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmIndexToTargets(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((targets = get_targets_table(dpy)) == NULL)
@@ -1394,6 +1450,7 @@ _XmIndexToTargets(Widget shell, Cardinal t_index, Atom **targetsRtn)
     return targets->entries[t_index].num_targets;
 }
 
+
 /*
  * minimize duplicates in the targets table by sorting compound entries
  */
@@ -1402,7 +1459,7 @@ acompare(XmConst void *a, XmConst void *b)
 {
     Atom *pa = (Atom *)a, *pb = (Atom *)b;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:acompare(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:acompare(%d)\n",
 		      __FILE__, __LINE__));
 
     return *pa - *pb;
@@ -1417,10 +1474,10 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
 {
     Display *dpy = XtDisplay(shell);
     XmDndTargetsTable targets;
-    int i;
+    Cardinal i;
     Atom *atoms;
 
-    DEBUGOUT(XdbDebug(__FILE__, shell,
+    DEBUGOUT(_LtDebug(__FILE__, shell,
 		      "%s:_XmTargetsToIndex(%d) - %p 0x%x targets %p\n", 
 		      __FILE__, __LINE__,
 		      tlist,
@@ -1441,7 +1498,7 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
 
 	targets = get_targets_table(dpy);
     }
-    DEBUGOUT(XdbDebug(__FILE__, shell,
+    DEBUGOUT(_LtDebug(__FILE__, shell,
 		      "%s:_XmTargetsToIndex(%d) - targets->num_entries %i\n", 
 		      __FILE__, __LINE__,
 		      targets->num_entries
@@ -1534,10 +1591,11 @@ _XmTargetsToIndex(Widget shell, Atom *tlist, Cardinal numTargets)
     return i;
 }
 
+
 /*
  * called when a drag starts, to allocate an Atom for the DragContext
  */
-Atom
+extern Atom
 _XmAllocMotifAtom(Widget shell, Time time)
 {
     XmDndAtomsTable atoms;
@@ -1546,9 +1604,9 @@ _XmAllocMotifAtom(Widget shell, Time time)
     int i;
     char buf[32];
 
-    DEBUGOUT(XdbDebug(__FILE__, shell, "%s:_XmAllocMotifAtom(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, shell, "%s:_XmAllocMotifAtom(%d)\n",
 		      __FILE__, __LINE__));
-    DEBUGOUT(XdbDebug("DRAGSOURCE", shell, "%s:_XmAllocMotifAtom(%d)\n",
+    DEBUGOUT(_LtDebug("DRAGSOURCE", shell, "%s:_XmAllocMotifAtom(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((atoms = get_atoms_table(dpy)) == NULL)
@@ -1608,28 +1666,29 @@ _XmAllocMotifAtom(Widget shell, Time time)
 
     XFlush(dpy);
 
-    if (XdbInDebug("DRAGSOURCE", shell))
+    if (_LtDebugInDebug("DRAGSOURCE", shell))
     {
     char *AtomName = XGetAtomName(dpy, alloc);
 
-	DEBUGOUT(XdbDebug0("DRAGSOURCE", shell, "\t%s - 0x%x\n", AtomName, time));
+	DEBUGOUT(_LtDebug0("DRAGSOURCE", shell, "\t%s - 0x%x\n", AtomName, time));
     	XFree(AtomName);
     }
 
     return alloc;
 }
 
+
 /*
  * Free the atom.
  */
-void
+extern void
 _XmFreeMotifAtom(Widget shell, Atom atom)
 {
     XmDndAtomsTable atoms;
     Display *dpy = XtDisplay(shell);
     int i;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmFreeMotifAtom(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmFreeMotifAtom(%d)\n",
 		      __FILE__, __LINE__));
 
     if (atom == None)
@@ -1677,16 +1736,17 @@ _XmFreeMotifAtom(Widget shell, Atom atom)
     XFlush(dpy);
 }
 
+
 /*
  * I understand what it does, by why would you want to do it?
  */
-void
+extern void
 _XmDestroyMotifWindow(Display *dpy)
 {
     Atom dw;
     Window win;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmDestroyMotifWindow(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmDestroyMotifWindow(%d)\n",
 		      __FILE__, __LINE__));
 
     win = read_drag_window(dpy);
@@ -1702,6 +1762,7 @@ _XmDestroyMotifWindow(Display *dpy)
     XDestroyWindow(dpy, win);
 }
 
+
 /*
  * get the drag proxy window.  XmDisplay uses this to initialize
  * the proxy instance variable.
@@ -1715,7 +1776,7 @@ _XmGetDragProxyWindow(Display *display)
     unsigned long nitems, bafter;
     unsigned char *prop = NULL;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d)\n",
 		      __FILE__, __LINE__));
 
     if ((win = read_drag_window(display)) == None)
@@ -1725,25 +1786,27 @@ _XmGetDragProxyWindow(Display *display)
 
     pw = XmInternAtom(display, _XA_MOTIF_DRAG_PROXY_WINDOW, False);
 
-    if (XGetWindowProperty(display, win, pw, 0L, 100000L,
+    if (XGetWindowProperty(display, win, pw, 0L, PROP_LENGTH,
 			   False, AnyPropertyType,
 			   &atype, &aformat, &nitems, &bafter, &prop)
 	== Success && atype == XA_WINDOW && aformat == 32 && nitems == 1)
     {
+        DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d) - bafter=%i\n",
+		      __FILE__, __LINE__, bafter));
 	win = *((Window *)prop);
     }
-
     if (prop)
     {
 	XFree((XPointer)prop);
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d) - %p\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetDragProxyWindow(%d) - %p\n",
 		      __FILE__, __LINE__, win));
 
     return win;
 }
 
+
 /*
  * get the drag receiver info property from the target
  *
@@ -1751,7 +1814,7 @@ _XmGetDragProxyWindow(Display *display)
  * application's window.  There's a lot more there than what Daniel
  * talks about.  Must be due to PREREGISTER, yes?
  */
-Boolean
+extern Boolean
 _XmGetDragReceiverInfo(Display *display, Window win, XmDragReceiverInfo ri)
 {
     Atom dri;
@@ -1762,18 +1825,18 @@ _XmGetDragReceiverInfo(Display *display, Window win, XmDragReceiverInfo ri)
     unsigned long bafter, length;
     Window root;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmGetDragReceiverInfo(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmGetDragReceiverInfo(%d)\n",
 		      __FILE__, __LINE__));
-    DEBUGOUT(XdbDebug0("DRAGSOURCE", NULL, "%s:_XmGetDragReceiverInfo(%d) - %p\n",
+    DEBUGOUT(_LtDebug0("DRAGSOURCE", NULL, "%s:_XmGetDragReceiverInfo(%d) - %p\n",
 		      __FILE__, __LINE__, win));
 
     dri = XmInternAtom(display, _XA_MOTIF_DRAG_RECEIVER_INFO, False);
 
-    if (XGetWindowProperty(display, win, dri, 0L, 100000L, False,
+    if (XGetWindowProperty(display, win, dri, 0L, PROP_LENGTH, False,
 			   dri, &type, &format, &length, &bafter,
 			   (unsigned char **)&receiver) != Success)
     {
-	DEBUGOUT(XdbDebug0("DRAGSOURCE", NULL, "%s:_XmGetDragReceiverInfo(%d) - getting prop failed\n",
+	DEBUGOUT(_LtDebug0("DRAGSOURCE", NULL, "%s:_XmGetDragReceiverInfo(%d) - getting prop failed\n",
 		      __FILE__, __LINE__));
 	return False;
     }
@@ -1782,7 +1845,7 @@ _XmGetDragReceiverInfo(Display *display, Window win, XmDragReceiverInfo ri)
     {
 	ri->dragProtocolStyle = XmDRAG_NONE;
 	XFree((char *)receiver);
-	DEBUGOUT(XdbDebug0("DRAGSOURCE", NULL, "%s:_XmGetDragReceiverInfo(%d) - None available\n",
+	DEBUGOUT(_LtDebug0("DRAGSOURCE", NULL, "%s:_XmGetDragReceiverInfo(%d) - None available\n",
 		      __FILE__, __LINE__));
 	return False;
     }
@@ -1823,18 +1886,20 @@ _XmGetDragReceiverInfo(Display *display, Window win, XmDragReceiverInfo ri)
     return True;
 }
 
-void
+
+extern void
 _XmSetDragReceiverInfo(Widget w, Widget widget)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmSetDragReceiverInfo(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmSetDragReceiverInfo(%d)\n",
 		      __FILE__, __LINE__));
 
 }
 
-void
+
+extern void
 _XmClearDragReceiverInfo(Widget shell)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmClearDragReceiverInfo(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmClearDragReceiverInfo(%d)\n",
 		      __FILE__, __LINE__));
 
 }
@@ -1842,10 +1907,10 @@ _XmClearDragReceiverInfo(Widget shell)
 /*
  * free up the dropsite info
  */
-void
+extern void
 _XmFreeDragReceiverInfo(XmShellDropSiteInfo di)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmFreeDragReceiverInfo(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmFreeDragReceiverInfo(%d)\n",
 		      __FILE__, __LINE__));
 
     if (di)
@@ -1859,13 +1924,14 @@ _XmFreeDragReceiverInfo(XmShellDropSiteInfo di)
     }
 }
 
-unsigned char
+
+extern unsigned char
 _XmByteOrder(void)
 {
     static unsigned char byte_order = 0;
 
     /*
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmByteOrder(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmByteOrder(%d)\n",
 		      __FILE__, __LINE__));
     */
 
