@@ -1,9 +1,9 @@
 /*
  *
- * $Id: DropSMgr.c,v 1.31 2000/09/22 20:35:11 amai Exp $
+ * $Id: DropSMgr.c,v 1.36 2001/07/27 18:51:55 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DropSMgr.c,v 1.31 2000/09/22 20:35:11 amai Exp $";
+static const char rcsid[] = "$Id: DropSMgr.c,v 1.36 2001/07/27 18:51:55 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -42,98 +42,70 @@ static const char rcsid[] = "$Id: DropSMgr.c,v 1.31 2000/09/22 20:35:11 amai Exp
 #include <XmI/DebugUtil.h>
 
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
-
 #define HASH_BUCKETS	127
 
+
 /* Forward Declarations */
 
 static void __XmDSMCreateInfo(XmDropSiteManagerObject dsm,
 			      Widget widget,
 			      ArgList args,
 			      Cardinal num_args);
-
 static void __XmDSMDestroyInfo(XmDropSiteManagerObject dsm,
 			       Widget widget);
-
 static void __XmDSMStartUpdate(XmDropSiteManagerObject dsm,
 			       Widget widget);
-
 static void __XmDSMRetrieveInfo(XmDropSiteManagerObject dsm,
 				Widget widget,
 				ArgList args,
 				Cardinal num_args);
-
 static void __XmDSMUpdateInfo(XmDropSiteManagerObject dsm,
 			      Widget widget,
 			      ArgList args,
 			      Cardinal num_args);
-
 static void __XmDSMEndUpdate(XmDropSiteManagerObject dsm,
 			     Widget widget);
-
 static void __XmDSMUpdateDSM(XmDropSiteManagerObject dsm,
 			     XtPointer clientData,
 			     XtPointer callData);
-
 static void __XmDSMProcessMotion(XmDropSiteManagerObject dsm,
 				 XtPointer clientData,
 				 XtPointer callData);
-
 static void __XmDSMProcessDrop(XmDropSiteManagerObject dsm,
 			       XtPointer clientData,
 			       XtPointer callData);
-
 static void __XmDSMOperationChanged(XmDropSiteManagerObject dsm,
 				    XtPointer clientData,
-				    XtPointer callData);
-
+ 			    XtPointer callData);
 static void __XmDSMChangeRoot(XmDropSiteManagerObject dsm,
 			      XtPointer clientData,
 			      XtPointer callData);
-
 static void __XmDSMInsertInfo(XmDropSiteManagerObject dsm,
 			      XtPointer clientData,
 			      XtPointer callData);
-
 static void __XmDSMRemoveInfo(XmDropSiteManagerObject dsm,
 			      XtPointer info);
-
 static void __XmDSMSyncTree(XmDropSiteManagerObject dsm,
 			    Widget shell);
-
 static int __XmDSMGetTree(XmDropSiteManagerObject dsm,
 			  Widget shell,
 			  XtPointer dataPtr);
-
 static void __XmDSMCreateDSInfoTable(XmDropSiteManagerObject dsm);
-
 static void __XmDSMDestroyDSInfoTable(XmDropSiteManagerObject dsm);
-
 static void __XmDSMRegisterInfo(XmDropSiteManagerObject dsm,
 				Widget widget,
 				XtPointer info);
-
 static XtPointer __XmDSMWidgetToInfo(XmDropSiteManagerObject dsm,
 				     Widget widget);
-
 static void __XmDSMUnregisterInfo(XmDropSiteManagerObject dsm,
 				  XtPointer info);
-
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass widget_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void destroy(Widget w);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
 static void updateTree(Widget w, XtPointer cd, XtPointer cbs);
 
 #define Offset(f)	XtOffsetOf(XmDropSiteManagerRec, dropManager.f)
@@ -157,7 +129,7 @@ static XtResource resources[] =
 };
 #undef Offset
 
-/* *INDENT-OFF* */
+
 #if 0
 static XmBaseClassExtRec _XmDropSMgrObjectClassExtRec = {
     /* next_extension            */ NULL,
@@ -247,7 +219,6 @@ XmDropSiteManagerClassRec xmDropSiteManagerClassRec = {
 	/* extension        */  NULL
     }
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmDropSiteManagerObjectClass = (WidgetClass)(&xmDropSiteManagerClassRec);
@@ -259,19 +230,20 @@ WidgetClass xmDropSiteManagerObjectClass = (WidgetClass)(&xmDropSiteManagerClass
 static void
 class_initialize(void)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:class_initialize(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:class_initialize(%d)\n",
     	__FILE__, __LINE__));
 #if 0
     _XmDropSMgrObjectClassExtRec.record_type = XmQmotif;
 #endif
 }
 
+
 static void
 class_part_initialize(WidgetClass widget_class)
 {
     WidgetClass sc;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:class_part_initialize(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:class_part_initialize(%d)\n",
     	__FILE__, __LINE__));
     _XmFastSubclassInit(widget_class, XmDROP_SITE_MANAGER_BIT);
 
@@ -378,13 +350,14 @@ class_part_initialize(WidgetClass widget_class)
     }
 }
 
+
 static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
     XmDropSiteInfoRec hr;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -394,7 +367,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     DS_CurAnimate(new_w) = True;
 
@@ -437,10 +410,11 @@ initialize(Widget request, Widget new_w,
 
 }
 
+
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:destroy(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:destroy(%d)\n",
     	__FILE__, __LINE__));
     DSMDestroyTable((XmDropSiteManagerObject)w);
 
@@ -448,11 +422,12 @@ destroy(Widget w)
     _XmRegionDestroy(DS_NewAncestorClipRegion(w));
 }
 
+
 static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:set_values(%d) - %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -465,19 +440,20 @@ set_values(Widget old, Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     return True;
 }
 
+
 static void
 updateReceiverInfo(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:updateReceiverInfo(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:updateReceiverInfo(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(XdbDebug("DRAGSINK", w, "%s:updateReceiverInfo(%d) - %s\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", w, "%s:updateReceiverInfo(%d) - %s\n",
     	__FILE__, __LINE__,
-    	XdbEventType2String(ev->xany.type)));
+    	_LtDebugEventType2String(ev->xany.type)));
 #if 1
     /* rws 8 Feb 2000
        I have no idea if this belongs here or not, but it has to be
@@ -491,7 +467,7 @@ updateReceiverInfo(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
     Atom pa;
     Widget shell = w;
 
-	DEBUGOUT(XdbDebug("DND", shell, "%s:createShellInfoRec(%d)\n",
+	DEBUGOUT(_LtDebug("DND", shell, "%s:createShellInfoRec(%d)\n",
 	    __FILE__, __LINE__));
     	ri.byte_order = _XmByteOrder();
     	ri.protocol_version = DND_PROTOCOL_VERSION;
@@ -507,6 +483,7 @@ updateReceiverInfo(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 #endif
 }
 
+
 static void
 SwapMessageData(XmDndMessage *msg)
 {
@@ -542,7 +519,9 @@ SwapMessageData(XmDndMessage *msg)
     }
 }
 
-int
+
+/* for Motif BC ?! */
+extern int
 _XmMessageTypeToReason(BYTE reason)
 {
     switch (reason & DND_CLEAR_EVENT_TYPE)
@@ -582,7 +561,9 @@ _XmMessageTypeToReason(BYTE reason)
     }
 }
 
-void
+
+/* for Motif BC ? */
+extern void
 _XmICCEventToICCCallback(XmDndMessage *msg, XmDragDropCallbackStruct *cbs)
 {
     switch (msg->reason & DND_CLEAR_EVENT_TYPE)
@@ -642,15 +623,16 @@ _XmICCEventToICCCallback(XmDndMessage *msg, XmDragDropCallbackStruct *cbs)
     }
 }
 
+
 static void
 externalSourceHandler(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 {
-    DEBUGOUT(XdbDebug2(__FILE__, w, (Widget)cd, "%s:externalSourceHandler(%d)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)cd, "%s:externalSourceHandler(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(XdbDebug2("DRAGSINK", w, (Widget)cd, "%s:externalSourceHandler(%d)\n",
+    DEBUGOUT(_LtDebug2("DRAGSINK", w, (Widget)cd, "%s:externalSourceHandler(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(XdbDebug0("DRAGSINK", w, "\t%s\n",
-    	XdbEventType2String(ev->xany.type)));
+    DEBUGOUT(_LtDebug0("DRAGSINK", w, "\t%s\n",
+    	_LtDebugEventType2String(ev->xany.type)));
 
     switch (ev->xany.type)
     {
@@ -668,14 +650,14 @@ externalSourceHandler(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 	    XmDragTopLevelClientDataStruct TLCcbs;
 
 	    	SwapMessageData(msg);
-		DEBUGOUT(XdbDebug0("DRAGSINK", w, "\t%s from %s\n",
-		    XdbDragAndDropMessageType2String(msg->reason & DND_CLEAR_EVENT_TYPE),
+		DEBUGOUT(_LtDebug0("DRAGSINK", w, "\t%s from %s\n",
+		    _LtDebugDragAndDropMessageType2String(msg->reason & DND_CLEAR_EVENT_TYPE),
 		    msg->reason & ~DND_CLEAR_EVENT_TYPE ? "Receiver" : "Initiator"));
-		DEBUGOUT(XdbDebug0("DRAGSINK", w, "\tDS_CurDragContext %s %p\n",
+		DEBUGOUT(_LtDebug0("DRAGSINK", w, "\tDS_CurDragContext %s %p\n",
 		    DS_CurDragContext(dsm) ? XtName(DS_CurDragContext(dsm)) : "NULL", DS_CurDragContext(dsm)));
-		DEBUGOUT(XdbDebug0("DRAGSINK", w, "\tDisplay_ActiveDC %s %p\n",
+		DEBUGOUT(_LtDebug0("DRAGSINK", w, "\tDisplay_ActiveDC %s %p\n",
 		    Display_ActiveDC(disp) ? XtName(Display_ActiveDC(disp)) : "NULL", Display_ActiveDC(disp)));
-		DEBUGOUT(XdbDebug0("DRAGSINK", w, "\tXmGetDragContext %s %p\n",
+		DEBUGOUT(_LtDebug0("DRAGSINK", w, "\tXmGetDragContext %s %p\n",
 		    XmGetDragContext((Widget)dsm, msg->time) ? XtName(XmGetDragContext((Widget)dsm, msg->time)) : "NULL", XmGetDragContext((Widget)dsm, msg->time)));
 
 		DnDcbs.any.reason = _XmMessageTypeToReason(msg->reason);
@@ -695,15 +677,20 @@ externalSourceHandler(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 	    }
 	    else
 	    {
+	    /* rws 28 Mar 2001
+	       Normal situation
 	    char *AtomName;
 
 		AtomName = XGetAtomName(ev->xclient.display, ev->xclient.message_type);
 		_XmWarning(w, "Unexpected ClientMessaget, type >%s<\n    %s:externalSourceHandler(%d)", 
 		    AtomName, __FILE__, __LINE__);
 		XtFree(AtomName);
+	    */
 	    }
 	}
 	break;
+    /* rws 28 Mar 2001
+       Normal situation
     case SelectionClear:
 	{
 	char *AtomName;
@@ -714,15 +701,18 @@ externalSourceHandler(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 	    XtFree(AtomName);
 	}
 	break;
+    */
     default:
-    	_XmWarning(w, "Unexpected event >%s<\n    %s:externalSourceHandler(%d)", XdbEventType2String(ev->xany.type), __FILE__, __LINE__);
-    	;
+    	/*
+    	_XmWarning(w, "Unexpected event >%s<\n    %s:externalSourceHandler(%d)", _LtDebugEventType2String(ev->xany.type), __FILE__, __LINE__);
+    	*/
+    	break;
     }
 #if 0
     Widget dc, disp;
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "External drag event seen\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "External drag event seen\n"));
 
     disp = XmGetXmDisplay(XtDisplay(w));
 
@@ -738,6 +728,7 @@ externalSourceHandler(Widget w, XtPointer cd, XEvent *ev, Boolean *ctd)
 #endif
 }
 
+
 /*
  * this should be called with a shell widget.
  */
@@ -747,9 +738,9 @@ updateTree(Widget w, XtPointer cd, XtPointer cbs)
     Widget disp = XmGetXmDisplay(XtDisplay(w));
     XmTreeUpdateCallbackStruct *tucbs = (XmTreeUpdateCallbackStruct *) cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:updateTree(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:updateTree(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(XdbDebug("DRAGSINK", w, "%s:updateTree(%d)\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", w, "%s:updateTree(%d)\n",
     	__FILE__, __LINE__));
 
     if (Display_DragReceiverProtocolStyle(disp) == XmDRAG_NONE)
@@ -794,16 +785,18 @@ updateTree(Widget w, XtPointer cd, XtPointer cbs)
     }
 }
 
+
 static void
 destroyInfo(Widget w, XtPointer cd, XtPointer cbs)
 {
     Widget dsm = (Widget)cd;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:destroyInfo(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:destroyInfo(%d)\n",
     	__FILE__, __LINE__));
     DSMDestroyInfo((XmDropSiteManagerObject)dsm, w);
 }
 
+
 static XmDropSiteInfo
 createShellInfoRec(XmDropSiteManagerObject dsm, Widget shell)
 {
@@ -811,7 +804,7 @@ createShellInfoRec(XmDropSiteManagerObject dsm, Widget shell)
     XmDropSiteInfo dsi;
     XRectangle rect;
 
-    DEBUGOUT(XdbDebug(__FILE__, shell, "%s:createShellInfoRec(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, shell, "%s:createShellInfoRec(%d)\n",
     	__FILE__, __LINE__));
     dsi = (XmDropSiteInfo) XtCalloc(1, sizeof(XmDropSiteInfoRec));
 
@@ -839,10 +832,11 @@ createShellInfoRec(XmDropSiteManagerObject dsm, Widget shell)
     return dsi;
 }
 
+
 static void
 addChildToComposite(XmDropSiteInfo pi, XmDropSiteInfo ci, short pos)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:addChildToComposite(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:addChildToComposite(%d)\n",
     	__FILE__, __LINE__));
 
     if (pi == NULL || ci == NULL)
@@ -904,12 +898,13 @@ addChildToComposite(XmDropSiteInfo pi, XmDropSiteInfo ci, short pos)
     pi->leaf = False;
 }
 
+
 static void
 removeChildFromComposite(XmDropSiteInfo pi, XmDropSiteInfo dsi)
 {
     int i;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:removeChildFromComposite(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:removeChildFromComposite(%d)\n",
     	__FILE__, __LINE__));
 
     if (pi->dropSiteType != XmDROP_SITE_COMPOSITE)
@@ -940,10 +935,11 @@ removeChildFromComposite(XmDropSiteInfo pi, XmDropSiteInfo dsi)
     pi->numChildren--;
 }
 
+
 static void
 destroyInfoRec(XmDropSiteInfo dsi, Boolean thorough)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:destroyInfoRec(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:destroyInfoRec(%d)\n",
     	__FILE__, __LINE__));
 
     if (dsi->dropSiteType == XmDROP_SITE_COMPOSITE && thorough &&
@@ -963,6 +959,7 @@ destroyInfoRec(XmDropSiteInfo dsi, Boolean thorough)
     }
 }
 
+
 /*
  * create the per-widget information
  */
@@ -974,25 +971,26 @@ __XmDSMCreateInfo(XmDropSiteManagerObject object,
 {
     XmRegion r = _XmRegionCreate();
     XmDropSiteInfo hr;
-    int x, y, i;
+    int x, y;
+    Cardinal i;
     Window root;
     unsigned int width, height, border;
     XRectangle rect;
     Widget shell;
     XmDropSiteInfo info;
 
-    DEBUGOUT(XdbDebug2(__FILE__, (Widget)object, widget,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)object, widget,
 		      "%s:__XmDSMCreateInfo(%d) - %i args\n", 
 		      __FILE__, __LINE__,
 		      num_args
 		      ));
-    DEBUGOUT(XdbPrintArgList(__FILE__, (Widget)object, args, num_args, False));
-    DEBUGOUT(XdbDebug2("DRAGSINK", (Widget)object, widget,
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, (Widget)object, args, num_args, False));
+    DEBUGOUT(_LtDebug2("DRAGSINK", (Widget)object, widget,
 		      "%s:__XmDSMCreateInfo(%d) - %i args\n", 
 		      __FILE__, __LINE__,
 		      num_args
 		      ));
-    DEBUGOUT(XdbPrintArgList("DRAGSINK", (Widget)object, args, num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList("DRAGSINK", (Widget)object, args, num_args, False));
 
     DSMStartUpdate(object, widget);
 
@@ -1087,13 +1085,14 @@ __XmDSMCreateInfo(XmDropSiteManagerObject object,
     }
 }
 
+
 static void
 __XmDSMDestroyInfo(XmDropSiteManagerObject dsm,
 		   Widget widget)
 {
     XmDropSiteInfo dsi;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM DestroyInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM DestroyInfo\n"));
 
     dsi = (XmDropSiteInfo) DSMWidgetToInfo(dsm, widget);
 
@@ -1119,6 +1118,7 @@ __XmDSMDestroyInfo(XmDropSiteManagerObject dsm,
     DSMEndUpdate(dsm, widget);
 }
 
+
 static void
 __XmDSMStartUpdate(XmDropSiteManagerObject dsm,
 		   Widget widget)
@@ -1126,7 +1126,7 @@ __XmDSMStartUpdate(XmDropSiteManagerObject dsm,
     Widget shell = widget;
     XmDropSiteInfo info;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM StartUpdate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM StartUpdate\n"));
 
     while (!XtIsShell(shell))
     {
@@ -1148,6 +1148,7 @@ __XmDSMStartUpdate(XmDropSiteManagerObject dsm,
     info->inUpdate++;
 }
 
+
 static void
 __XmDSMRetrieveInfo(XmDropSiteManagerObject dsm,
 		    Widget widget,
@@ -1156,7 +1157,7 @@ __XmDSMRetrieveInfo(XmDropSiteManagerObject dsm,
 {
     XmDropSiteInfo info;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM RetrieveInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM RetrieveInfo\n"));
 
     if (XmIsDragContext(widget))
     {
@@ -1185,6 +1186,7 @@ __XmDSMRetrieveInfo(XmDropSiteManagerObject dsm,
 		   args, num_args);
 }
 
+
 static void
 __XmDSMUpdateInfo(XmDropSiteManagerObject dsm,
 		  Widget widget,
@@ -1193,11 +1195,12 @@ __XmDSMUpdateInfo(XmDropSiteManagerObject dsm,
 {
     XmDropSiteInfo dsi, ndsi;
     XmRegion r;
-    int x, y, i;
+    int x, y;
+    Cardinal i;
     Window root;
     unsigned int width, height, border;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM UpdateInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM UpdateInfo\n"));
 
     dsi = (XmDropSiteInfo) DSMWidgetToInfo(dsm, widget);
 
@@ -1263,6 +1266,7 @@ __XmDSMUpdateInfo(XmDropSiteManagerObject dsm,
     DSMEndUpdate(dsm, widget);
 }
 
+
 static void
 __XmDSMEndUpdate(XmDropSiteManagerObject dsm,
 		 Widget widget)
@@ -1271,7 +1275,7 @@ __XmDSMEndUpdate(XmDropSiteManagerObject dsm,
     Widget shell;
     XmTreeUpdateCallbackStruct tucbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM EndUpdate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM EndUpdate\n"));
 
     shell = widget;
 
@@ -1312,6 +1316,7 @@ __XmDSMEndUpdate(XmDropSiteManagerObject dsm,
     }
 }
 
+
 static void
 __XmDSMUpdateDSM(XmDropSiteManagerObject dsm,
 		 XtPointer clientData,
@@ -1319,8 +1324,8 @@ __XmDSMUpdateDSM(XmDropSiteManagerObject dsm,
 {
     XmDragDropCallbackStruct *cbs = (XmDragDropCallbackStruct *) callData;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM UpdateDSM\n"));
-    DEBUGOUT(XdbDebug("DRAGSINK", (Widget)dsm, "__XmDSMUpdateDSM\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM UpdateDSM\n"));
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "__XmDSMUpdateDSM\n"));
 
     switch (cbs->any.reason)
     {
@@ -1342,19 +1347,20 @@ __XmDSMUpdateDSM(XmDropSiteManagerObject dsm,
 	break;
 
     default:
-	DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm,
 			  "DSMUpdate default: %d\n", cbs->any.reason));
 	break;
     }
 }
 
+
 static Boolean
 loc_in_info(XmDropSiteManagerObject dsm, XmDropSiteInfo dsi,
 	    Position x, Position y)
 {
     Position tx, ty;
 
-    DEBUGOUT(XdbDebug2(__FILE__, (Widget)dsm, dsi->dropSite, "%s:loc_in_info(%d) - %+i%+i %+i%+i\n",
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)dsm, dsi->dropSite, "%s:loc_in_info(%d) - %+i%+i %+i%+i\n",
     	__FILE__, __LINE__,
     	x, y,
     	DS_RootX(dsm), DS_RootY(dsm)));
@@ -1366,7 +1372,7 @@ loc_in_info(XmDropSiteManagerObject dsm, XmDropSiteInfo dsi,
 
     x -= tx;
     y -= ty;
-    DEBUGOUT(XdbDebug0(__FILE__, (Widget)dsm, "\t%+i%+i\n",
+    DEBUGOUT(_LtDebug0(__FILE__, (Widget)dsm, "\t%+i%+i\n",
     	x, y));
 
     if (_XmRegionPointInRegion(dsi->region, x, y))
@@ -1379,6 +1385,7 @@ loc_in_info(XmDropSiteManagerObject dsm, XmDropSiteInfo dsi,
     }
 }
 
+
 static XmDropSiteInfo
 loc_to_info(XmDropSiteManagerObject dsm, XmDropSiteInfo dsi,
 	    Position x, Position y)
@@ -1386,14 +1393,14 @@ loc_to_info(XmDropSiteManagerObject dsm, XmDropSiteInfo dsi,
     int i;
     XmDropSiteInfo child;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "%s:loc_to_info(%d) - %+i%+i %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:loc_to_info(%d) - %+i%+i %s\n",
     	__FILE__, __LINE__,
     	x, y,
     	dsi->leaf ? "Leaf" : "Not leaf"));
 
     if (!dsi->leaf)
     {
-	DEBUGOUT(XdbDebug0(__FILE__, (Widget)dsm, "\t%i children\n", dsi->numChildren));
+	DEBUGOUT(_LtDebug0(__FILE__, (Widget)dsm, "\t%i children\n", dsi->numChildren));
 	for (i = 0; i < dsi->numChildren; i++)
 	{
 	    child = dsi->children[i];
@@ -1428,6 +1435,7 @@ loc_to_info(XmDropSiteManagerObject dsm, XmDropSiteInfo dsi,
     return NULL;
 }
 
+
 /**
  * Waider 14/06/98 I've just noticed that this function /has/ no
  * function other than, at the moment, to generate core dumps.
@@ -1440,7 +1448,7 @@ animate(XmDropSiteManagerObject dsm,
     XmDropSiteInfo dsi = (XmDropSiteInfo) DS_CurInfo(dsm);
     Widget dc;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "%s:animate(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:animate(%d)\n",
     	__FILE__, __LINE__));
 
     if (dsi && dsi->animationStyle == XmDRAG_UNDER_NONE)
@@ -1451,6 +1459,7 @@ animate(XmDropSiteManagerObject dsm,
     dc = DS_CurDragContext(dsm);
 }
 
+
 static void
 drop_site_enter(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
 		XmDragMotionCallbackStruct *cbs, XmDropSiteInfo dsi,
@@ -1464,7 +1473,7 @@ drop_site_enter(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
     int nimps;
     Widget par;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "%s:drop_site_enter(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:drop_site_enter(%d)\n",
     	__FILE__, __LINE__));
 
     dpc.reason = XmCR_DROP_SITE_ENTER_MESSAGE;
@@ -1576,6 +1585,7 @@ drop_site_enter(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
     }
 }
 
+
 static void
 drop_site_leave(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
 		XmDragMotionCallbackStruct *cbs, XmDropSiteInfo dsi,
@@ -1585,7 +1595,7 @@ drop_site_leave(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
     XmDropSiteLeaveCallbackStruct dsl;
     Position x, y;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "%s:drop_site_leave(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:drop_site_leave(%d)\n",
     	__FILE__, __LINE__));
 
     dpc.reason = XmCR_DROP_SITE_LEAVE_MESSAGE;
@@ -1626,6 +1636,7 @@ drop_site_leave(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
     }
 }
 
+
 static void
 drag_motion(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
 	    XmDragMotionCallbackStruct *cbs, XmDropSiteInfo dsi,
@@ -1635,7 +1646,7 @@ drag_motion(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
     XmDragMotionCallbackStruct dm;
     Position x, y;
 
-    DEBUGOUT(XdbDebug("DRAGSINK", (Widget)dsm, "%s:drag_motion(%d)\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "%s:drag_motion(%d)\n",
     	__FILE__, __LINE__));
 
     dpc.reason = XmCR_DROP_SITE_MOTION_MESSAGE;
@@ -1709,6 +1720,7 @@ drag_motion(XmDropSiteManagerObject dsm, XmDragMotionClientDataStruct * cd,
     }
 }
 
+
 /*
  * When a drag motion event is sent to this client, we handle 
  * the notification of the drop site (if it has drag under effects)
@@ -1724,11 +1736,11 @@ __XmDSMProcessMotion(XmDropSiteManagerObject dsm,
     XmDropSiteInfo ndsi;
     unsigned char ps;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "__XmDSMProcessMotion - %s %+i%+i %+i%+i\n",
-    	XdbDragAndDropMessageType2String(cbs->reason),
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "__XmDSMProcessMotion - %s %+i%+i %+i%+i\n",
+    	_LtDebugDragAndDropMessageType2String(cbs->reason),
     	cbs->x, cbs->y, DS_RootX(dsm), DS_RootY(dsm)));
-    DEBUGOUT(XdbDebug("DRAGSINK", (Widget)dsm, "__XmDSMProcessMotion - %s %+i%+i %+i%+i\n",
-    	XdbDragAndDropMessageType2String(cbs->reason),
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "__XmDSMProcessMotion - %s %+i%+i %+i%+i\n",
+    	_LtDebugDragAndDropMessageType2String(cbs->reason),
     	cbs->x, cbs->y, DS_RootX(dsm), DS_RootY(dsm)));
 
     if (DS_CurDragContext(dsm) == NULL)
@@ -1759,9 +1771,9 @@ __XmDSMProcessMotion(XmDropSiteManagerObject dsm,
 		drop_site_leave(dsm, cd, cbs, dsi, ps);
 	    }
 
-            DEBUGOUT(XdbDebug(__FILE__, 
+            DEBUGOUT(_LtDebug(__FILE__, 
                               (Widget)dsm, "Setting dsi to %p\n", ndsi ));
-            DEBUGOUT(XdbDebug("DRAGSINK", 
+            DEBUGOUT(_LtDebug("DRAGSINK", 
                               (Widget)dsm, "Setting dsi to %s\n", 
                               ndsi ? XtName(ndsi->dropSite) : "NULL"));
 	    DS_CurInfo(dsm) = (XtPointer)ndsi;
@@ -1773,12 +1785,13 @@ __XmDSMProcessMotion(XmDropSiteManagerObject dsm,
 	}
     }
 
-    DEBUGOUT(XdbDebug("DRAGSINK", 
+    DEBUGOUT(_LtDebug("DRAGSINK", 
                       (Widget)dsm, "Dragging on %s\n", 
                       dsi ? XtName(dsi->dropSite) : "NULL"));
     drag_motion(dsm, cd, cbs, dsi, ps);
 }
 
+
 /*
  * When the drop is started (BDrag is released), we let the drop site know that
  * it's being dropped in
@@ -1800,8 +1813,8 @@ __XmDSMProcessDrop(XmDropSiteManagerObject dsm,
     Cardinal nimps;
     Atom *itargs;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "__XmDSMProcessDrop\n"));
-    DEBUGOUT(XdbDebug("DRAGSINK", (Widget)dsm, "__XmDSMProcessDrop %s %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "__XmDSMProcessDrop\n"));
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "__XmDSMProcessDrop %s %s\n",
     	cbs->dropAction == XmDROP ? "XmDROP" : "not XmDROP",
     	cbs->dropSiteStatus == XmDROP_SITE_VALID ? "XmDROP_SITE_VALID" : "not XmDROP_SITE_VALID"));
 
@@ -1928,6 +1941,7 @@ __XmDSMProcessDrop(XmDropSiteManagerObject dsm,
     }
 }
 
+
 /*
  * We notify the current drop site (if any) that the operation of the drag
  * has changed
@@ -1947,7 +1961,7 @@ __XmDSMOperationChanged(XmDropSiteManagerObject dsm,
     int nimps;
     Widget par;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM OperationChanged\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM OperationChanged\n"));
 
     if (DS_CurDragContext(dsm) == NULL)
     {
@@ -2071,6 +2085,7 @@ __XmDSMOperationChanged(XmDropSiteManagerObject dsm,
     }
 }
 
+
 static void
 __XmDSMChangeRoot(XmDropSiteManagerObject dsm,
 		  XtPointer clientData,
@@ -2080,10 +2095,10 @@ __XmDSMChangeRoot(XmDropSiteManagerObject dsm,
     (XmDragTopLevelClientDataStruct *) clientData;
     XmDragDropCallbackStruct *cbs = (XmDragDropCallbackStruct *) callData;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "__XmDSMChangeRoot: %s\n",
-		      XdbDragAndDropMessageType2String(cbs->any.reason)));
-    DEBUGOUT(XdbDebug("DRAGSINK", (Widget)dsm, "__XmDSMChangeRoot: %s\n",
-		      XdbDragAndDropMessageType2String(cbs->any.reason)));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "__XmDSMChangeRoot: %s\n",
+		      _LtDebugDragAndDropMessageType2String(cbs->any.reason)));
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "__XmDSMChangeRoot: %s\n",
+		      _LtDebugDragAndDropMessageType2String(cbs->any.reason)));
 
     DS_CurTime(dsm) = cbs->any.timeStamp;
 
@@ -2112,7 +2127,7 @@ __XmDSMChangeRoot(XmDropSiteManagerObject dsm,
 	}
 	else
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "EEEEEK!!!\n")); /* EEK! */
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "EEEEEK!!!\n")); /* EEK! */
 	    DS_DSRoot(dsm) = NULL;
 	}
 
@@ -2153,6 +2168,7 @@ __XmDSMChangeRoot(XmDropSiteManagerObject dsm,
     }
 }
 
+
 static void
 __XmDSMInsertInfo(XmDropSiteManagerObject dsm,
 		  XtPointer clientData,
@@ -2162,9 +2178,9 @@ __XmDSMInsertInfo(XmDropSiteManagerObject dsm,
     Widget w, parent;
     XmTreeUpdateCallbackStruct tucbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "%s:__XmDSMInsertInfo(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:__XmDSMInsertInfo(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(XdbDebug("DRAGSINK", (Widget)dsm, "%s:__XmDSMInsertInfo(%d)\n",
+    DEBUGOUT(_LtDebug("DRAGSINK", (Widget)dsm, "%s:__XmDSMInsertInfo(%d)\n",
     	__FILE__, __LINE__));
 
     w = dsi->dropSite;
@@ -2224,6 +2240,7 @@ __XmDSMInsertInfo(XmDropSiteManagerObject dsm,
     }
 }
 
+
 static void
 __XmDSMRemoveInfo(XmDropSiteManagerObject dsm,
 		  XtPointer info)
@@ -2232,7 +2249,7 @@ __XmDSMRemoveInfo(XmDropSiteManagerObject dsm,
     Widget w;
     XmTreeUpdateCallbackStruct tucbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM RemoveInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM RemoveInfo\n"));
 
     w = dsi->dropSite;
 
@@ -2277,14 +2294,16 @@ __XmDSMRemoveInfo(XmDropSiteManagerObject dsm,
     DSMDestroyInfo(dsm, pi->dropSite);
 }
 
+
 static void
 __XmDSMSyncTree(XmDropSiteManagerObject dsm,
 		Widget shell)
 {
-    DEBUGOUT(XdbDebug2(__FILE__, (Widget)dsm, shell, "%s:__XmDSMSyncTree(%d)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)dsm, shell, "%s:__XmDSMSyncTree(%d)\n",
     	__FILE__, __LINE__));
 }
 
+
 /*
  * This function creates (or replaces) the property on the shell widget
  * to contain the entire drop site database.
@@ -2294,11 +2313,12 @@ __XmDSMGetTree(XmDropSiteManagerObject dsm,
 	       Widget shell,
 	       XtPointer dataPtr)
 {
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM GetTree\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM GetTree\n"));
 
     return 0;
 }
 
+
 /*
  * Creates a hash table that goes from widgets to drop site information
  */
@@ -2307,7 +2327,7 @@ __XmDSMCreateDSInfoTable(XmDropSiteManagerObject dsm)
 {
     DSInfoTable *it;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM CreateDSInfoTable\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM CreateDSInfoTable\n"));
 
     it = (DSInfoTable *) XtCalloc(1, sizeof(DSInfoTable));
 
@@ -2318,6 +2338,7 @@ __XmDSMCreateDSInfoTable(XmDropSiteManagerObject dsm)
 					      sizeof(XmDropSiteInfo));
 }
 
+
 /*
  * destroys the hash table
  */
@@ -2326,7 +2347,7 @@ __XmDSMDestroyDSInfoTable(XmDropSiteManagerObject dsm)
 {
     DSInfoTable *it;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM DestroyDSInfoTable\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM DestroyDSInfoTable\n"));
 
     it = (DSInfoTable *) DS_DSTable(dsm);
 
@@ -2335,6 +2356,7 @@ __XmDSMDestroyDSInfoTable(XmDropSiteManagerObject dsm)
     XtFree((char *)it);
 }
 
+
 /*
  * adds a widget and its associated info to the hash table
  */
@@ -2347,9 +2369,9 @@ __XmDSMRegisterInfo(XmDropSiteManagerObject dsm,
     DSInfoTable *dst;
     long hash;
 
-    DEBUGOUT(XdbDebug2(__FILE__, (Widget)dsm, widget, "%s:__XmDSMRegisterInfo(%d)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)dsm, widget, "%s:__XmDSMRegisterInfo(%d)\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(XdbDebug2("DRAGSINK", (Widget)dsm, widget, "%s:__XmDSMRegisterInfo(%d)\n",
+    DEBUGOUT(_LtDebug2("DRAGSINK", (Widget)dsm, widget, "%s:__XmDSMRegisterInfo(%d)\n",
     	__FILE__, __LINE__));
 
     if (dsi->registered)
@@ -2367,6 +2389,7 @@ __XmDSMRegisterInfo(XmDropSiteManagerObject dsm,
     dsi->registered = 1;
 }
 
+
 /*
  * retrieves the info for a given widget from the hash table
  */
@@ -2378,7 +2401,7 @@ __XmDSMWidgetToInfo(XmDropSiteManagerObject dsm,
     long hash;
     XmDropSiteInfo dsi;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM WidgetToInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM WidgetToInfo\n"));
 
     info = (DSInfoTable *) DS_DSTable(dsm);
 
@@ -2405,6 +2428,7 @@ __XmDSMWidgetToInfo(XmDropSiteManagerObject dsm,
     return NULL;
 }
 
+
 /*
  * removes the info from the hash table, along with the widget that
  * hashes to it.
@@ -2417,7 +2441,7 @@ __XmDSMUnregisterInfo(XmDropSiteManagerObject dsm,
     DSInfoTable *dst;
     long hash;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "DSM UnregisterInfo\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "DSM UnregisterInfo\n"));
 
     if (!dsi->registered)
     {
@@ -2440,33 +2464,36 @@ __XmDSMUnregisterInfo(XmDropSiteManagerObject dsm,
     dsi->registered = 0;
 }
 
-void
+
+extern void
 _XmDSMUpdate(XmDropSiteManagerObject dsm,
 	     XtPointer clientData,
 	     XtPointer callData)
 {
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "_XmDSMUpdate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "_XmDSMUpdate\n"));
 
     DSMUpdate(dsm, clientData, callData);
 }
 
-int
+
+extern int
 _XmDSMGetTreeFromDSM(XmDropSiteManagerObject dsm,
 		     Widget shell,
 		     XtPointer dataPtr)
 {
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "_XmDSMGetTreeFromDSM\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "_XmDSMGetTreeFromDSM\n"));
 
     return DSMGetTreeFromDSM(dsm, shell, dataPtr);
 }
 
-Boolean
+
+extern Boolean
 _XmDropSiteShell(Widget widget)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "_XmDropSiteShell\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmDropSiteShell\n"));
 
     dsm = _XmGetDropSiteManagerObject((XmDisplay)disp);
 
@@ -2483,12 +2510,13 @@ _XmDropSiteShell(Widget widget)
     return False;
 }
 
+
 static Boolean
 has_ds_offspring(XmDropSiteManagerObject dsm, Widget w)
 {
-    int i;
+    Cardinal i;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)dsm, "%s:has_ds_offspring(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)dsm, "%s:has_ds_offspring(%d)\n",
     	__FILE__, __LINE__));
 
     if (!XtIsComposite(w))
@@ -2513,13 +2541,14 @@ has_ds_offspring(XmDropSiteManagerObject dsm, Widget w)
     return False;
 }
 
-Boolean
+
+extern Boolean
 _XmDropSiteWrapperCandidate(Widget widget)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget)), par;
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "_XmDropSiteWrapperCandidate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmDropSiteWrapperCandidate\n"));
 
     dsm = _XmGetDropSiteManagerObject((XmDisplay)disp);
 
@@ -2552,13 +2581,14 @@ _XmDropSiteWrapperCandidate(Widget widget)
     return has_ds_offspring(dsm, widget);
 }
 
-Widget
+
+extern Widget
 _XmGetActiveDropSite(Widget widget)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "_XmGetActiveDropSite\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmGetActiveDropSite\n"));
 
     dsm = _XmGetDropSiteManagerObject((XmDisplay)disp);
 
@@ -2572,13 +2602,14 @@ _XmGetActiveDropSite(Widget widget)
     }
 }
 
-void
+
+extern void
 _XmSyncDropSiteTree(Widget shell)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(shell));
     XmDropSiteManagerObject dsm;
 
-    DEBUGOUT(XdbDebug(__FILE__, shell, "_XmSyncDropSiteTree\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "_XmSyncDropSiteTree\n"));
 
     dsm = _XmGetDropSiteManagerObject((XmDisplay)disp);
 
@@ -2588,121 +2619,131 @@ _XmSyncDropSiteTree(Widget shell)
 /*
  * dead function
  */
-void
+
+extern void
 _XmIEndUpdate(XtPointer client_data, XtIntervalId *interval_id)
 {
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmIEndUpdate(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmIEndUpdate(%d)\n",
     	__FILE__, __LINE__));
 
 }
 
-void
+
+extern void
 XmDropSiteConfigureStackingOrder(Widget widget,
 				 Widget Sibling,
 				 Cardinal stack_mode)
 {
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropSiteConfigureStackingOrder()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteConfigureStackingOrder()\n"));
 
     /* FIX ME */
 }
 
-void
+
+extern void
 XmDropSiteEndUpdate(Widget widget)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropSiteEndUpdate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteEndUpdate()\n"));
 
     DSMEndUpdate(_XmGetDropSiteManagerObject((XmDisplay)disp), widget);
 }
 
-Status
+
+extern Status
 XmDropSiteQueryStackingOrder(Widget widget,
 			     Widget *parent_return,
 			     Widget **child_returns,
 			     Cardinal *num_child_returns)
 {
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropSiteQueryStackingOrder()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteQueryStackingOrder()\n"));
 
     /* FIX ME */
 
     return 0;
 }
 
-void
+
+extern void
 XmDropSiteRegister(Widget widget,
 		   ArgList arglist,
 		   Cardinal argcount)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(XdbDebug(__FILE__, widget,
+    DEBUGOUT(_LtDebug(__FILE__, widget,
 		      "%s:XmDropSiteRegister(%d) - %i args\n",
 		      __FILE__, __LINE__,
 		      argcount));
-    DEBUGOUT(XdbPrintArgList(__FILE__, widget, arglist, argcount, False));
-    DEBUGOUT(XdbDebug("DRAGSINK", widget,
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, widget, arglist, argcount, False));
+    DEBUGOUT(_LtDebug("DRAGSINK", widget,
 		      "%s:XmDropSiteRegister(%d) - %i args\n",
 		      __FILE__, __LINE__,
 		      argcount));
-    DEBUGOUT(XdbPrintArgList("DRAGSINK", widget, arglist, argcount, False));
+    DEBUGOUT(_LtDebugPrintArgList("DRAGSINK", widget, arglist, argcount, False));
 
     DSMCreateInfo(_XmGetDropSiteManagerObject((XmDisplay)disp),
 		  widget, arglist, argcount);
 }
 
-void
+
+extern void
 XmDropSiteRetrieve(Widget widget,
 		   ArgList arglist,
 		   Cardinal argcount)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropSiteRetrieve()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteRetrieve()\n"));
 
     DSMRetrieveInfo(_XmGetDropSiteManagerObject((XmDisplay)disp),
 		    widget, arglist, argcount);
 }
 
-void
+
+extern void
 XmDropSiteStartUpdate(Widget widget)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropSiteStartUpdate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteStartUpdate()\n"));
 
     DSMStartUpdate(_XmGetDropSiteManagerObject((XmDisplay)disp), widget);
 }
 
-void
+
+extern void
 XmDropSiteUnregister(Widget widget)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropSiteUnregister()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteUnregister()\n"));
 
     DSMDestroyInfo(_XmGetDropSiteManagerObject((XmDisplay)disp), widget);
 }
 
-void
+
+extern void
 XmDropSiteUpdate(Widget widget,
 		 ArgList arglist,
 		 Cardinal argcount)
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropSiteUpdate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteUpdate()\n"));
 
     DSMUpdateInfo(_XmGetDropSiteManagerObject((XmDisplay)disp),
 		  widget, arglist, argcount);
 }
 
-XmDropSiteVisuals
+
+extern XmDropSiteVisuals
 XmDropSiteGetActiveVisuals(Widget widget)
 {
     /* FIX ME */
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropSiteGetActiveVisuals()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmDropSiteGetActiveVisuals()\n"));
 
     return NULL;
 }
