@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Gadget.c,v 1.17 2000/09/23 15:05:24 amai Exp $
+ * $Id: Gadget.c,v 1.19 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Gadget.c,v 1.17 2000/09/23 15:05:24 amai Exp $";
+static const char rcsid[] = "$Id: Gadget.c,v 1.19 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -510,68 +510,68 @@ input_dispatch(Widget w,
 	       XEvent *event,
 	       Mask event_mask)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Inside base Gadget input_dispatch() routine "
 		      "(you really should write one for this gadget... :)\n"));
 
     if (event_mask & XmENTER_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Enter event sent to gadget %d\n", w));
     }
     else if (event_mask & XmLEAVE_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Leave event sent to gadget %d\n", w));
     }
     else if (event_mask & XmFOCUS_IN_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Focus in event sent to gadget %d\n", w));
     }
     else if (event_mask & XmFOCUS_OUT_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Focus out event sent to gadget %d\n", w));
     }
     else if (event_mask & XmMOTION_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Motion event sent to gadget %d\n", w));
     }
     else if (event_mask & XmARM_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Arm event sent to gadget %d\n", w));
     }
     else if (event_mask & XmACTIVATE_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Activate event sent to gadget %d\n", w));
     }
     else if (event_mask & XmHELP_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Help event sent to gadget %d\n", w));
     }
     else if (event_mask & XmKEY_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Key event sent to gadget %d\n", w));
     }
     else if (event_mask & XmMULTI_ARM_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Multi arm event sent to gadget %d\n", w));
     }
     else if (event_mask & XmMULTI_ACTIVATE_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Multi activate event sent to gadget %d\n", w));
     }
     else if (event_mask & XmBDRAG_EVENT)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "BDrag event sent to gadget %d\n", w));
     }
 }
@@ -667,7 +667,7 @@ static void
 gadget_border_unhighlight(Widget w)
 {
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "gadget_border_unhighlight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "gadget_border_unhighlight\n"));
 
     /* with zero width, we don't need this... */
     if (G_HighlightThickness(w) == 0)
@@ -699,7 +699,7 @@ static void
 gadget_border_highlight(Widget w)
 {
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "gadget_border_highlight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "gadget_border_highlight\n"));
 
     /* with zero width, we don't need this... */
     if (G_HighlightThickness(w) == 0)
