@@ -1,9 +1,9 @@
 /**
  *
- * $Id: LabelG.c,v 1.96 2000/09/22 20:35:12 amai Exp $
+ * $Id: LabelG.c,v 1.100 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LabelG.c,v 1.96 2000/09/22 20:35:12 amai Exp $";
+static const char rcsid[] = "$Id: LabelG.c,v 1.100 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -473,9 +473,9 @@ secondary_object_create(Widget request,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "LabelGCacheRec %s being initialized.\n", XtName(new_w)));
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -586,7 +586,7 @@ _XmAssignLabG_MarginHeight(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -631,7 +631,7 @@ _XmAssignLabG_MarginWidth(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -674,7 +674,7 @@ _XmAssignLabG_MarginLeft(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -717,7 +717,7 @@ _XmAssignLabG_MarginRight(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -760,7 +760,7 @@ _XmAssignLabG_MarginTop(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -803,7 +803,7 @@ _XmAssignLabG_MarginBottom(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -850,17 +850,77 @@ drag_convert_proc(Widget w, Atom *selection,
 {
     Atom COMPOUND_TEXT;
     Atom MOTIF_DROP;
+    Widget source;
+    char *ct, *text;
+    XmString label;
+    Atom TEXT;
+    int len;
 
+    _XmObjectLock(w);
     COMPOUND_TEXT = XmInternAtom(XtDisplay(w), _XA_COMPOUND_TEXT, False);
     MOTIF_DROP = XmInternAtom(XtDisplay(w), _XA_MOTIF_DROP, False);
+    TEXT = XmInternAtom(XtDisplay(w), _XA_TEXT, False);
 
     if (*selection != MOTIF_DROP)
     {
+	_XmObjectUnlock(w);
 	return False;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "We're dealing with a motif drop\n"));
-    return False;
+    DEBUGOUT(_LtDebug(__FILE__, w, "We're dealing with a motif drop\n"));
+
+    XtVaGetValues(w,
+    	XmNsourceWidget, &source,
+    	NULL);
+    XtVaGetValues(source,
+    	XmNlabelString, &label,
+    	NULL);
+
+    ct = XmCvtXmStringToCT(label);
+    XmStringFree(label);
+    text = XtNewString(ct);
+    len = strlen(text);
+
+    if (*target == XA_STRING){
+        *length_return = len;
+        *value_return = text;
+        *type_return = XA_STRING;
+    }
+    else if (*target == COMPOUND_TEXT || *target == TEXT){
+
+	    XTextProperty prop;
+	    char *buf;
+	    int ret;
+
+	    buf = XtMalloc(len + 1);
+            strncpy(buf, text, len);
+	    buf[len] = '\0';
+
+	    ret = XmbTextListToTextProperty(XtDisplay(w), &buf, 1,
+	    			XCompoundTextStyle, &prop);
+		
+	    XtFree(buf);
+	    if (ret != 0){
+	    	*length_return = 0;
+	    	*value_return  = NULL;
+	    }
+	    else{
+	    	buf = XtMalloc(prop.nitems + 1);
+		strncpy(buf, prop.value, prop.nitems);
+		buf[prop.nitems] = '\0';
+	    	*length_return = prop.nitems;
+	    	*value_return  = buf;
+	    }
+	   *type_return = COMPOUND_TEXT;
+
+    }
+    else
+	return False;
+
+    *format_return = 8;
+
+    _XmObjectUnlock(w);
+    return True;
 }
 
 static void
@@ -872,28 +932,30 @@ void
 _XmProcessDrag(Widget w, XEvent *event,
 	       String *params, Cardinal *num_params)
 {
-    Atom export_target;
+    Atom export_target[3];
     Arg args[10];
     int n = 0;
     Widget dc;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Processing a drag-drop request\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Processing a drag-drop request\n"));
 
     if (LabG_IsPixmap(w))
     {
-	export_target = XmInternAtom(XtDisplay(w),
+	export_target[0] = XmInternAtom(XtDisplay(w),
 				     _XA_PIXMAP,
 				     False);
+        XtSetArg(args[n], XmNexportTargets, export_target); n++;
+        XtSetArg(args[n], XmNnumExportTargets, 1); n++;
     }
     else
     {
-	export_target = XmInternAtom(XtDisplay(w),
-				     _XA_COMPOUND_TEXT,
-				     False);
+	export_target[0] = XmInternAtom(XtDisplay(w), _XA_COMPOUND_TEXT, False);
+	export_target[1] = XmInternAtom(XtDisplay(w), _XA_TEXT, False);
+	export_target[2] = XA_STRING;
+        XtSetArg(args[n], XmNexportTargets, export_target); n++;
+        XtSetArg(args[n], XmNnumExportTargets, 3); n++;
     }
 
-    XtSetArg(args[n], XmNexportTargets, &export_target); n++;
-    XtSetArg(args[n], XmNnumExportTargets, 1); n++;
     XtSetArg(args[n], XmNdragOperations, XmDROP_COPY); n++;
     XtSetArg(args[n], XmNconvertProc, drag_convert_proc); n++;
     XtSetArg(args[n], XmNclientData, w); n++;
@@ -1023,7 +1085,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "LabelG InitializePrehook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelG InitializePrehook\n"));
 }
 #endif
 
@@ -1035,7 +1097,7 @@ initialize_posthook(Widget request,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "LabelG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -1055,7 +1117,7 @@ initialize(Widget request, Widget new_w,
 {
     XmString xmstring;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -1065,7 +1127,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     LabG_SkipCallback(new_w) = False;
 
@@ -1248,7 +1310,7 @@ resize(Widget w)
 	    {
 		_XmAssignLabG_MarginRight((XmLabelGadget)w,
 		    LABEL_ACC_PAD + LabG_AccTextRect(w).width);
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "resize: set right margin to %d\n",
 				  LabG_MarginRight(w)));
 		_XmReCacheLabG(w);
@@ -1261,7 +1323,7 @@ resize(Widget w)
 	    {
 		_XmAssignLabG_MarginLeft((XmLabelGadget)w,
 		    LABEL_ACC_PAD + LabG_AccTextRect(w).width);
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "resize: set left margin to %d\n",
 				  LabG_MarginLeft(w)));
 		_XmReCacheLabG(w);
@@ -1345,7 +1407,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1436,7 +1498,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh_needed = False, relayout_needed = False,
 	recalc_needed = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "LabelGadget SetValues %d %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelGadget SetValues %d %d\n",
 		      LabG_MarginRight(new_w), LabG_MarginRight(old)));
 
     /* Silently discard accelerator for non-menu labels and cascades */
@@ -1697,7 +1759,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1752,7 +1814,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "LabelG: GetValuesHook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "LabelG: GetValuesHook\n"));
 }
 #endif
 
@@ -1833,11 +1895,11 @@ expose(Widget w,
 	- ((G_ShadowThickness(w) + G_HighlightThickness(w)) << 1)
 	- LabG_MarginTop(w) - LabG_MarginBottom(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
              "Expose: cliprect %d %d %dx%d\n",
             cliprect.x, cliprect.y,
              cliprect.width, cliprect.height));
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
              "Expose: acctextrect %d %d %dx%d\n",
             LabG_AccTextRect(w).x, LabG_AccTextRect(w).y,
              LabG_AccTextRect(w).width, LabG_AccTextRect(w).height));
@@ -2058,7 +2120,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     a.width = XtWidth(w);
     a.height = XtHeight(w);
     a.request_mode = CWWidth | CWHeight;
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "LabelGadget queried for size: reporting %d %d %08x\n",
 		      XtWidth(w), XtHeight(w), answer));
 
@@ -2179,11 +2241,11 @@ input_dispatch(Widget gadget,
     switch (event_mask)
     {
     case XmHELP_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "LabelGadget got help event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "LabelGadget got help event\n"));
 	break;
 
     case XmBDRAG_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "LabelGadget got bdrag event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "LabelGadget got bdrag event\n"));
 	_XmProcessDrag(gadget, event, NULL, NULL);
 	break;
     }
