@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Manager.c,v 1.89 2000/09/29 22:51:55 amai Exp $
+ * $Id: Manager.c,v 1.96 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Manager.c,v 1.89 2000/09/29 22:51:55 amai Exp $";
+static const char rcsid[] = "$Id: Manager.c,v 1.96 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -43,8 +43,6 @@ static const char rcsid[] = "$Id: Manager.c,v 1.89 2000/09/29 22:51:55 amai Exp
 #include <X11/keysym.h>
 #include <Xm/VirtKeysP.h>
 
-#include <XmI/DebugUtil.h>
-
 /* For determining class type */
 #include <Xm/CascadeBP.h>
 #include <Xm/CascadeBGP.h>
@@ -74,6 +72,9 @@ static XmSpecifyLayoutDirectionTraitRec _XmManagerLayoutTraitRec =
 
 #endif
 
+#include <XmI/DebugUtil.h>
+
+
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -394,7 +395,7 @@ static XmSyntheticResource syn_resources[] =
     },
 #endif
 };
-/* *INDENT-OFF* */
+
 static XmBaseClassExtRec _XmManagerCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -506,7 +507,7 @@ XmManagerClassRec xmManagerClassRec = {
 	/* extension                    */ (XtPointer)&_XmManagerClassExtRec
     },
 };
-/* *INDENT-ON* */
+
 
 
 
@@ -632,8 +633,8 @@ class_part_initialize(WidgetClass widget_class)
 #if XmVERSION > 1
     /* FIX ME: do I need to worry about subclasses */
     /* initialize traits */
-    if (!XmeTraitSet(xmManagerWidgetClass, XmQTspecifyLayoutDirection,
-		     &_XmManagerLayoutTraitRec))
+    if (!XmeTraitSet((XtPointer)xmManagerWidgetClass, XmQTspecifyLayoutDirection,
+		     (XtPointer)&_XmManagerLayoutTraitRec))
     {
 	_XmWarning(NULL, "XmManager ClassInitialize: XmeTraitSet failed\n");
     }
@@ -673,10 +674,8 @@ CreateHighlightGC(Widget mw)
     /* have no idea ! */
     unused = 0;
 
-    MGR_HighlightGC(mw) =
-      XtAllocateGC((Widget)mw,
-                  DefaultDepthOfScreen(XtScreen((Widget)mw)),
-                  mask,&values,dynamic,unused);
+    MGR_HighlightGC(mw) = XtGetGC((Widget)mw, mask, &values);
+
 }
 
 static void
@@ -850,7 +849,7 @@ initialize(Widget request,
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(XdbDebug("RWS", w, "%s:destroy(%d)\n",
+    DEBUGOUT(_LtDebug("RWS", w, "%s:destroy(%d)\n",
 		      __FILE__, __LINE__
 	     ));
     XtReleaseGC(w, MGR_TopShadowGC(w));
@@ -880,7 +879,7 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
        This causes a parse error with gcc on AIX???
        Boolean wz = False, hz = False; */
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
 		      __FILE__, __LINE__,
 		      XtWidth(w), XtHeight(w)));
 
@@ -929,7 +928,7 @@ set_values(Widget old,
 {
     Boolean need_refresh = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "SetValues()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "SetValues()\n"));
 
 #if 0
     if (XtWidth(new_w) != XtWidth(old) && XtWidth(new_w) == 0)
@@ -1034,7 +1033,7 @@ geometry_manager(Widget w,
 		 XtWidgetGeometry *reply)
 {
     /* Motif does not have this method */
-    DEBUGOUT(XdbDebug(__FILE__, w, "geometry_manager()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "geometry_manager()\n"));
 
     if (reply)
     {
@@ -1070,7 +1069,7 @@ changed_managed(Widget w)
 {
     /* Motif does not have this method */
     /* FIX ME */
-    DEBUGOUT(XdbDebug(__FILE__, w, "ChangeManaged()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged()\n"));
 
 
     _XmNavigChangeManaged(w);
@@ -1098,7 +1097,7 @@ constraint_initialize(Widget request,
 		|| G_EventMask(new_w) & XmENTER_EVENT
 		|| G_EventMask(new_w) & XmLEAVE_EVENT)
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, manager, "adding event handler\n"));
+		DEBUGOUT(_LtDebug(__FILE__, manager, "adding event handler\n"));
 
 		XtAddEventHandler(manager,
 				  PointerMotionMask | EnterWindowMask |
@@ -1121,7 +1120,7 @@ _XmGadgetArm(Widget w,
     XButtonEvent *ev = (XButtonEvent *)event;
     Widget g = (Widget)_XmInputForGadget(w, ev->x, ev->y);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetArm()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetArm()\n"));
 
     if (g)
     {
@@ -1150,7 +1149,7 @@ _XmGadgetActivate(Widget w,
 {
     Widget g = (Widget)MGR_SelectedGadget(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetActivate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetActivate()\n"));
 
     if (g)
     {
@@ -1171,7 +1170,7 @@ _XmGadgetMultiArm(Widget w,
     XButtonEvent *ev = (XButtonEvent *)event;
     Widget g = (Widget)_XmInputForGadget(w, ev->x, ev->y);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetMultiArm()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetMultiArm()\n"));
 
     if (g)
     {
@@ -1213,7 +1212,7 @@ _XmGadgetMultiActivate(Widget w,
 {
     Widget g = (Widget)MGR_SelectedGadget(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetMultiActivate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetMultiActivate()\n"));
 
     if (g)
     {
@@ -1248,7 +1247,7 @@ _XmGadgetDrag(Widget w,
     XButtonEvent *ev = (XButtonEvent *)event;
     Widget g = (Widget)_XmInputForGadget(w, ev->x, ev->y);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetDrag()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetDrag()\n"));
 
     if (g)
     {
@@ -1266,7 +1265,7 @@ _XmGadgetSelect(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, w, g, "Inside _XmGadgetSelect()\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, w, g, "Inside _XmGadgetSelect()\n"));
 
     if (g && XmIsGadget(g))
     {
@@ -1288,7 +1287,7 @@ _XmManagerParentActivate(Widget w,
     XmParentProcessDataRec data;
     XmManagerWidgetClass mwc = (XmManagerWidgetClass)w->core.widget_class;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Inside ManagerParentActivate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside ManagerParentActivate()\n"));
 
     data.input_action.process_type = XmINPUT_ACTION;
     data.input_action.event = event;
@@ -1368,7 +1367,7 @@ _XmGadgetTraverseRight(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, g,
+    DEBUGOUT(_LtDebug(__FILE__, g,
 		      "Manager XmProcessTraversal(TRAVERSE_RIGHT)\n"));
 
     XmProcessTraversal(g, XmTRAVERSE_RIGHT);
@@ -1395,7 +1394,7 @@ _XmGadgetHelp(Widget w,
     Widget cur;
     XmAnyCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmGadgetHelp()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetHelp()\n"));
 
     if (g)
     {
@@ -1440,8 +1439,8 @@ _XmGadgetKeyInput(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, w, g, "Inside _XmGadgetKeyInput()\n"));
-    DEBUGOUT(XdbDebug2(__FILE__, w, g,
+    DEBUGOUT(_LtDebug2(__FILE__, w, g, "Inside _XmGadgetKeyInput()\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, w, g,
 		       "event type: %d code %08x\n",
 		       event->type, event->xkey.keycode));
 
@@ -1461,7 +1460,7 @@ _XmGadgetButtonMotion(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Inside _XmGadgetButtonMotion(), gadget %s\n",
 		      g ? XtName(g) : "(null)"));
 
@@ -1482,7 +1481,7 @@ _XmManagerParentCancel(Widget w,
     XmParentProcessDataRec data;
     XmManagerWidgetClass mwc = (XmManagerWidgetClass)w->core.widget_class;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ManagerParentCancel\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ManagerParentCancel\n"));
 
     data.input_action.process_type = XmINPUT_ACTION;
     data.input_action.event = event;
@@ -1527,7 +1526,7 @@ _XmSocorro(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmAnyCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Inside _XmSocorro()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmSocorro()\n"));
 
     cbs.reason = XmCR_HELP;
     cbs.event = event;
@@ -1576,12 +1575,12 @@ _XmManagerEventHandler(Widget w,
     g = _XmInputForGadget(w, event->xmotion.x, event->xmotion.y);
     if (g == NULL)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "### _XmManagerEventHandler(gadget NULL)\n"));
     }
     else
     {
-	DEBUGOUT(XdbDebug2(__FILE__, w,
+	DEBUGOUT(_LtDebug2(__FILE__, w,
 			   (Widget)g, "### _XmManagerEventHandler()\n"));
     }
 
@@ -1621,7 +1620,7 @@ _XmManagerEventHandler(Widget w,
 
 	if (MGR_HighlightedWidget(w) != NULL)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w, "Sending LEAVE event to gadget\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "Sending LEAVE event to gadget\n"));
 	    _XmDispatchGadgetInput(MGR_HighlightedWidget(w),
 				   event,
 				   XmLEAVE_EVENT);
@@ -1644,7 +1643,7 @@ _XmManagerEventHandler(Widget w,
 
 	if (MGR_HighlightedWidget(w) == NULL)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w, "Sending ENTER event to gadget\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "Sending ENTER event to gadget\n"));
 
 	    _XmDispatchGadgetInput((Widget)g,
 				   event,
@@ -1657,14 +1656,14 @@ _XmManagerEventHandler(Widget w,
 	    if (MGR_HighlightedWidget(w) != (Widget)g)
 	    {
 
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "Sending LEAVE event to old gadget\n"));
 
 		_XmDispatchGadgetInput(MGR_HighlightedWidget(w),
 				       event,
 				       XmLEAVE_EVENT);
 
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "Sending ENTER event to new gadget\n"));
 
 		_XmDispatchGadgetInput((Widget)g,
@@ -1680,7 +1679,7 @@ _XmManagerEventHandler(Widget w,
 void
 _XmDestroyParentCallback(Widget w, XtPointer client, XtPointer call)
 {
-    DEBUGOUT(XdbDebug2("NEDIT", XtParent(w), w,
+    DEBUGOUT(_LtDebug2("NEDIT", XtParent(w), w,
 		       "%s:_XmDestroyParentCallback(%d)\n",
 		       __FILE__, __LINE__));
     XtDestroyWidget(XtParent(w));
@@ -1748,12 +1747,12 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
     XtActionProc act = NULL;
     Widget comp = (Widget)client_data;
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Got Accelerator key: type %d code %04x "
 		      "state %08x data %08x\n",
 		      event->type, event->xkey.keycode, event->xkey.state,
 		      client_data));
-    DEBUGOUT(XdbDebug("NMEM", w,
+    DEBUGOUT(_LtDebug("NMEM", w,
 		      "Got Accelerator key: type %d code %04x "
 		      "state %08x data %08x\n",
 		      event->type, event->xkey.keycode, event->xkey.state,
@@ -1762,16 +1761,16 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
     if (!XmIsManager(w) ||
 	(event->type != KeyPress && event->type != KeyRelease))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Bad match for event.  Not manager or bad event.\n"));
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		    "Got Accelerator key: code: %08x state: %08x cd %08x %s\n",
 		      event->xkey.keycode, event->xkey.state, comp,
 		      XtName(comp)));
-    DEBUGOUT(XdbDebug("NMEM", w,
+    DEBUGOUT(_LtDebug("NMEM", w,
 		    "Got Accelerator key: code: %08x state: %08x cd %08x %s\n",
 		      event->xkey.keycode, event->xkey.state, comp,
 		      XtName(comp)));
@@ -1801,7 +1800,7 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
     if (!comp->core.widget_class)
     {
 	_XmWarning(NULL, "XmManager _XmAcceleratorHandler: bad news!!!\n");
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmAcceleratorHandler: called for w=%s"
 			  " with invalid comp, ignoring\n",
 			  XtName(w)));
@@ -1820,7 +1819,7 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
      * --mu@trends.net, 1998.09.06 */
     if (!XtIsSensitive(comp))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			"_XmAcceleratorHandler: %s is insensitive, ignoring\n",
 			  XtName(comp)));
 	return;
@@ -1836,7 +1835,7 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 	{
 	    Cardinal num_params = 0;
 
-	    DEBUGOUT(XdbDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 			      "MATCH!!!! "
 			      "code %08x state %08x name: %s:%s mnem: %d\n",
 			      event->xkey.keycode, event->xkey.state,
@@ -1845,7 +1844,7 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 			      : "(nil)",
 			      comp ? XtName(comp) : "(nil)",
 			      MGR_KeyboardList(w)[i].isMnemonic));
-	    DEBUGOUT(XdbDebug("NMEM", w,
+	    DEBUGOUT(_LtDebug("NMEM", w,
 			      "MATCH!!!! "
 			      "code %08x state %08x name: %s:%s mnem: %d\n",
 			      event->xkey.keycode, event->xkey.state,
@@ -1857,35 +1856,57 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 
 	    /* Make sure XmGetPostedFromWidget works: ? */
 
+   /* amai: The following "if (act==NULL)" catches are just dumb
+            attempts to prevent some rare crashes, e.g. as seen with
+   	    NEdit. They really should be replaced by something better.
+   	    Actually the only confirmed crash location is the
+   	    first one, however I just decided to add a "full set"
+	    of checks here ...
+	    The _XmWarning()s should help us to get additional feedback
+	    on that issue!
+	    FIX ME ! */
+
 	    if (!MGR_KeyboardList(w)[i].isMnemonic || RC_Type(XtParent(comp)) == XmMENU_BAR ||
 		(MGR_KeyboardList(w)[i].isMnemonic && XtParent(comp) == RC_PopupPosted(w))
 		)
 	    {
-		DEBUGOUT(XdbDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
+		DEBUGOUT(_LtDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
 				   "menu showing\n"));
-		DEBUGOUT(XdbDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
+		DEBUGOUT(_LtDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
 				   "menu showing\n"));
 		if (XmIsPrimitive(MGR_KeyboardList(w)[i].component))
 		{
 		    act = PrimC_ArmAndActivate(XtClass(comp));
-
-		    (*act) (comp, event, NULL, &num_params);
+		    if (act==NULL) {
+                       _XmWarning(w, "%s:_XmAcceleratorHandler(%d) - act==NULL for %s", 
+		               __FILE__, __LINE__, comp->core.widget_class->core_class.class_name);
+		    } else {
+                       (*act) (comp, event, NULL, &num_params);
+		    }
 		}
 		else if (XmIsGadget(MGR_KeyboardList(w)[i].component))
 		{
 		    act = GC_ArmAndActivate(XtClass(comp));
-
-		    (*act) (comp, event, NULL, &num_params);
+		    if (act==NULL) {
+                       _XmWarning(w, "%s:_XmAcceleratorHandler(%d) - act==NULL for gadget", 
+		               __FILE__, __LINE__);
+	            } else {
+                       (*act) (comp, event, NULL, &num_params);
+		    }
 		}
 		else if (XmIsRowColumn(w))
 		{
 		    act = RCClass_ArmAndActivate(XtClass(comp));
-
-		    (*act) (comp, event, NULL, &num_params);
+		    if (act==NULL) {
+                       _XmWarning(w, "%s:_XmAcceleratorHandler(%d) - act==NULL for RowColumn", 
+		               __FILE__, __LINE__);
+		    } else {
+                       (*act) (comp, event, NULL, &num_params);
+		    }
 		}
 		else
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, MGR_KeyboardList(w)[i].component,
+		    DEBUGOUT(_LtDebug(__FILE__, MGR_KeyboardList(w)[i].component,
 				      "Not a widget/gadget\n"));
 
 		    XtCallActionProc(comp, "Activate", event, NULL, 0);
@@ -1895,9 +1916,9 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 	    }
 	    else
 	    {
-		DEBUGOUT(XdbDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
+		DEBUGOUT(_LtDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
 				   "menu is not showing\n"));
-		DEBUGOUT(XdbDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
+		DEBUGOUT(_LtDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
 				   "menu is not showing\n"));
 	    }
 
@@ -1931,7 +1952,7 @@ AddKeyboardEntry(Widget m, Widget w, XmKeyboardData *item)
 	{
 	    MGR_SizeKeyboardList(m) *= 2;
 	    MGR_KeyboardList(m) =
-		(XmKeyboardData *)XtRealloc((XtPointer)MGR_KeyboardList(m),
+		(XmKeyboardData *)XtRealloc((char *)MGR_KeyboardList(m),
 					    sizeof(XmKeyboardData) *
 					    MGR_SizeKeyboardList(m));
 	}
@@ -1956,12 +1977,12 @@ AddKeyboardEntry(Widget m, Widget w, XmKeyboardData *item)
 
     MGR_NumKeyboardEntries(m)++;
 
-    DEBUGOUT(XdbDebug(__FILE__, m,
+    DEBUGOUT(_LtDebug(__FILE__, m,
 		      "GrabKey: key %04x Sym: %04x modifiers %08x %s %s\n",
 		      item->key, item->keysym, item->modifiers,
 		      item->needGrab ? "Grabbing" : "Not Grabbing",
 		      item->isMnemonic ? "mnemonic" : "not mnemonic"));
-    DEBUGOUT(XdbDebug("NMEM", m,
+    DEBUGOUT(_LtDebug("NMEM", m,
 		      "GrabKey: key %04x Sym: %04x modifiers %08x %s %s\n",
 		      item->key, item->keysym, item->modifiers,
 		      item->needGrab ? "Grabbing" : "Not Grabbing",
@@ -2037,9 +2058,9 @@ _XmManagerInstallAccelerator(Widget m, Widget w, String s)
     unsigned int modifiers = 0;
     XmKeyboardData data;
 
-    DEBUGOUT(XdbDebug2(__FILE__, m, w,
+    DEBUGOUT(_LtDebug2(__FILE__, m, w,
 		       "_XmManagerInstallAccelerator(%s)\n", s));
-    DEBUGOUT(XdbDebug2("NMEM", m, w,
+    DEBUGOUT(_LtDebug2("NMEM", m, w,
 		       "_XmManagerInstallAccelerator(%s)\n", s));
 
     /* Do we really have an accelerator ? */
@@ -2078,7 +2099,7 @@ _XmManagerInstallAccelerator(Widget m, Widget w, String s)
     }
 
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmManagerInstallAccelerator found manager %s\n",
 		      XtName(mw)));
 
@@ -2160,8 +2181,8 @@ _XmManagerInstallMnemonic(Widget m, Widget w, KeySym mn)
 	return;
     }
 
-    DEBUGOUT(XdbDebug2(__FILE__, m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
-    DEBUGOUT(XdbDebug2("NMEM", m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
+    DEBUGOUT(_LtDebug2(__FILE__, m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
+    DEBUGOUT(_LtDebug2("NMEM", m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
 
     /* If we're dealing with the menu bar, store the stuff in the highest
      * manager widget that you can find (with all the accelerators) */
@@ -2193,8 +2214,8 @@ _XmManagerInstallMnemonic(Widget m, Widget w, KeySym mn)
 	    }
 	}
 
-	DEBUGOUT(XdbDebug2(__FILE__, mw, w, "Store mnemonic info\n"));
-	DEBUGOUT(XdbDebug2("NMEM", mw, w, "Store mnemonic info\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, mw, w, "Store mnemonic info\n"));
+	DEBUGOUT(_LtDebug2("NMEM", mw, w, "Store mnemonic info\n"));
 	m = mw;
     }
 
@@ -2256,18 +2277,18 @@ widget_navigable(Widget w)
 	    MGR_NavigationType(w) == XmEXCLUSIVE_TAB_GROUP ||
 	    (MGR_NavigationType(w) == XmTAB_GROUP && !_XmShellIsExclusive(w)))
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WidgetNavigable => XmDESCENDANTS_TAB_NAVIGABLE\n"));
 
 	    return XmDESCENDANTS_TAB_NAVIGABLE;
 	}
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WidgetNavigable => XmDESCENDANTS_NAVIGABLE\n"));
 
 	return XmDESCENDANTS_NAVIGABLE;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "WidgetNavigable => XmNOT_NAVIGABLE\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "WidgetNavigable => XmNOT_NAVIGABLE\n"));
 
     return XmNOT_NAVIGABLE;
 }
@@ -2277,7 +2298,7 @@ _XmManagerHighlightPixmapDefault(Widget w, int offset, XrmValue *value)
 {
     static Pixmap pixmap;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmManagerHighlightPixmapDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmManagerHighlightPixmapDefault\n"));
 
     pixmap = XmUNSPECIFIED_PIXMAP;
 
@@ -2296,7 +2317,7 @@ _XmManagerTopShadowPixmapDefault(Widget w, int offset, XrmValue *value)
 {
     static Pixmap pixmap;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmManagerTopShadowPixmapDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmManagerTopShadowPixmapDefault\n"));
 
     pixmap = XmUNSPECIFIED_PIXMAP;
 
