@@ -1,9 +1,9 @@
 /**
  *
- * $Id: MapEvent.c,v 1.15 2000/09/22 20:35:12 amai Exp $
+ * $Id: MapEvent.c,v 1.19 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MapEvent.c,v 1.15 2000/09/22 20:35:12 amai Exp $";
+static const char rcsid[] = "$Id: MapEvent.c,v 1.19 2001/07/27 18:51:56 dannybackx Exp $";
 
 /*
  * this code borrows heavily from TMparse.c.  The copyright there is as follows:
@@ -52,17 +52,18 @@ static const char rcsid[] = "$Id: MapEvent.c,v 1.15 2000/09/22 20:35:12 amai Exp
 #include <LTconfig.h>
 
 #include <ctype.h>
-#include <stdlib.h>    /* -> qsort() */
+#include <stdlib.h>
 #include <string.h>
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
-#include <XmI/DebugUtil.h>
 
 #define XK_MISCELLANY
 #define XK_LATIN1
 #include <X11/keysymdef.h>
 
+#include <XmI/DebugUtil.h>
+
 
 #define COLON	':'
 
@@ -1607,11 +1608,11 @@ ParseRepeat(String str, int *reps, Boolean *plus, Boolean *error)
     {
 	String start = str;
 	char repStr[7];
-	int len;
+	size_t len;
 
 	ScanNumeric(str);
 	len = (str - start);
-	if (len < sizeof repStr)
+	if (len < sizeof(repStr))
 	{
 	    memcpy(repStr, start, len);
 	    repStr[len] = '\0';
@@ -1768,7 +1769,7 @@ ParseEventSeq(String str, EventSeqPtr *eventSeqP, Boolean *error)
 static void
 PrintLateBindings(LateBindingsPtr late)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "LateBindings: knot: %d pair: %d, ref: %d KeySym %04x\n",
 		      late->knot, late->pair, late->ref_count, late->keysym));
 }
@@ -1776,15 +1777,15 @@ PrintLateBindings(LateBindingsPtr late)
 static void
 PrintEvent(Event *event)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "Event: modifiers: %08x modMask: %08x late: %p\n",
 		      event->modifiers, event->modifierMask,
 		      event->lateModifiers));
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "       eventType: %08x eventCode: %08x codeMask: %08x\n",
 		      event->eventType, event->eventCode,
 		      event->eventCodeMask));
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "       standard: %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "       standard: %d\n",
 		      event->standard));
 
     if (event->lateModifiers)
@@ -1798,7 +1799,7 @@ PrintEventSeq(EventSeqPtr evs)
 {
     EventSeqPtr tmp;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "EventSequence:\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "EventSequence:\n"));
     for (tmp = evs; tmp != NULL; tmp = tmp->next)
     {
 	PrintEvent(&evs->event);
@@ -1909,7 +1910,7 @@ _XmMapBtnEvent(String str, int *eventType,
 
     _XmTransParseInit();
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
 
     ParseEventSeq(str, &evs, &err);
 
@@ -1962,13 +1963,13 @@ _XmMapKeyEvent(String str, int *eventType,
 
     _XmTransParseInit();
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
 
     ParseEventSeq(str, &evs, &err);
 
     if (evs == NULL)
     {
-    	DEBUGOUT(XdbDebug(__FILE__, NULL, "MapKey got NULL sequence:\n"));
+    	DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got NULL sequence:\n"));
 	FreeEventSeq(evs);
 
 	return False;
@@ -1982,7 +1983,7 @@ _XmMapKeyEvent(String str, int *eventType,
     err = SetLateModifier(_XmGetDefaultDisplay(), evs);
     if (err)
     {
-    	DEBUGOUT(XdbDebug(__FILE__, NULL, "MapKey got err sequence:\n"));
+    	DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got err sequence:\n"));
 	FreeEventSeq(evs);
 
 	return False;
