@@ -1,9 +1,9 @@
 /**
  *
- * $Id: PanedW.c,v 1.48 2000/09/22 20:35:12 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/PanedW.c,v 1.52 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PanedW.c,v 1.48 2000/09/22 20:35:12 amai Exp $";
+static const char rcsid[] = "$Id: PanedW.c,v 1.52 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -416,7 +416,6 @@ static XmSyntheticResource constraint_syn_resources[] =
 
 static void SashAction(Widget w, XtPointer client_data, XtPointer call_data);
 
-/* *INDENT-OFF* */
 #if 0
 static CompositeClassExtensionRec panedWCompositeExt = {
     /* next_extension */  NULL,
@@ -533,7 +532,6 @@ XmPanedWindowClassRec xmPanedWindowClassRec = {
 	/* extension */ NULL,
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmPanedWindowWidgetClass = (WidgetClass)&xmPanedWindowClassRec;
@@ -574,6 +572,7 @@ ValidatePaneMin(Widget w)
     }
 }
 
+
 static void
 ValidatePaneMax(Widget w)
 {
@@ -593,6 +592,7 @@ ValidatePaneMax(Widget w)
     }
 }
 
+
 static Boolean
 AllPanesRealized(Widget w)
 {
@@ -623,6 +623,7 @@ class_initialize()
 }
 #endif
 
+
 static void
 class_part_initialize(WidgetClass widget_class)
 {
@@ -651,6 +652,7 @@ class_part_initialize(WidgetClass widget_class)
     _XmFastSubclassInit(widget_class, XmPANED_WINDOW_BIT);
 }
 
+
 static void
 CreateFlipGC(Widget w)
 {
@@ -666,11 +668,12 @@ CreateFlipGC(Widget w)
     PW_FlipGC(w) = XtGetGC(w, careabout, &gcv);
 }
 
+
 static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -680,7 +683,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     PW_StartY(new_w) = 0;
     PW_PaneCount(new_w) = 0;
@@ -697,11 +700,12 @@ initialize(Widget request, Widget new_w,
 						     PW_NumSlots(new_w));
 }
 
+
 static void
 constraint_initialize(Widget request, Widget new_w,
 		      ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug2(__FILE__, XtParent(new_w), new_w,
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w,
 		       "%s:constraint_initialize(%d) - %i args\n"
 		       "\trequest X %5i Y %5i W %5i H %5i\n"
 		       "\t  new_w X %5i Y %5i W %5i H %5i\n"
@@ -713,7 +717,7 @@ constraint_initialize(Widget request, Widget new_w,
 		       XtX(new_w), XtY(new_w),
 		       XtWidth(new_w), XtHeight(new_w),
 		       XtWidth(XtParent(new_w)), XtHeight(XtParent(new_w))));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     ValidatePaneMin(new_w);
     ValidatePaneMax(new_w);
@@ -739,6 +743,7 @@ destroy(Widget w)
     XtReleaseGC(w, PW_FlipGC(w));
 }
 
+
 static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
@@ -747,7 +752,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean redisplay = False;
     Arg argl[3];
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "PanedWindow set_values****************\n"));
 
     if (PW_SeparatorOn(new_w) != PW_SeparatorOn(old))
@@ -828,6 +833,7 @@ set_values(Widget old, Widget request, Widget new_w,
     return redisplay;
 }
 
+
 static void
 expose(Widget w, XEvent *event, Region region)
 {
@@ -853,6 +859,7 @@ expose(Widget w, XEvent *event, Region region)
     _XmRedisplayGadgets(w, event, region);
 }
 
+
 static Boolean
 constraint_set_values(Widget current, Widget request, Widget new_w,
 		      ArgList args, Cardinal *num_args)
@@ -861,7 +868,7 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
     Boolean redisplay = False;
     int i;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "PanedWindow constraint_set_values\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PanedWindow constraint_set_values\n"));
 
     if (!PWC_IsPane(current))
     {
@@ -926,17 +933,18 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
 	redisplay = True;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, pw,
+    DEBUGOUT(_LtDebug(__FILE__, pw,
 		      "constraint_set_values: after PreferredSize\n"));
     return redisplay;
 }
 
+
 static void
 resize(Widget w)
 {
     XtWidgetGeometry geo;
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "PanedWindow Resize (%d %d)\n",
 		      XtWidth(w), XtHeight(w)));
 
@@ -947,6 +955,7 @@ resize(Widget w)
     _XmPanedWLayout(w, NULL, NULL, &geo, NULL, NULL, NULL);
 }
 
+
 static void
 realize(Widget w,
 	XtValueMask *value_mask,
@@ -956,7 +965,7 @@ realize(Widget w,
     XtWidgetGeometry geo;
     */
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
     	__FILE__, __LINE__,
     	XtWidth(w), XtHeight(w)));
 
@@ -1008,13 +1017,14 @@ panedw_insert_position(Widget w)
     return PWC_PositionIndex(w);
 }
 
+
 static void
 insert_child(Widget w)
 {
     XmPanedWindowWidget pw = (XmPanedWindowWidget)XtParent(w);
     int i;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:insert_child(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:insert_child(%d)\n",
 		      __FILE__, __LINE__));
 
     if (PW_RecursivelyCalled(pw))
@@ -1076,6 +1086,7 @@ insert_child(Widget w)
     PW_RecursivelyCalled(pw) = False;
 }
 
+
 static void
 delete_child(Widget w)
 {
@@ -1092,14 +1103,15 @@ delete_child(Widget w)
 #undef superclass
 }
 
+
 #if 0
 static XtGeometryResult
 query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *desired)
 {
     /* Motif does not have this method! */
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "QueryGeometry (request %s)\n",
-		      XdbWidgetGeometry2String(proposed)));
+		      _LtDebugWidgetGeometry2String(proposed)));
 
     _XmPanedWPreferredSize(w, NULL, NULL, desired);
 
@@ -1132,6 +1144,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *desired)
 }
 #endif
 
+
 static XtGeometryResult
 geometry_manager(Widget w,
 		 XtWidgetGeometry *request,
@@ -1142,17 +1155,17 @@ geometry_manager(Widget w,
     Widget pw = XtParent(w);
     XmKidGeometry boxes = NULL, sashes = NULL, seps = NULL;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "PanedW: geometry manager\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PanedW: geometry manager\n"));
 
     if (AllPanesRealized(pw))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "All panes realized in geom_manager\n"));
     }
 
     if (AllPanesRealized(pw) && !PWC_AllowResize(w) && XtIsManaged(pw))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Not allowing resize from geom_manager\n"));
 
 	return XtGeometryNo;
@@ -1167,7 +1180,7 @@ geometry_manager(Widget w,
 
     want = *request;
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "geom_mgr: child %s wants %d %d\n", XtName(w),
 		      request->width, request->height));
 
@@ -1175,7 +1188,7 @@ geometry_manager(Widget w,
 
     if (_XmMakeGeometryRequest(pw, &geo) == XtGeometryYes)
     {
-	DEBUGOUT(XdbDebug(__FILE__, pw,
+	DEBUGOUT(_LtDebug(__FILE__, pw,
 			  "We wanted %d %d and we got it\n",
 			  geo.width, geo.height));
     }
@@ -1183,7 +1196,7 @@ geometry_manager(Widget w,
     {
 	geo.width = XtWidth(pw);
 	geo.height = XtHeight(pw);
-	DEBUGOUT(XdbDebug(__FILE__, pw,
+	DEBUGOUT(_LtDebug(__FILE__, pw,
 			  "We didn't get our request, but %d %d\n",
 			  geo.width, geo.height));
     }
@@ -1219,7 +1232,7 @@ geometry_manager(Widget w,
 	    PWC_DHeight(w) = want.height;
 	}
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Child wanted %d and that's ok\n", want.height));
 
 	_XmSetKidGeo(boxes, w);
@@ -1239,19 +1252,20 @@ geometry_manager(Widget w,
 
     if (good == 0)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Child wanted %d (NO)\n", want.height));
 	return XtGeometryNo;
     }
     else
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Child wanted %d (ALMOST)\n", want.height));
 	return XtGeometryAlmost;
     }
 #undef Wants
 }
 
+
 static int
 pi_sort(const void *a, const void *b)
 {
@@ -1261,17 +1275,18 @@ pi_sort(const void *a, const void *b)
     return PWC_PositionIndex(wa) - PWC_PositionIndex(wb);
 }
 
+
 static void
 change_managed(Widget w)
 {
     int i, j;
     XtWidgetGeometry geo;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "PanedWindow change_managed\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PanedWindow change_managed\n"));
 
     if (PW_RecursivelyCalled(w))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "ChangeManaged was recursively called\n"));
 	return;
     }
@@ -1332,7 +1347,7 @@ change_managed(Widget w)
 
 		PW_PaneCount(w)++;
 
-		DEBUGOUT(XdbDebug(__FILE__, MGR_Children(w)[i],
+		DEBUGOUT(_LtDebug(__FILE__, MGR_Children(w)[i],
 				  "Setting DHeight in change_managed to %d:"
 				  " was %d\n",
 				  XtHeight(MGR_Children(w)[i]),
@@ -1343,7 +1358,7 @@ change_managed(Widget w)
 		{
 		    PW_NumSlots(w) *= 2;
 		    PW_ManagedChildren(w) =
-			(WidgetList)XtRealloc((void *)PW_ManagedChildren(w),
+			(WidgetList)XtRealloc((char *)PW_ManagedChildren(w),
 					      sizeof(Widget) * PW_NumSlots(w));
 		}
 
@@ -1417,7 +1432,7 @@ change_managed(Widget w)
 	    CoreConstraints(PW_ManagedChildren(w)[PW_NumManagedChildren(w) - 1]);
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Compute size in change_managed\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Compute size in change_managed\n"));
 
     _XmPanedWPreferredSize(w, NULL, NULL, &geo);
 
@@ -1435,6 +1450,7 @@ change_managed(Widget w)
     _XmNavigChangeManaged(w);
 }
 
+
 #if 0
 static Boolean
 traversal_children(Widget mw, Widget **children, Cardinal *num_children)
@@ -1470,7 +1486,8 @@ traversal_children(Widget mw, Widget **children, Cardinal *num_children)
 
     return True;
 }
-#endif
+#endif /* #if 0*/
+
 
 static void
 _XmPanedWPreferredSize(Widget w, Widget rchild,
@@ -1480,7 +1497,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
     int i;
     Dimension curw, curh;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmPanedWPreferredSize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmPanedWPreferredSize\n"));
 
     /* Find widest child and compute total height of PanedWindow */
     curw = curh = 0;
@@ -1489,7 +1506,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
 
 	child = PW_ManagedChildren(w)[i];
 
-	DEBUGOUT(XdbDebug2(__FILE__, w, child,
+	DEBUGOUT(_LtDebug2(__FILE__, w, child,
 			   "_XmPanedWPreferredSize: child wid %d ht %d "
 			   "pref.ht. %d panemin %d panemax %d\n",
 			   XtWidth(child), XtHeight(child),
@@ -1499,7 +1516,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
 	if (rchild != NULL && child == rchild && childgeom != NULL &&
 	    childgeom->request_mode & CWWidth)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w, "Using childgeom width: %d\n",
+	    DEBUGOUT(_LtDebug(__FILE__, w, "Using childgeom width: %d\n",
 			      childgeom->width));
 	    curw = curw >= childgeom->width ? curw : childgeom->width;
 	}
@@ -1516,7 +1533,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
 	if (rchild != NULL && child == rchild && childgeom != NULL &&
 	    childgeom->request_mode & CWHeight)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w, "Using childgeom height: %d\n",
+	    DEBUGOUT(_LtDebug(__FILE__, w, "Using childgeom height: %d\n",
 			      childgeom->height));
 	    curh += _XmMax(childgeom->height, PWC_PaneMinimum(child));
 	}
@@ -1529,7 +1546,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
     curh += 2 * PW_MarginHeight(w);
     curw += 2 * PW_MarginWidth(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmPanedWPreferredSize: computed %d %d\n",
 		      curw, curh));
 
@@ -1538,6 +1555,7 @@ _XmPanedWPreferredSize(Widget w, Widget rchild,
     pwg->request_mode = CWWidth | CWHeight;
 }
 
+
 static void
 _XmPanedWLayout(Widget w, Widget rchild,
 		XtWidgetGeometry *childgeom, XtWidgetGeometry *pwg,
@@ -1745,6 +1763,7 @@ _XmPanedWLayout(Widget w, Widget rchild,
     }
 }
 
+
 static void
 MoveBorder(Widget pw, Widget sash, int dy)
 {
@@ -1769,14 +1788,14 @@ MoveBorder(Widget pw, Widget sash, int dy)
 	/* Move up? */
 	if (dy < 0)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, pw,
+	    DEBUGOUT(_LtDebug(__FILE__, pw,
 			      "Move up: %d %d %d %d %d\n",
 			      PWC_DHeight(panea), dy, PWC_PaneMaximum(panea),
 			      PWC_DHeight(paneb), PWC_PaneMinimum(paneb)));
 
 	    if ((XtHeight(paneb) - dy) < PWC_PaneMaximum(paneb))
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, paneb, "Widget can grow\n"));
+		DEBUGOUT(_LtDebug(__FILE__, paneb, "Widget can grow\n"));
 
 		/*
 		 * can panea absorb the change?  If so, then adjust paneb's
@@ -1784,7 +1803,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		if ((XtHeight(panea) + dy) > PWC_PaneMinimum(panea))
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, panea,
+		    DEBUGOUT(_LtDebug(__FILE__, panea,
 				      "Widget can shrink to compensate\n"));
 
 		    cons = PW_BottomPane(pw);
@@ -1812,7 +1831,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		else if (XtHeight(panea) > PWC_PaneMinimum(panea))
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, panea,
+		    DEBUGOUT(_LtDebug(__FILE__, panea,
 				      "Widget can partially compensate\n"));
 
 		    dy += XtHeight(panea) - PWC_PaneMinimum(panea);
@@ -1840,7 +1859,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		    sash = PWC_Sash(PW_ManagedChildren(pw)[PWC_Position(panea) - 1]);
 		    panea = PWC_Sash(sash);
 
-		    DEBUGOUT(XdbDebug(__FILE__, paneb,
+		    DEBUGOUT(_LtDebug(__FILE__, paneb,
 				      "And we'll try to pass it off\n"));
 
 		    PW_TopPane(pw) = (XmPanedWindowConstraintPtr)
@@ -1851,7 +1870,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		else
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, pw,
+		    DEBUGOUT(_LtDebug(__FILE__, pw,
 				      "No more panes above\n"));
 		    return;
 		}
@@ -1868,7 +1887,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		    sash = PWC_Sash(paneb);
 		    paneb = PW_ManagedChildren(pw)[PWC_Position(PWC_Sash(sash)) + 1];
 
-		    DEBUGOUT(XdbDebug(__FILE__, paneb,
+		    DEBUGOUT(_LtDebug(__FILE__, paneb,
 				      "And we'll try to pass it off\n"));
 
 		    PW_BottomPane(pw) = (XmPanedWindowConstraintPtr)
@@ -1876,7 +1895,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		}
 		else
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, paneb, "Can't grow\n"));
+		    DEBUGOUT(_LtDebug(__FILE__, paneb, "Can't grow\n"));
 		    return;
 		}
 	    }
@@ -1884,7 +1903,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 	/* move down? */
 	else if (dy > 0)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, pw,
+	    DEBUGOUT(_LtDebug(__FILE__, pw,
 			      "Move down: %d %d %d %d %d\n",
 			      PWC_DHeight(panea), dy, PWC_PaneMaximum(panea),
 			      PWC_DHeight(paneb), PWC_PaneMinimum(paneb)));
@@ -1892,7 +1911,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 	    /* can panea grow? */
 	    if ((XtHeight(panea) + dy) < PWC_PaneMaximum(panea))
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, panea, "Pane can grow\n"));
+		DEBUGOUT(_LtDebug(__FILE__, panea, "Pane can grow\n"));
 
 		/*
 		 * can paneb absorb the change?  If so, increate panea's
@@ -1900,7 +1919,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		if ((XtHeight(paneb) - dy) > PWC_PaneMinimum(paneb))
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, paneb,
+		    DEBUGOUT(_LtDebug(__FILE__, paneb,
 				  "And this pane can shrink to compensate\n"));
 
 		    XtHeight(paneb) -= dy;
@@ -1928,7 +1947,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		else if (XtHeight(paneb) > PWC_PaneMinimum(paneb))
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, paneb,
+		    DEBUGOUT(_LtDebug(__FILE__, paneb,
 				  "And this pane can partially compensate\n"));
 
 		    dy -= XtHeight(paneb) - PWC_PaneMinimum(paneb);
@@ -1957,7 +1976,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		    sash = PWC_Sash(paneb);
 		    paneb = PW_ManagedChildren(pw)[PWC_Position(PWC_Sash(sash)) + 1];
 
-		    DEBUGOUT(XdbDebug(__FILE__, paneb,
+		    DEBUGOUT(_LtDebug(__FILE__, paneb,
 				      "And we'll try to pass it off\n"));
 
 		    PW_BottomPane(pw) = (XmPanedWindowConstraintPtr)
@@ -1968,7 +1987,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		 */
 		else
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, pw, "No more panes below\n"));
+		    DEBUGOUT(_LtDebug(__FILE__, pw, "No more panes below\n"));
 		    return;
 		}
 	    }
@@ -1984,7 +2003,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		    sash = PWC_Sash(PW_ManagedChildren(pw)[PWC_Position(panea) - 1]);
 		    panea = PWC_Sash(sash);
 
-		    DEBUGOUT(XdbDebug(__FILE__, paneb,
+		    DEBUGOUT(_LtDebug(__FILE__, paneb,
 				      "And we'll try to pass it off\n"));
 
 		    PW_TopPane(pw) = (XmPanedWindowConstraintPtr)
@@ -1992,7 +2011,7 @@ MoveBorder(Widget pw, Widget sash, int dy)
 		}
 		else
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, panea, "Pane can't grow\n"));
+		    DEBUGOUT(_LtDebug(__FILE__, panea, "Pane can't grow\n"));
 
 		    return;
 		}
@@ -2001,13 +2020,14 @@ MoveBorder(Widget pw, Widget sash, int dy)
 	/* no motion, bail out */
 	else
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, pw, "No motion\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, pw, "No motion\n"));
 
 	    return;
 	}
     }
 }
 
+
 static void
 SashAction(Widget w, XtPointer client_data, XtPointer call_data)
 {
@@ -2043,7 +2063,7 @@ SashAction(Widget w, XtPointer client_data, XtPointer call_data)
 
 	    }
 
-	    DEBUGOUT(XdbDebug(__FILE__, child,
+	    DEBUGOUT(_LtDebug(__FILE__, child,
 			      "SashAction places child %dx%d, size %d/%d\n",
 			      XtX(child), PWC_DY(child),
 			      XtWidth(child), XtHeight(child)));
@@ -2083,7 +2103,7 @@ SashAction(Widget w, XtPointer client_data, XtPointer call_data)
 		sash = PWC_Sash(child);
 		if (sash)
 		{
-		    DEBUGOUT(XdbDebug(__FILE__, pw,
+		    DEBUGOUT(_LtDebug(__FILE__, pw,
 				      "moving sash to : %d %d w = %d h = %d\n",
 				      XtWidth(pw) - PW_MarginWidth(pw) +
 				      PW_SashIndent(pw) - PW_SashWidth(pw),
