@@ -1,9 +1,9 @@
 /**
  *
- * $Id: PushB.c,v 1.77 2000/09/23 15:05:24 amai Exp $
+ * $Id: PushB.c,v 1.81 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PushB.c,v 1.77 2000/09/23 15:05:24 amai Exp $";
+static const char rcsid[] = "$Id: PushB.c,v 1.81 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -352,8 +352,8 @@ class_initialize(void)
     _XmPushBCoreClassExtRec.record_type = XmQmotif;
 
 #if XmVERSION > 1
-	if (! XmeTraitSet(xmPushButtonWidgetClass, XmQTactivatable,
-			&_XmPushBTraitRec)) {
+	if (! XmeTraitSet((XtPointer)xmPushButtonWidgetClass, XmQTactivatable,
+			(XtPointer)&_XmPushBTraitRec)) {
 		_XmWarning(NULL,
 			"XmPushButton ClassInitialize: XmeTraitSet failed\n");
 	}
@@ -450,7 +450,7 @@ initialize(Widget request, Widget new_w,
 {
     Dimension margin, width, height;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -459,7 +459,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     /* check the RepType resources */
     if (PB_MultiClick(new_w) == (unsigned char)XmUNSPECIFIED ||
@@ -572,7 +572,7 @@ initialize(Widget request, Widget new_w,
 	    XtWidth(request) = XtWidth(new_w);
 #endif
 
-	    DEBUGOUT(XdbDebug(__FILE__, new_w,
+	    DEBUGOUT(_LtDebug(__FILE__, new_w,
 			      "adjust margins for default button\n"
 			      "\trequest X %5i Y %5i W %5i H %5i\n"
 			      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -606,7 +606,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh_needed = False;
     Dimension margin, width, height;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -618,7 +618,7 @@ set_values(Widget old, Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     /* check the RepType resources */
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRMultiClick),
@@ -834,7 +834,7 @@ expose(Widget w, XEvent *event, Region region)
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "PB expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PB expose\n"));
 
     if (!IN_MENU(w))
     {
@@ -843,7 +843,7 @@ expose(Widget w, XEvent *event, Region region)
 	    inset += Xm3D_ENHANCE_PIXEL + Lab_Shadow(w)
 		  + (PB_DefaultButtonShadow(w) << 1);
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "x %d y %d w %d h %d b %d\n",
 			  inset, inset,
 			  (XtWidth(w) - (inset << 1)),
@@ -1019,8 +1019,8 @@ Activate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     XButtonEvent *ev = (XButtonEvent *)event;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Activate()\n"));
-    DEBUGOUT(XdbDebug("ENTRY", w, "Activate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Activate()\n"));
+    DEBUGOUT(_LtDebug("ENTRY", w, "Activate()\n"));
 
     /*
      * This test also broke Accelerators. Refined as well.
@@ -1108,7 +1108,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
 {
     Widget w = (Widget)data;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmTimeout\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmTimeout\n"));
 
     PB_Timer(w) = 0;
 
@@ -1125,8 +1125,8 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     Boolean poppedUp;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndActivate\n"));
-    DEBUGOUT(XdbDebug("MENU", w, "%s:ArmAndActivate(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ArmAndActivate(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1196,8 +1196,8 @@ EnterWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "PushB Enter\n"));
-    DEBUGOUT(XdbDebug("MENU", w, "%s:EnterWindow(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "PushB Enter\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:EnterWindow(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1245,8 +1245,8 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "LeaveWindow()\n"));
-    DEBUGOUT(XdbDebug("MENU", w, "%s:LeaveWindow(%d) - %s %s %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "LeaveWindow()\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:LeaveWindow(%d) - %s %s %s\n",
     	__FILE__, __LINE__,
     	IN_MENU(w) ? "menu" : "no-menu",
     	IN_MENU(w) && _XmGetInDragMode(w) ? "dragging" : "not-dragging",
@@ -1300,9 +1300,9 @@ ButtonUp(Widget w,
     Boolean validButton, poppedUp;
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s(%d) - ButtonUp()\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s(%d) - ButtonUp()\n",
     	__FILE__, __LINE__));
-    DEBUGOUT(XdbDebug("MENU", w, "%s:ButtonUp(%d)\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ButtonUp(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1317,9 +1317,9 @@ ButtonUp(Widget w,
     {
 	validButton = False;
     }
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s(%d):ButtonUp() - valid %s %ix%i\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s(%d):ButtonUp() - valid %s %ix%i\n",
     	__FILE__, __LINE__,
-    	XdbBoolean2String(validButton),
+    	_LtDebugBoolean2String(validButton),
     	event->xbutton.x, event->xbutton.y));
 
     if (!validButton)
@@ -1385,8 +1385,8 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     Boolean poppedUp;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ButtonDown()\n"));
-    DEBUGOUT(XdbDebug("MENU", w, "%s:ButtonDown(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonDown()\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ButtonDown(%d)\n",
     	__FILE__, __LINE__
     	));
     /* queue events until the next button event */
@@ -1398,7 +1398,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
 	if (!validButton)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w, "ButtonDown() - Invalid button\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonDown() - Invalid button\n"));
 	    return;
 	}
     }
@@ -1407,7 +1407,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
     RC_MenuShellPopdown(w, event, &poppedUp);
     {
-    int i;
+    Cardinal i;
     Widget menu = XtParent(w);
 
 	for (i = 0; i < MGR_NumChildren(menu); i++)
@@ -1453,7 +1453,7 @@ MultiActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XButtonEvent *ev = (XButtonEvent *)event;
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "PushB: MultiClick\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PushB: MultiClick\n"));
 
     if (PB_MultiClick(w) == XmMULTICLICK_KEEP)
     {
@@ -1503,7 +1503,7 @@ MultiActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 MultiArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "PushB: MultiArm\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PushB: MultiArm\n"));
 
     if (PB_MultiClick(w) == XmMULTICLICK_KEEP)
 	Arm(w, event, NULL, NULL);
@@ -1512,7 +1512,7 @@ MultiArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 KeySelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "KeySelect\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KeySelect\n"));
 
     /* FIX ME */
 }
