@@ -1,9 +1,9 @@
 /**
  *
- * $Id: PushBG.c,v 1.82 2000/09/22 20:35:12 amai Exp $
+ * $Id: PushBG.c,v 1.87 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PushBG.c,v 1.82 2000/09/22 20:35:12 amai Exp $";
+static const char rcsid[] = "$Id: PushBG.c,v 1.87 2001/07/27 18:51:57 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -426,9 +426,9 @@ secondary_object_create(Widget request, Widget new_w,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "PushBGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -521,8 +521,8 @@ class_initialize(void)
     xmPushButtonGCacheObjClassRec.object_class.num_resources = ncom;
 
 #if XmVERSION > 1
-    if (! XmeTraitSet(xmPushButtonGadgetClass, XmQTactivatable,
-		&_XmPushBGTraitRec)) {
+    if (! XmeTraitSet((XtPointer)xmPushButtonGadgetClass, XmQTactivatable,
+		(XtPointer)&_XmPushBGTraitRec)) {
 	_XmWarning(NULL,
 	    "XmPushButtonGadget ClassInitialize: XmeTraitSet failed\n");
     }
@@ -593,7 +593,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "PushBG InitializePrehook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG InitializePrehook\n"));
 }
 #endif
 
@@ -603,7 +603,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "PushBG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -760,7 +760,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -868,7 +868,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh_needed = False;
     Dimension margin, width, height;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -880,7 +880,7 @@ set_values(Widget old, Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     if (new_w->core.being_destroyed)
     {
@@ -1071,7 +1071,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1129,7 +1129,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "GetValuesHook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "GetValuesHook\n"));
 }
 #endif
 
@@ -1138,7 +1138,7 @@ expose(Widget w, XEvent *event, Region region)
 {
     Dimension inset;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "PBG expose: XY %d %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "PBG expose: XY %d %d\n",
 		      XtX(w), XtY(w)));
 
     if (!IN_MENU(w))
@@ -1148,7 +1148,7 @@ expose(Widget w, XEvent *event, Region region)
 	    inset += Xm3D_ENHANCE_PIXEL + LabG_Shadow(w)
 		+ (PBG_DefaultButtonShadow(w) << 1);
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "x %d y %d w %d h %d b %d\n",
 			  inset, inset,
 			  (XtWidth(w) - (inset << 1)),
@@ -1335,8 +1335,8 @@ Activate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     XButtonEvent *ev = (XButtonEvent *)event;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Activate\n"));
-    DEBUGOUT(XdbDebug("MENU", w, "%s:Activate(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Activate\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:Activate(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1391,7 +1391,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
 {
     Widget w = (Widget)data;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmTimeout\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmTimeout\n"));
 
     PBG_Timer(w) = 0;
 
@@ -1408,8 +1408,8 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     Boolean poppedUp;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndActivate\n"));
-    DEBUGOUT(XdbDebug("MENU", w, "%s:ArmAndActivate(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ArmAndActivate(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1472,8 +1472,8 @@ EnterWindow(Widget w,
 {
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "EnterWindow()\n"));
-    DEBUGOUT(XdbDebug("MENU", w, "%s:EnterWindow(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "EnterWindow()\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:EnterWindow(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1517,7 +1517,7 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug("MENU", w, "%s:LeaveWindow(%d) - %s %s %s\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:LeaveWindow(%d) - %s %s %s\n",
     	__FILE__, __LINE__,
     	IN_MENU(w) ? "menu" : "no-menu",
     	IN_MENU(w) && _XmGetInDragMode(w) ? "dragging" : "not-dragging",
@@ -1568,9 +1568,9 @@ ButtonUp(Widget w, XEvent *event, String *params, Cardinal *num_params)
     Boolean validButton, poppedUp;
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ButtonUp()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonUp()\n"));
 
-    DEBUGOUT(XdbDebug("MENU", w, "%s:ButtonUp(%d)\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ButtonUp(%d)\n",
     	__FILE__, __LINE__
     	));
     /* queue events until the next button event */
@@ -1646,7 +1646,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     Boolean poppedUp;
 
-    DEBUGOUT(XdbDebug("MENU", w, "%s:ButtonDown(%d)\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ButtonDown(%d)\n",
     	__FILE__, __LINE__
     	));
     /* queue events until the next button event */
@@ -1665,7 +1665,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
     RC_MenuShellPopdown(w, event, &poppedUp);
     {
-    int i;
+    Cardinal i;
     Widget menu = XtParent(w);
 
 	for (i = 0; i < MGR_NumChildren(menu); i++)
@@ -1734,7 +1734,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     switch (event_mask)
     {
     case XmARM_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got arm event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got arm event\n"));
 	if (IN_MENU(gadget))
 	{
 	    ButtonDown(gadget, event, NULL, &num_params);
@@ -1760,7 +1760,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmACTIVATE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got activate event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got activate event\n"));
 	/*
 	 * The test below is expanded so it also checks for the Shell.
 	 * In tearoff menus, the shell will be a TransientShell, thus we'll
@@ -1796,17 +1796,17 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmENTER_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got an enter window\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got an enter window\n"));
 	EnterWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmLEAVE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got a leave window\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got a leave window\n"));
 	LeaveWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmMOTION_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "got a motion event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got a motion event\n"));
 	break;
 
     case XmFOCUS_IN_EVENT:
