@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ResConvert.c,v 1.68 2000/12/03 00:12:11 dannybackx Exp $
+ * $Id: ResConvert.c,v 1.77 2001/08/05 09:25:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ResConvert.c,v 1.68 2000/12/03 00:12:11 dannybackx Exp $";
+static const char rcsid[] = "$Id: ResConvert.c,v 1.77 2001/08/05 09:25:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -43,13 +43,10 @@ static const char rcsid[] = "$Id: ResConvert.c,v 1.68 2000/12/03 00:12:11 dannyb
 #include <Xm/ExtObjectP.h>
 #include <Xm/XmosP.h>
 
-#include <XmI/DebugUtil.h>
-
 #include "LTmisc.h"
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
+#include <XmI/DebugUtil.h>
+
 
 enum
 {
@@ -110,7 +107,7 @@ static Boolean _XmCvtStringToRenderTable(Display *display, XrmValue *args,
 #endif
 
 
-int	xmUseVersion = 0;
+int xmUseVersion = 0;
 
 /* please be careful if you're editting these arrays, as
  * the strings have to be in the _same_ order as the
@@ -544,12 +541,13 @@ static char *spb_arrow_layouts[] =
 
 static unsigned char spb_arrow_layout_values[] =
 {
-    XmARROWS_BEGINNING,
     XmARROWS_END,
-    XmARROWS_SPLIT
+    XmARROWS_BEGINNING,
+    XmARROWS_SPLIT,
+    XmARROWS_FLAT_END,
+    XmARROWS_FLAT_BEGINNING
 };
 
-#if XmVERSION > 1
 /* Notebook */
 static char *nb_child_types[] =
 {
@@ -570,7 +568,6 @@ static unsigned char nb_child_type_values[] =
     XmSTATUS_AREA, 
     XmPAGE_SCROLLER
 };
-#endif
 
 static char *indicator_on[] =
 {
@@ -608,7 +605,7 @@ static unsigned char indicator_on_values[] =
     XmINDICATOR_FILL,		/* yes */
 };
 
-#endif
+#endif /* XmVERSION > 1 */
 
 
 extern void
@@ -659,10 +656,6 @@ _XmRegisterConverters(void)
 	    0
 	}};
 
-#ifdef NONSTANDARD_CONVERTERS
-    extern void _XmRegisterNSEConverters(void);
-#endif
-
     if (first)
     {
 	first = False;
@@ -1040,7 +1033,7 @@ _XmError(Widget w, const char *fmt, ...)
 /*
  * Warning convenience
  *
- * Added XdbDebug stuff here to be able to avoid infinite loops in applications
+ * Added _LtDebug stuff here to be able to avoid infinite loops in applications
  * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
  * bugs of cource :-(
  */
@@ -1092,7 +1085,7 @@ _LtWarning(Widget w, const char *fmt, va_list arg_list)
 
 	if (redirect)
 	{
-	    XdbPrintString(buf);
+	    _LtDebugPrintString(buf);
 	}
 	else
 	{
@@ -1111,7 +1104,7 @@ _LtWarning(Widget w, const char *fmt, va_list arg_list)
 
 	if (redirect)
 	{
-	    XdbPrintString(buf);
+	    _LtDebugPrintString(buf);
 	}
 	else
 	{
@@ -1123,15 +1116,17 @@ _LtWarning(Widget w, const char *fmt, va_list arg_list)
 /*
  * Warning convenience
  *
- * Added XdbDebug stuff here to be able to avoid infinite loops in applications
+ * Added _LtDebug stuff here to be able to avoid infinite loops in applications
  * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
- * bugs of cource :-(
+ * bugs of course :-(
  */
 
 /* unshadow for the Motif 2.x build */
+#if XmVERSION >= 2
 #ifdef _XmWarning
 #undef _XmWarning
 #endif
+#endif
 
 extern void
 _XmWarning(Widget w, const char *fmt, ...)
@@ -1197,7 +1192,7 @@ XmCvtXmStringToCT(XmString string)
     XmStringDirection direction;
     Boolean separator;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmCvtXmStringToCT\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmCvtXmStringToCT\n"));
 
     if (XmStringInitContext(&context, string) == True)
     {
@@ -1301,7 +1296,7 @@ XmCvtXmStringToText(Display *display, XrmValuePtr args,
     to_val->addr = value;
     to_val->size = strlen(value);  /* FIXME: should this be sizeof(value)? */
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "XmCvtXmStringToText(%p) => %s\n",
 		      from_val->addr, to_val->addr));
 
@@ -1540,7 +1535,7 @@ _XmCvtStringToXmString(Display *display,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XtPointer)&newString;
+	    to->addr = (XPointer)&newString;
 	    to->size = sizeof(XmString);
 	}
 	else
@@ -1563,7 +1558,7 @@ _XmCvtStringToXmString(Display *display,
 					 XmRXmString);
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmCvtStringToXmString(%s) => %p\n",
 		      from->addr, to->addr));
 
@@ -1591,7 +1586,7 @@ __XmFontListResourceAddEntry(Display *display,
     XmFontListEntry newEntry;
     char *eq, *end, *fn, *ft, *tag, *font, *semi, *colon;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "__XmFontListResourceAddEntry(%s)\n", full_entry));
 
     eq = strchr(full_entry, (int)'=');
@@ -1827,7 +1822,7 @@ _XmCvtStringToXmFontList(Display *display,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XtPointer)&newFontList;
+	    to->addr = (XPointer)&newFontList;
 	    to->size = sizeof(XmFontList);
 	}
 	else
@@ -1949,7 +1944,7 @@ _XmCvtStringToCardinal(Display *display,
 	{
 		if (to->addr == NULL)
 		{
-			to->addr = (XtPointer)&value;
+			to->addr = (XPointer)&value;
 			to->size = sizeof(Cardinal);
 		}
 		else
@@ -1989,7 +1984,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XtPointer)&k;
+	    to->addr = (XPointer)&k;
 	    to->size = sizeof(k);
 	    return True;
 	}
@@ -2005,7 +2000,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
 	    {
 		XtDisplayStringConversionWarning(d, (char *)from->addr,
 						 XmRKeySym);
-		DEBUGOUT(XdbDebug(__FILE__, NULL,
+		DEBUGOUT(_LtDebug(__FILE__, NULL,
 				  "_XmCvtStringToKeySym fail at line %d\n",
 				  __LINE__));
 		return False;
@@ -2015,7 +2010,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
 
     XtDisplayStringConversionWarning(d, (char *)from->addr, XmRKeySym);
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmCvtStringToKeySym fail at line %d\n", __LINE__));
     return False;
 }
@@ -2045,7 +2040,7 @@ _XmCvtStringToResIndPosition(Display *display,
 
     if (to->addr == NULL)
     {
-	to->addr = (XtPointer)&pos;
+	to->addr = (XPointer)&pos;
 	to->size = sizeof pos;
     }
     else
@@ -2089,7 +2084,7 @@ _XmCvtStringToResIndDimension(Display *display,
 
     if (to->addr == NULL)
     {
-	to->addr = (XtPointer)&dim;
+	to->addr = (XPointer)&dim;
 	to->size = sizeof dim;
     }
     else
@@ -2133,7 +2128,7 @@ _XmCvtStringToResIndInt(Display *display,
 
     if (to->addr == NULL)
     {
-	to->addr = (XtPointer)&pos;
+	to->addr = (XPointer)&pos;
 	to->size = sizeof pos;
     }
     else
@@ -2181,7 +2176,7 @@ _XmCvtStringToWidget(	Display *display,
 
 	if (to->addr == NULL)
 	{
-	    to->addr = (XtPointer)&child;
+	    to->addr = (XPointer)&child;
 	    to->size = sizeof(Widget);
 	}
 	else
@@ -2282,7 +2277,7 @@ _XmCvtStringToBooleanDimension( Display *display,
 	}
 
 	if (to->addr == NULL) {
-	    to->addr = (XtPointer)&value;
+	    to->addr = (XPointer)&value;
 	    to->size = sizeof(value);
 	} else {
 	    if (to->size >= sizeof(value)) {
@@ -2342,7 +2337,7 @@ _XmCvtStringToTextPosition( Display *display,
 
     tp = atol( from->addr);
     if (to->addr == NULL) {
-	to->addr = (XtPointer)&tp;
+	to->addr = (XPointer)&tp;
 	to->size = sizeof tp;
     } else {
 	if (to->size < sizeof tp) {
@@ -2370,7 +2365,7 @@ _XmCvtStringToTopItemPosition( Display *display,
 
     tip = atoi( from->addr);
     if (to->addr == NULL) {
-	to->addr = (XtPointer)&tip;
+	to->addr = (XPointer)&tip;
 	to->size = sizeof tip;
     } else {
 	if (to->size < sizeof tip) {
@@ -2503,7 +2498,7 @@ _XmCvtStringToSomeTable( Display *display,
 
 	    case ST_XM_STRING_TABLE:
 		table[nitems] =
-		    XmStringCreateLtoR(str, XmFONTLIST_DEFAULT_TAG);
+		    (XtPointer)XmStringCreateLtoR(str, XmFONTLIST_DEFAULT_TAG);
 		XtFree(str);
 	    }
 
@@ -2572,7 +2567,7 @@ _XmCvtStringToSomeTable( Display *display,
     }
 
     if (to->addr == NULL) {
-	to->addr = (XtPointer)&table;
+	to->addr = (XPointer)&table;
 	to->size = sizeof table;
     } else {
 	if (to->size < sizeof table) {
@@ -2647,7 +2642,7 @@ get_unit_type(Widget w, Cardinal *size, XrmValue *val)
     ut = _XmGetUnitType(w);
 }
 
-#if	XmVERSION > 1
+#if XmVERSION > 1
 /*
  * XmConvertStringToUnits converts a string specification value and returns
  * the converted value as the return value from the function. This function
@@ -2700,11 +2695,11 @@ _XmCvtStringToTabList(Display *display,
 
 static Boolean
 _XmCvtStringToRenderTable(Display *display,
-		       XrmValue *args,
-		       Cardinal *num_args,
-		       XrmValue *from,
-		       XrmValue *to,
-		       XtPointer *converter_data)
+                          XrmValue *args,
+                          Cardinal *num_args,
+                          XrmValue *from,
+                          XrmValue *to,
+                          XtPointer *converter_data)
 {
 
 	return False;
@@ -2713,19 +2708,28 @@ _XmCvtStringToRenderTable(Display *display,
 
 extern unsigned int
 XmCvtXmStringToByteStream(XmString string,
-                      unsigned char **prop_return)
+                          unsigned char **prop_return)
 {
         _XmWarning(NULL, "XmConvertStringToUnits() is not implemented yet!\n");
 	return 0;
 }
 
 
+
+extern XmString 
+XmCvtByteStreamToXmString(unsigned char *property)
+{
+      _XmWarning(NULL, "XmCvtByteStreamToXmString() is not implemented yet!\n");
+      return NULL;
+}
+
+
 extern int
 XmCvtXmStringTableToTextProperty (Display *display,
-                                      XmStringTable string_table,
-                                      int count,
-                                      XmICCEncodingStyle style,
-                                      XTextProperty *text_prop_return)
+                                  XmStringTable string_table,
+                                  int count,
+                                  XmICCEncodingStyle style,
+                                  XTextProperty *text_prop_return)
 {
         _XmWarning(NULL, "XmCvtXmStringTableToTextProperty() is not implemented yet!\n");
 	return 0;
