@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Scale.c,v 1.42 2000/12/12 17:09:31 amai Exp $
+ * $Id: Scale.c,v 1.48 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,13 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Scale.c,v 1.42 2000/12/12 17:09:31 amai Exp $";
+static const char rcsid[] = "$Id: Scale.c,v 1.48 2001/07/27 18:51:57 dannybackx Exp $";
 
 #include <LTconfig.h>
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <limits.h>
+#include <math.h>
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
@@ -78,32 +79,22 @@ static const char rcsid[] = "$Id: Scale.c,v 1.42 2000/12/12 17:09:31 amai Exp $"
 #define Scale_ShadowThickness(x) MGR_ShadowThickness(x)
 
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void destroy(Widget w);
-
 static void realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
 static XtGeometryResult query_geometry(Widget w,
 				       XtWidgetGeometry *request,
 				       XtWidgetGeometry *reply);
-
 static XtGeometryResult geometry_manager(Widget w,
 					 XtWidgetGeometry *request,
 					 XtWidgetGeometry *reply);
-
 static void expose(Widget w, XEvent *event, Region region);
-
 static void resize(Widget w);
-
 static void change_managed(Widget w);
 
 #if 0
@@ -113,36 +104,25 @@ static void insert_child(Widget w);
 static XmKidGeometry _XmScalePreferredSize(Widget scale, Widget child,
 					   XtWidgetGeometry *childgeom,
 					   Dimension *w, Dimension *ht);
-
 static XtGeometryResult _XmScaleGeomRequest(Widget scale,
 					    Dimension *wd, Dimension *ht);
-
 static void _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 			   Widget child, XtWidgetGeometry *childgeom,
 			   Dimension curw, Dimension curh);
-
 static void _XmScaleConfigureChildren(Widget scale,
 				      Widget child,
 				      XmKidGeometry boxes);
-
 static int _XmScaleConvertWidthToSliderSize(Widget w);
-
 static int _XmScaleConvertSCBValueToScaleValue(Widget w, int value);
-
 static int _XmScaleConvertScaleValueToSCBValue(Widget w);
-
 static void _ScaleValueChanged(Widget sb, XtPointer cd, XtPointer data);
-
 static void _ScaleDrag(Widget sb, XtPointer cd, XtPointer data);
-
 static void computeValueSize(Widget w);
-
 static void showValue(Widget w, int scb_value, int scale_value);
 
 #if 0
 static void GetFocus(Widget w, XEvent *event,
 		     String *params, Cardinal *num_params);
-
 static void LoseFocus(Widget w, XEvent *event,
 		      String *params, Cardinal *num_params);
 #endif
@@ -465,7 +445,7 @@ initialize(Widget request, Widget new_w,
     Dimension wd, ht;
     */
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -475,7 +455,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     if (Scale_ScaleWidth(new_w) == 0)
     {
@@ -629,7 +609,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Widget sb, lab;
     int resize = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "XmScale set_values()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "XmScale set_values()\n"));
 
     sb = ((XmScaleWidget)new_w)->composite.children[CHILD_SB];
     lab = ((XmScaleWidget)new_w)->composite.children[CHILD_LAB];
@@ -813,7 +793,7 @@ expose(Widget w,
        XEvent *event,
        Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale expose()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale expose()\n"));
 
     _XmRedisplayGadgets(w, event, region);
 
@@ -840,7 +820,7 @@ query_geometry(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 
 #define Wants(x)	((wants.request_mode & x) == x)
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
 
     wants = *request;
 
@@ -890,7 +870,7 @@ query_geometry(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
     XtWidgetGeometry wants;
     Dimension wd, ht;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
 
     wants = *request;
 
@@ -913,7 +893,7 @@ resize(Widget w)
     XmKidGeometry boxes;
     Dimension wd, ht;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Scale %s Resize: x %d y %d w %d h %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Scale %s Resize: x %d y %d w %d h %d\n",
 		      XtName(w), XtX(w), XtY(w), XtWidth(w), XtHeight(w)));
 
     Scale_SliderSize(w) = _XmScaleConvertWidthToSliderSize(w);
@@ -943,7 +923,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
     XmKidGeometry boxes;
     XtWidgetGeometry wants;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale geometry_manager()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale geometry_manager()\n"));
 
     wants = *request;
 
@@ -967,7 +947,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 
     *reply = *request;
 
-    reply->request_mode = CWWidth|CWHeight;
+    reply->request_mode &= CWWidth|CWHeight;
 
     if (Wants(CWWidth) && Wants(CWHeight) &&
 	wants.width == reply->width && wants.height == reply->height)
@@ -991,6 +971,14 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 	return XtGeometryYes;
     }
 
+    if (Wants(CWWidth) && wants.width == reply->width)
+    {
+    	reply->request_mode &= ~CWWidth;
+    }
+    if (Wants(CWHeight) && wants.height == reply->height)
+    {
+    	reply->request_mode &= ~CWHeight;
+    }
     return XtGeometryAlmost;
 #undef Wants
 }
@@ -1009,7 +997,7 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
     XmKidGeometry boxes;
     */
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale realize()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale realize()\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->core_class.realize) (w, value_mask, attributes);
@@ -1041,7 +1029,7 @@ change_managed(Widget w)
     Dimension wd, ht;
     XmKidGeometry boxes;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale change_managed()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale change_managed()\n"));
 
     wd = ht = 0;
     boxes = _XmScalePreferredSize(w, NULL, NULL, &wd, &ht);
@@ -1069,7 +1057,7 @@ insert_child(Widget w)
     (*superclass->composite_class.insert_child) (w);
 #undef  superclass
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Scale %s: insert child %s\n",
 		      XtName(XtParent(w)), XtName(w)));
 }
@@ -1697,7 +1685,7 @@ _XmScaleGeomRequest(Widget scale, Dimension *wd, Dimension *ht)
     request.width = *wd;
     request.height = *ht;
 
-    DEBUGOUT(XdbDebug(__FILE__, scale, "_XmScaleGeomRequest(ing) (%d %d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, scale, "_XmScaleGeomRequest(ing) (%d %d)\n",
 		      *wd, *ht));
 
     result = _XmMakeGeometryRequest(scale, &request);
@@ -1713,8 +1701,8 @@ _XmScaleGeomRequest(Widget scale, Dimension *wd, Dimension *ht)
 	*ht = XtHeight(scale);
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, scale, "_XmScaleLayout (%d %d) => %s\n",
-		      *wd, *ht, XdbGeometryResult2String(result)));
+    DEBUGOUT(_LtDebug(__FILE__, scale, "_XmScaleLayout (%d %d) => %s\n",
+		      *wd, *ht, _LtDebugGeometryResult2String(result)));
 
     return result;
 }
@@ -1768,9 +1756,9 @@ _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 	{
 	    for (i = 2; i < num_children; i++)
 	    {
-		boxes[i].box.width = (Dimension)((float)boxes[i].box.width /
-						 (float)curw *
-						 (float)XtWidth(scale));
+		boxes[i].box.width = (Dimension)((double)boxes[i].box.width /
+						 (double)curw *
+						 (double)XtWidth(scale));
 	    }
 	}
 #endif
@@ -1861,9 +1849,9 @@ _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 	if (XtWidth(scale) > curw)
 	{
 	    for (i = 2; i < num_children; i++)
-		boxes[i].box.height = (Dimension)((float)boxes[i].box.height /
-						  (float)curw *
-						  (float)XtWidth(scale));
+		boxes[i].box.height = (Dimension)((double)boxes[i].box.height /
+						  (double)curw *
+						  (double)XtWidth(scale));
 	}
 #endif
 
@@ -1930,8 +1918,8 @@ _XmScaleConfigureChildren(Widget scale, Widget child, XmKidGeometry boxes)
     _XmSetKidGeo(boxes, child);
 
     Scale_SliderSize(scale) = _XmScaleConvertWidthToSliderSize(scale);
-    inc = (int)((float)(SCB_MAX - SCB_MIN - Scale_SliderSize(scale)) /
-		(float)(Scale_Maximum(scale) - Scale_Minimum(scale)) +
+    inc = (int)((double)(SCB_MAX - SCB_MIN - Scale_SliderSize(scale)) /
+		(double)(Scale_Maximum(scale) - Scale_Minimum(scale)) +
 		0.5);
     inc = _XmMax(inc, 1);	/* FIX ME */
     p_inc = inc * Scale_ScaleMultiple(scale);
@@ -2124,7 +2112,7 @@ GetFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmScrollBarWidget sb;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "GetFocus\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "GetFocus\n"));
 
     sb = (XmScrollBarWidget)(((XmScaleWidget)w)->composite.children[CHILD_SB]);
 
@@ -2138,7 +2126,7 @@ LoseFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmScrollBarWidget sb;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "LoseFocus\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "LoseFocus\n"));
 
     sb = (XmScrollBarWidget)(((XmScaleWidget)w)->composite.children[CHILD_SB]);
 
@@ -2177,9 +2165,9 @@ _XmScaleConvertWidthToSliderSize(Widget w)
 	    if (XtWidth(sb) == 2 * (ht + st))
 	    {
 		/* Note: M*tif 1.2.2 SIGFPE's on this -- PvH */
-		ret = (int)((float)(SCB_MAX - SCB_MIN) /
-			    (float)(Scale_Maximum(w) - Scale_Minimum(w)) *
-			    (float)HSLIDERSIZE);
+		ret = (int)((double)(SCB_MAX - SCB_MIN) /
+			    (double)(Scale_Maximum(w) - Scale_Minimum(w)) *
+			    (double)HSLIDERSIZE);
 	    }
 	    else if (XtWidth(sb) < HSLIDERSIZE)
 	    {
@@ -2223,25 +2211,42 @@ _XmScaleConvertWidthToSliderSize(Widget w)
 static int
 _XmScaleConvertSCBValueToScaleValue(Widget w, int value)
 {
+    double roundarg;
+    int result;
+
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmScaleConvertSCBValueToScaleValue(,%i)\n",
+                       value));
     if ((SCB_MAX - SCB_MIN - Scale_SliderSize(w)) == 0)
     {
 	return Scale_Minimum(w);
     }
 
-    return (int)((float)(Scale_Maximum(w) - Scale_Minimum(w)) 
-		* (float)value 
-		/ (float)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
-		+ (float)Scale_Minimum(w) );
+    roundarg = (double)(Scale_Maximum(w) - Scale_Minimum(w)) 
+	     * (double)value 
+	     / (double)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
+	     + (double)Scale_Minimum(w);
+
+    result = (int)(roundarg + 0.5);
+
+    return result;
 }
 
 
 static int
 _XmScaleConvertScaleValueToSCBValue(Widget w)
 {
-    return (int)((float)(Scale_Value(w) - Scale_Minimum(w)) 
-		* (float)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
-		/ (float)(Scale_Maximum(w) - Scale_Minimum(w)) 
-		);
+
+    double roundarg;
+    int result;
+
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmScaleConvertScaleValueToSCBValue()\n"));
+    roundarg = (double)(Scale_Value(w) - Scale_Minimum(w)) 
+	     * (double)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
+	     / (double)(Scale_Maximum(w) - Scale_Minimum(w));
+    /* amai: is this the correct formula? 
+             looks like the old one in _XmScaleConvertSCBValueToScaleValue() */
+    result = (int)(roundarg);
+    return result;
 }
 
 
@@ -2260,5 +2265,5 @@ _XmScaleProcessingDirectionDefault(Widget w, int offset, XrmValue *val)
 	direction = XmMAX_ON_RIGHT;	/* FIX ME */
     }
 
-    val->addr = (XtPointer)&direction;
+    val->addr = (XPointer)&direction;
 }
