@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Screen.c,v 1.19 2000/09/18 11:17:58 amai Exp $
+ * $Id: Screen.c,v 1.26 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team 
+ * Copyright (C) 1995-2001 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Screen.c,v 1.19 2000/09/18 11:17:58 amai Exp $";
+static const char rcsid[] = "$Id: Screen.c,v 1.26 2001/07/27 18:51:57 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -43,40 +43,29 @@ static const char rcsid[] = "$Id: Screen.c,v 1.19 2000/09/18 11:17:58 amai Exp $
 
 #include <XmI/DebugUtil.h>
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
 
-
-XrmQuark _XmInvalidCursorIconQuark;
-XrmQuark _XmValidCursorIconQuark;
-XrmQuark _XmNoneCursorIconQuark;
-XrmQuark _XmDefaultDragIconQuark;
-XrmQuark _XmMoveCursorIconQuark;
-XrmQuark _XmCopyCursorIconQuark;
-XrmQuark _XmLinkCursorIconQuark;
+/* Some global variables */
+XrmQuark _XmInvalidCursorIconQuark=0;
+XrmQuark _XmValidCursorIconQuark=0;
+XrmQuark _XmNoneCursorIconQuark=0;
+XrmQuark _XmDefaultDragIconQuark=0;
+XrmQuark _XmMoveCursorIconQuark=0;
+XrmQuark _XmCopyCursorIconQuark=0;
+XrmQuark _XmLinkCursorIconQuark=0;
 
 /* Forward Declarations */
 
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
-
 static void destroy(Widget w);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
-
 static void insert_child(Widget w);
 static void delete_child(Widget w);
-
 static void default_horizontal_font_unit(Widget w, int offset, XrmValue *val);
 static void default_vertical_font_unit(Widget w, int offset, XrmValue *val);
 
@@ -168,7 +157,7 @@ static XtResource resources[] =
     },
 };
 
-/* *INDENT-OFF* */
+
 static XmBaseClassExtRec _XmScreenCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -243,7 +232,6 @@ XmScreenClassRec xmScreenClassRec = {
         /* extension             */ NULL
     }
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmScreenClass = (WidgetClass)&xmScreenClassRec;
@@ -256,33 +244,36 @@ WidgetClass xmScreenClass = (WidgetClass)&xmScreenClassRec;
 #define PSWC_None               ((XContext) 0)
 static XContext PerScreenWidgetContext = PSWC_None;
 
+
 static void
 class_initialize(void)
 {
     _XmScreenCoreClassExtRec.record_type = XmQmotif;
 
     _XmInvalidCursorIconQuark = XrmStringToQuark(XmNdefaultInvalidCursorIcon);
-    _XmValidCursorIconQuark = XrmStringToQuark(XmNdefaultValidCursorIcon);
-    _XmNoneCursorIconQuark = XrmStringToQuark(XmNdefaultNoneCursorIcon);
-    _XmDefaultDragIconQuark = XrmStringToQuark(XmNdefaultSourceCursorIcon);
-    _XmMoveCursorIconQuark = XrmStringToQuark(XmNdefaultMoveCursorIcon);
-    _XmCopyCursorIconQuark = XrmStringToQuark(XmNdefaultCopyCursorIcon);
-    _XmLinkCursorIconQuark = XrmStringToQuark(XmNdefaultLinkCursorIcon);
+    _XmValidCursorIconQuark   = XrmStringToQuark(XmNdefaultValidCursorIcon);
+    _XmNoneCursorIconQuark    = XrmStringToQuark(XmNdefaultNoneCursorIcon);
+    _XmDefaultDragIconQuark   = XrmStringToQuark(XmNdefaultSourceCursorIcon);
+    _XmMoveCursorIconQuark    = XrmStringToQuark(XmNdefaultMoveCursorIcon);
+    _XmCopyCursorIconQuark    = XrmStringToQuark(XmNdefaultCopyCursorIcon);
+    _XmLinkCursorIconQuark    = XrmStringToQuark(XmNdefaultLinkCursorIcon);
 }
 
+
 static void
 class_part_initialize(WidgetClass widget_class)
 {
     _XmFastSubclassInit(widget_class, XmSCREEN_BIT);
 }
 
+
 static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
     XtPointer FirstScreenWidget;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "%s:initialize(%d)\n", 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "%s:initialize(%d)\n", 
     			__FILE__, __LINE__));
 
     /*
@@ -309,7 +300,7 @@ initialize(Widget request, Widget new_w,
      * appropiate screen.
      */
     if (XFindContext(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
-		     PerScreenWidgetContext, (XtPointer)&FirstScreenWidget)
+		     PerScreenWidgetContext, (XPointer *)&FirstScreenWidget)
 	== XCSUCCESS)
     {
 	_XmError(new_w, "Attempt to create a second XmScreen widget.");
@@ -317,7 +308,7 @@ initialize(Widget request, Widget new_w,
     else
     {
 	XSaveContext(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
-		     PerScreenWidgetContext, (_Xconst char *)new_w);
+		     PerScreenWidgetContext, (XPointer)new_w);
     }
 
     Screen_MwmPresent(new_w) = XmIsMotifWMRunning(new_w);
@@ -341,6 +332,7 @@ initialize(Widget request, Widget new_w,
     Screen_NullCursor(new_w) = None;
 }
 
+
 static void
 destroy(Widget w)
 {
@@ -364,6 +356,7 @@ destroy(Widget w)
     _XmInvalidateColorCache(False);
 }
 
+
 static void
 insert_child(Widget w)
 {
@@ -391,6 +384,7 @@ insert_child(Widget w)
 
 }
 
+
 static void
 delete_child(Widget w)
 {
@@ -420,16 +414,18 @@ delete_child(Widget w)
     }
 }
 
+
 static void
 realize(Widget w,
 	XtValueMask *value_mask,
 	XSetWindowAttributes *attributes)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:realize(%d)\n", 
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d)\n", 
     			__FILE__, __LINE__));
 
 }
 
+
 static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
@@ -466,6 +462,7 @@ set_values(Widget old, Widget request, Widget new_w,
     return need_refresh;
 }
 
+
 static void
 default_horizontal_font_unit(Widget w, int offset, XrmValue *val)
 {
@@ -492,6 +489,7 @@ default_horizontal_font_unit(Widget w, int offset, XrmValue *val)
 	: ((font->min_bounds.width + font->max_bounds.width) * 10 + 11) / 23;
 }
 
+
 static void
 default_vertical_font_unit(Widget w, int offset, XrmValue *val)
 {
@@ -519,7 +517,8 @@ default_vertical_font_unit(Widget w, int offset, XrmValue *val)
 	: ((font->ascent + font->descent) * 10 + 11) / 22;
 }
 
-XmDragIconObject
+
+extern XmDragIconObject
 _XmScreenGetOperationIcon(Widget w, unsigned char operation)
 {
     XmScreen scr;
@@ -570,7 +569,8 @@ _XmScreenGetOperationIcon(Widget w, unsigned char operation)
     return *d;
 }
 
-XmDragIconObject
+
+extern XmDragIconObject
 _XmScreenGetStateIcon(Widget w, unsigned char state)
 {
     XmScreen scr;
@@ -631,7 +631,8 @@ _XmScreenGetStateIcon(Widget w, unsigned char state)
     return Screen_StateCursorIcon(scr);
 }
 
-XmDragIconObject
+
+extern XmDragIconObject
 _XmScreenGetSourceIcon(Widget w)
 {
     XmScreen scr;
@@ -660,7 +661,8 @@ _XmScreenGetSourceIcon(Widget w)
     return Screen_DefaultSourceCursorIcon(scr);
 }
 
-Pixmap
+
+extern Pixmap
 _XmAllocScratchPixmap(XmScreen xmScreen,
 		      Cardinal depth,
 		      Dimension width,
@@ -668,7 +670,7 @@ _XmAllocScratchPixmap(XmScreen xmScreen,
 {
     XmScratchPixmap pix = NULL;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)xmScreen, "%s:_XmAllocScratchPixmap(%d) - %dx%dx%d\n", 
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "%s:_XmAllocScratchPixmap(%d) - %dx%dx%d\n", 
     			__FILE__, __LINE__,
     			width, height, depth));
 
@@ -678,7 +680,7 @@ _XmAllocScratchPixmap(XmScreen xmScreen,
 	    pix->width == width && pix->height == height)
 	{
 	    pix->inUse = True;
-	    DEBUGOUT(XdbDebug(__FILE__, (Widget)xmScreen, "\tfrom cache %p\n", 
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "\tfrom cache %p\n", 
     			pix->pixmap));
 	    break;
 	}
@@ -697,18 +699,19 @@ _XmAllocScratchPixmap(XmScreen xmScreen,
 	pix->next = Screen_ScratchPixmaps(xmScreen);
 	Screen_ScratchPixmaps(xmScreen) = pix;
 
-	DEBUGOUT(XdbDebug(__FILE__, (Widget)xmScreen, "\tnew %p\n", 
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "\tnew %p\n", 
 			    pix->pixmap));
     }
     return pix->pixmap;
 }
 
-void
+
+extern void
 _XmFreeScratchPixmap(XmScreen xmScreen, Pixmap pixmap)
 {
     XmScratchPixmap pix;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)xmScreen, "%s:_XmFreeScratchPixmap(%d) - %p\n", 
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "%s:_XmFreeScratchPixmap(%d) - %p\n", 
     			__FILE__, __LINE__,
     			pixmap));
     for (pix = Screen_ScratchPixmaps(xmScreen); pix != NULL; pix = pix->next)
@@ -726,13 +729,15 @@ _XmFreeScratchPixmap(XmScreen xmScreen, Pixmap pixmap)
     }
 }
 
-XmDragCursorCache *
+
+extern XmDragCursorCache *
 _XmGetDragCursorCachePtr(XmScreen xmScreen)
 {
     return &Screen_CursorCache(xmScreen);
 }
 
-void
+
+extern void
 _XmGetMaxCursorSize(Widget w,
 		    Dimension *width,
 		    Dimension *height)
@@ -744,7 +749,8 @@ _XmGetMaxCursorSize(Widget w,
     *height = Screen_MaxCursorHeight(scr);
 }
 
-Cursor
+
+extern Cursor
 _XmGetNullCursor(Widget w)
 {
     XmScreen scr;
@@ -775,7 +781,8 @@ _XmGetNullCursor(Widget w)
     return Screen_NullCursor(scr);
 }
 
-Cursor
+
+extern Cursor
 _XmGetMenuCursorByScreen(Screen *screen)
 {
     XmScreen scr;
@@ -784,7 +791,8 @@ _XmGetMenuCursorByScreen(Screen *screen)
     return Screen_MenuCursor(scr);
 }
 
-Boolean
+
+extern Boolean
 _XmGetMoveOpaqueByScreen(Screen *screen)
 {
     XmScreen scr;
@@ -793,7 +801,8 @@ _XmGetMoveOpaqueByScreen(Screen *screen)
     return Screen_MoveOpaque(scr);
 }
 
-unsigned char
+
+extern unsigned char
 _XmGetUnpostBehavior(Widget wid)
 {
     XmScreen scr;
@@ -802,7 +811,8 @@ _XmGetUnpostBehavior(Widget wid)
     return Screen_UnpostBehavior(scr);
 }
 
-int
+
+extern int
 _XmGetFontUnit(Screen *screen, int dimension)
 {
     XmScreen scr;
@@ -817,7 +827,8 @@ _XmGetFontUnit(Screen *screen, int dimension)
     return Screen_HorizUnit(scr);
 }
 
-void
+
+extern void
 _XmScreenRemoveFromCursorCache(XmDragIconObject icon)
 {
     XmScreen scr;
@@ -875,7 +886,8 @@ _XmScreenRemoveFromCursorCache(XmDragIconObject icon)
     }
 }
 
-XmScreenInfo *
+
+extern XmScreenInfo *
 _XmGetScreenInfo(Widget scr)
 {
     if (!Screen_ScreenInfo(scr))
@@ -898,17 +910,18 @@ _XmGetScreenInfo(Widget scr)
     return (XmScreenInfo *)Screen_ScreenInfo(scr);
 }
 
-Widget
+
+extern Widget
 XmGetXmScreen(Screen *scr)
 {
     Widget disp;
     Widget screen;
     int argc;
-    Arg args[3];
+    Arg args[4];
     char name[128];
     int screen_no, max_screens;
 
-    DEBUGOUT(XdbDebug0(__FILE__, (Widget)NULL, "%s:XmGetXmScreen(%d)\n", 
+    DEBUGOUT(_LtDebug0(__FILE__, (Widget)NULL, "%s:XmGetXmScreen(%d)\n", 
     			__FILE__, __LINE__));
 
     disp = XmGetXmDisplay(DisplayOfScreen(scr));
@@ -923,12 +936,12 @@ XmGetXmScreen(Screen *scr)
 	XtSetArg(args[argc], XmNwidth, 1); argc++;
 	XtSetArg(args[argc], XmNheight, 1); argc++;
 	XtSetArg(args[argc], XmNmappedWhenManaged, False); argc++;
+	XtSetArg(args[argc], XmNscreen, scr); argc++;
 
 	max_screens = ScreenCount(DisplayOfScreen(scr));
 	for (screen_no = 0; screen_no < max_screens; screen_no++)
 	{
-	    if (ScreenOfDisplay(DisplayOfScreen(scr), screen_no) ==
-		scr)
+	    if (ScreenOfDisplay(DisplayOfScreen(scr), screen_no) ==	scr)
 	    {
 		break;
 	    }
