@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/SelectionBox.c,v 1.48 2000/09/23 15:05:25 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/SelectionBox.c,v 1.55 2001/07/31 14:41:59 sholson Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/SelectionBox.c,v 1.48 2000/09/23 15:05:25 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/SelectionBox.c,v 1.55 2001/07/31 14:41:59 sholson Exp $";
 
 #include <LTconfig.h>
 
@@ -119,7 +119,7 @@ static XtResource resources[] =
     {
 	XmNtextString, XmCTextString, XmRXmString,
 	sizeof(XmString), Offset(text_string),
-	XmRImmediate, (XtPointer)XmUNSPECIFIED /*NULL*/	/* Used to be -1 (XmUNSPECIFIED) */
+	XmRImmediate, (XtPointer)XmUNSPECIFIED
     },
     {
 	XmNlistItems, XmCItems, XmRXmStringTable,
@@ -265,7 +265,6 @@ static XtActionsRec actions[] =
 	{"SelectionBoxRestore", _XmSelectionBoxRestore},
 };
 
-/* *INDENT-OFF* */
 #if 0
 static XmBaseClassExtRec _XmSelectionBCoreClassExtRec = {
     /* next_extension            */ NULL,
@@ -380,7 +379,6 @@ XmSelectionBoxClassRec xmSelectionBoxClassRec = {
 	/* extension                    */ NULL,
     }
 };
-/* *INDENT-ON* */
 
 
 
@@ -412,6 +410,7 @@ class_part_initialize(WidgetClass widget_class)
     _XmFastSubclassInit(widget_class, XmSELECTION_BOX_BIT);
 }
 
+
 /*
  * Determine if the selection is a match with one of the
  * items in the list
@@ -441,6 +440,7 @@ _XmSelectionBoxMatch(XmSelectionBoxWidget w)
     return r;
 }
 
+
 /*
  * When the user clicks on an item in the list, copy its value to the
  * text field.
@@ -459,26 +459,26 @@ ListSingleSelect(Widget w, XtPointer client, XtPointer call)
 
     if (SB_Text(sb) == NULL)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "ListSingleSelect (No TextField)\n"));
 	return;
     }
 
     if (lp == NULL || lp->item == NULL)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "ListSingleSelect (NULL)\n"));
 	return;
     }
 
     if (!XmStringGetLtoR(lp->item, XmFONTLIST_DEFAULT_TAG, &s))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "ListSingleSelect (Couldn't convert to string)\n"));
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "ListSingleSelect '%s'\n", s));
 
     XmTextFieldSetString(SB_Text(sb), s);
@@ -487,6 +487,7 @@ ListSingleSelect(Widget w, XtPointer client, XtPointer call)
     XtFree(s);
 }
 
+
 /*
  * This routine is called for any button child of selectionbox for the
  * XmNactivateCallback. Make mapping to XmNokCallback etc.
@@ -500,7 +501,7 @@ _XmSbButton(Widget w, XtPointer client, XtPointer call)
     XmSelectionBoxCallbackStruct cbs;
     int au = 0;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmSbButton\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmSbButton\n"));
 
     if (XmIsList(w))
     {
@@ -598,7 +599,7 @@ _XmSbButton(Widget w, XtPointer client, XtPointer call)
 	{
 	    XtUnmanageChild((Widget)sb);
 
-	    DEBUGOUT(XdbDebug2(__FILE__, (Widget)sb, w, "AutoUnmanage\n"));
+	    DEBUGOUT(_LtDebug2(__FILE__, (Widget)sb, w, "AutoUnmanage\n"));
 
 	    /* XtNpopdownCallback */
 	    XtCallCallbackList(s, Shell_PopdownCallback(s), NULL);
@@ -625,7 +626,7 @@ initialize(Widget request,
 {
     XmSelectionBoxWidget sb = (XmSelectionBoxWidget)new_w;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -634,7 +635,7 @@ initialize(Widget request,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
 
     SB_List(sb) = NULL;
@@ -646,6 +647,10 @@ initialize(Widget request,
 	_XmSelectionBoxCreateList(sb);
     }
 
+    if (SB_SelectionLabelString(sb) != NULL) {
+	SB_SelectionLabelString(sb) = XmStringCopy(SB_SelectionLabelString(sb));
+    }
+
     _XmSelectionBoxCreateSelectionLabel(sb);
     _XmSelectionBoxCreateText(sb);
 
@@ -658,6 +663,19 @@ initialize(Widget request,
     SB_Separator(sb) = NULL;
     if (SB_DialogType(sb) != XmDIALOG_COMMAND)
     {
+	if (SB_OkLabelString(sb) != NULL) {
+	    SB_OkLabelString(sb) = XmStringCopy(SB_OkLabelString(sb));
+	}
+
+	/* ApplyLabelString is handled in FileSB - should it be here? */
+
+	if (SB_CancelLabelString(sb) != NULL) {
+	    SB_CancelLabelString(sb) = XmStringCopy(SB_CancelLabelString(sb));
+	}
+
+	if (SB_HelpLabelString(sb) != NULL) {
+	    SB_HelpLabelString(sb) = XmStringCopy(SB_HelpLabelString(sb));
+	}
 
 	_XmSelectionBoxCreateSeparator(sb);
 	_XmSelectionBoxCreateOkButton(sb);
@@ -725,23 +743,26 @@ initialize(Widget request,
 		/* T. Straumann: List made a copy of the item list;
 		 *				 we have to adjust SB_ListItems
 		 */
-		XtVaGetValues(SB_List(sb), XmNitems, &SB_ListItems(sb), 0);
+		XtVaGetValues(SB_List(sb), XmNitems, &SB_ListItems(sb), NULL);
     }
 }
 
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(XdbDebug("RWS", w,"%s:destroy(%d)\n",
+    DEBUGOUT(_LtDebug("RWS", w,"%s:destroy(%d)\n",
     	__FILE__, __LINE__
     	));
     /* rws 14 Apr 1998
-       Motif does not have this method.  Then again we all know Motif has
-       memory leaks.
+       Motif does not have this method.  Thats because the strings are
+       shared with the child buttons and the buttons manage the storage.
      */
+    if (SB_SelectionLabelString(w)) XmStringFree(SB_SelectionLabelString(w));
     XmStringFree(SB_TextString(w));
-	/* T. Straumann: fixed memory leak */
-	XmStringFree(SB_ApplyLabelString(w));
+    if (SB_OkLabelString(w))        XmStringFree(SB_OkLabelString(w));
+    if (SB_ApplyLabelString(w))     XmStringFree(SB_ApplyLabelString(w));
+    if (SB_CancelLabelString(w))    XmStringFree(SB_CancelLabelString(w));
+    if (SB_HelpLabelString(w))      XmStringFree(SB_HelpLabelString(w));
 }
 
 /*
@@ -761,7 +782,7 @@ set_values(Widget old,
     Arg al[10];
     int ac;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -773,7 +794,7 @@ set_values(Widget old,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     /* this is required for every BB subclass */
     BB_InSetValues(new_w) = True;
@@ -1092,7 +1113,7 @@ _XmSelectionBoxGetTextColumns(Widget wid, int resource_offset,
     Arg a;
     int n;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "XmSelectionBoxGettTextColumns\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "XmSelectionBoxGettTextColumns\n"));
 
     XtSetArg(a, XmNtextColumns, &n);
     n = -1;
@@ -1108,7 +1129,7 @@ _XmSelectionBoxGetTextString(Widget wid, int resource_offset,
 {
     char *str;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmSelectionBoxGetTextString\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmSelectionBoxGetTextString\n"));
 
     str = XmTextFieldGetString(SB_Text(wid));
     *value = (XtArgVal)XmStringCreateSimple(str);
@@ -1122,7 +1143,7 @@ _XmSelectionBoxGetListItems(Widget wid, int resource_offset,
     XmStringTable l;
     Arg a;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid,
+    DEBUGOUT(_LtDebug(__FILE__, wid,
 		      "XmSelectionBoxGetListItems(_, %d, _)\n",
 		      resource_offset));
 
@@ -1149,7 +1170,7 @@ _XmSelectionBoxGetListItemCount(Widget wid, int resource_offset,
     Arg a;
     int n;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "XmSelectionBoxGetListItemCount\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "XmSelectionBoxGetListItemCount\n"));
 
     XtSetArg(a, XmNitemCount, &n);
     n = -1;
@@ -1202,7 +1223,7 @@ _XmSelectionBoxUpOrDown(Widget wid, XEvent *event,
     int *position_list, position_count, new_position, old_position;
     /* char *selected_text; */
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmSelectionBoxUpOrDown %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmSelectionBoxUpOrDown %s\n",
 		      argv ? *argv: "NULL"));
     if (list != NULL && text != NULL)
     {
@@ -1291,7 +1312,7 @@ _XmSelectionBoxRestore(Widget wid, XEvent *event,
     int item_count, *position_list, position_count;
     char *selected_text;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmSelectionBoxRestore\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmSelectionBoxRestore\n"));
 
     if (text != NULL && list != NULL)
     {
@@ -1330,7 +1351,7 @@ _XmSelectionBoxGeoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     register XmKidGeometry boxPtr;
     Cardinal numKids;
     Boolean newRow;
-    int nrows, i, nextras;
+    Cardinal nrows, i, nextras;
     Widget *extras;
 
     numKids = MGR_NumChildren(_w);
@@ -1720,7 +1741,7 @@ XmCreateSelectionDialog(Widget parent, char *name,
     Widget d, r;
     char *s;
     Arg *al = (Arg *)XtCalloc(argcount + 1, sizeof(Arg));
-    int ac, i;
+    Cardinal ac, i;
 
     s = _XmMakeDialogName(name);
 
@@ -1739,7 +1760,7 @@ XmCreateSelectionDialog(Widget parent, char *name,
     XtFree(s);
 
     r = XtCreateWidget(name, xmSelectionBoxWidgetClass, d, al, ac);
-    XtFree((XtPointer)al);
+    XtFree((XPointer)al);
     return r;
 }
 
@@ -1750,7 +1771,7 @@ XmCreatePromptDialog(Widget parent, char *name,
     Widget d, ret;
     char *s;
     Arg *al;
-    int i;
+    Cardinal i;
 
     s = _XmMakeDialogName(name);
 
@@ -1769,12 +1790,13 @@ XmCreatePromptDialog(Widget parent, char *name,
     XtSetArg(al[argcount - 1], XmNdialogType, XmDIALOG_PROMPT);
     ret = XtCreateWidget(name, xmSelectionBoxWidgetClass, d, al, argcount);
 
-    XtFree((XtPointer)al);
+    XtFree((XPointer)al);
 
     return ret;
 }
 
 
+/* This routine is marked as obsolete as of Motif 2.1 */
 Widget
 XmSelectionBoxGetChild(Widget w, unsigned char child)
 {
@@ -1782,17 +1804,15 @@ XmSelectionBoxGetChild(Widget w, unsigned char child)
 
     switch (child)
     {
+
     case XmDIALOG_APPLY_BUTTON:
 	return SB_ApplyButton(sb);
 
     case XmDIALOG_CANCEL_BUTTON:
 	return BB_CancelButton(sb);
 
-    case XmDIALOG_OK_BUTTON:
-	return SB_OkButton(sb);
-
-    case XmDIALOG_FILTER_TEXT:
-	return BB_CancelButton(sb);
+    case XmDIALOG_DEFAULT_BUTTON:
+	return BB_DefaultButton(sb);
 
     case XmDIALOG_HELP_BUTTON:
 	return SB_HelpButton(sb);
@@ -1800,43 +1820,32 @@ XmSelectionBoxGetChild(Widget w, unsigned char child)
     case XmDIALOG_LIST:
 	return SB_List(sb);
 
+    case XmDIALOG_LIST_LABEL:
+	return SB_ListLabel(sb);
+	
+    case XmDIALOG_OK_BUTTON:
+	return SB_OkButton(sb);
+
+    case XmDIALOG_SELECTION_LABEL:
+	return SB_SelectionLabel(sb);
+
     case XmDIALOG_SEPARATOR:
 	return SB_Separator(sb);
 
     case XmDIALOG_TEXT:
 	return SB_Text(sb);
 
-    case XmDIALOG_LIST_LABEL:
-	return SB_ListLabel(sb);
-
-    case XmDIALOG_MESSAGE_LABEL:
+    case XmDIALOG_WORK_AREA:
+      /* TODO: implement this */
 	return NULL;
 
-    case XmDIALOG_SELECTION_LABEL:
-	return SB_SelectionLabel(sb);
-
-    case XmDIALOG_SYMBOL_LABEL:
-	return NULL;
-
-    case XmDIALOG_FILTER_LABEL:
-	return NULL;
-
-    case XmDIALOG_DIR_LIST:
-	return NULL;
-
-    case XmDIALOG_DIR_LIST_LABEL:
-	return NULL;
-
-    case XmDIALOG_DEFAULT_BUTTON:
-	return BB_DefaultButton(sb);
-
-	/* These are illegal */
-    case XmDIALOG_NONE:
+    /* These are illegal */
     default:
 	return NULL;
     }
 }
 
+
 /*      
  * Keep track of button children
  */
@@ -1858,6 +1867,8 @@ insert_child(Widget w)
     }
 #endif
 }
+
+
 static void
 DeleteChild(Widget w)
 {
@@ -1887,12 +1898,13 @@ DeleteChild(Widget w)
 		SB_ListLabel(sb) = NULL;
 }
 
+
 static void
 _XmDialogTypeDefault(Widget w, int offset, XrmValue *value)
 {
     static unsigned char dialog_type;
     
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmDialogTypeDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmDialogTypeDefault\n"));
     
     dialog_type = XmDIALOG_WORK_AREA;
     
