@@ -1,9 +1,9 @@
 /**
  *
- * $Id: SeparatoG.c,v 1.16 2000/09/22 20:35:13 amai Exp $
+ * $Id: SeparatoG.c,v 1.20 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: SeparatoG.c,v 1.16 2000/09/22 20:35:13 amai Exp $";
+static const char rcsid[] = "$Id: SeparatoG.c,v 1.20 2001/07/27 18:51:57 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -301,9 +301,9 @@ secondary_object_create(Widget request,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "SeparatorGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -376,7 +376,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "SeparatoG InitializePrehook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "SeparatoG InitializePrehook\n"));
 
     /*
      * We should allocate secondary object here, using _XmExtObjAlloc (to create
@@ -400,7 +400,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "SeparatoG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "SeparatoG InitializePosthook\n"));
 
     /* don't let the null fool you */
     SEPG_Cache(new_w) = (XmSeparatorGCacheObjPart *)
@@ -537,7 +537,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -712,7 +712,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -763,7 +763,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "XmSeparatorGadget %s Expose (shadowThickness %d)\n",
 		      XtName(w), G_ShadowThickness(w)));
 
