@@ -1,9 +1,9 @@
 /**
  *
- * $Id: TearOff.c,v 1.44 2000/09/23 15:05:26 amai Exp $
+ * $Id: TearOff.c,v 1.48 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996-2000 LessTif Development Team 
+ * Copyright (C) 1996-2001 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: TearOff.c,v 1.44 2000/09/23 15:05:26 amai Exp $";
+static const char rcsid[] = "$Id: TearOff.c,v 1.48 2001/07/27 18:51:57 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -53,12 +53,12 @@ static void
 _XmTearOffFocusChangeEventHandler(Widget reportingWidget, XtPointer data,
 				  XEvent *event, Boolean *cont)
 {
-	DEBUGOUT(XdbDebug("TEAROFF", reportingWidget,
+	DEBUGOUT(_LtDebug("TEAROFF", reportingWidget,
 		      "_XmTearOffFocusChangeEventHandler() - %s\n",
-		      XdbEventType2String(event->type)));
-	DEBUGOUT(XdbDebug(__FILE__, reportingWidget,
+		      _LtDebugEventType2String(event->type)));
+	DEBUGOUT(_LtDebug(__FILE__, reportingWidget,
 		      "_XmTearOffFocusChangeEventHandler() - %s\n",
-		      XdbEventType2String(event->type)));
+		      _LtDebugEventType2String(event->type)));
 	switch(event->type)
 	{
 	case FocusIn:
@@ -74,7 +74,7 @@ _XmTearOffFocusChangeEventHandler(Widget reportingWidget, XtPointer data,
 	    _XmMenuDisarmItem(MGR_ActiveChild(reportingWidget));
 	    */
 	    {
-	    int i;
+	    Cardinal i;
 	    Widget w = reportingWidget;
 
 		for (i = 0; i < MGR_NumChildren(w); i++)
@@ -95,7 +95,7 @@ _XmTearOffBtnDownEventHandler(Widget reportingWidget, XtPointer data,
 {
 Widget menu;
 
-    DEBUGOUT(XdbDebug(__FILE__, reportingWidget,
+    DEBUGOUT(_LtDebug(__FILE__, reportingWidget,
 		      "_XmTearOffBtnDownEventHandler()\n"));
     if (XmIsRowColumn(reportingWidget))
     {
@@ -132,7 +132,7 @@ Widget menu;
 	 * to it after we're done. */
 	_XmMenuFocus(w, XmMENU_FOCUS_SAVE, CurrentTime);
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "RC FOCUS SET: %s\n", XtName(w)));
+	DEBUGOUT(_LtDebug(__FILE__, w, "RC FOCUS SET: %s\n", XtName(w)));
 
 	_XmMenuFocus(w, XmMENU_FOCUS_SET, CurrentTime);
 #endif
@@ -175,7 +175,7 @@ Widget menu;
     }
     else
     {
-	DEBUGOUT(XdbDebug(__FILE__, reportingWidget,
+	DEBUGOUT(_LtDebug(__FILE__, reportingWidget,
 		      "_XmTearOffBtnDownEventHandler() - Not torn/armed\n"));
     }
 }
@@ -186,7 +186,7 @@ _XmTearOffBtnUpEventHandler(Widget reportingWidget, XtPointer data,
 {
 Widget menu;
 
-    DEBUGOUT(XdbDebug(__FILE__, reportingWidget,
+    DEBUGOUT(_LtDebug(__FILE__, reportingWidget,
 		      "_XmTearOffBtnUpEventHandler()\n"));
     if (XmIsRowColumn(reportingWidget))
     {
@@ -205,7 +205,7 @@ Widget menu;
     }
     else
     {
-	DEBUGOUT(XdbDebug(__FILE__, reportingWidget,
+	DEBUGOUT(_LtDebug(__FILE__, reportingWidget,
 		      "_XmTearOffBtnUpEventHandler() - Not torn/armed\n"));
     }
 }
@@ -213,7 +213,7 @@ Widget menu;
 void
 _XmDestroyTearOffShell(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmDestroyTearOffShell()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmDestroyTearOffShell()\n"));
 }
 
 void
@@ -221,9 +221,9 @@ _XmDismissTearOff(Widget shell, XtPointer closure, XtPointer call_data)
 {
     Widget menu;
     ShellWidget sw = (ShellWidget)shell;
-    XEvent *event = call_data;
+    XEvent *event = (XEvent *)call_data;
 
-    DEBUGOUT(XdbDebug(__FILE__, shell, "_XmDismissTearOff()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, shell, "_XmDismissTearOff()\n"));
 
     if (XtIsSubclass(shell, transientShellWidgetClass))
     {
@@ -258,7 +258,7 @@ _XmTearOffInitiate(Widget w, XEvent *event)
     Widget menu;
     Widget shell;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmTearOffInitiate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTearOffInitiate()\n"));
 
     _XmUngrabKeyboard(w, CurrentTime);
     _XmUngrabPointer(w, CurrentTime);
@@ -267,7 +267,7 @@ _XmTearOffInitiate(Widget w, XEvent *event)
 
     if (!XmIsRowColumn(menu))
     {
-	DEBUGOUT(XdbDebug2(__FILE__, menu, w, "Parent is not a menu\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, menu, w, "Parent is not a menu\n"));
 	return;
     }
 
@@ -379,9 +379,9 @@ _XmTearOffInitiate(Widget w, XEvent *event)
 void
 _XmAddTearOffEventHandlers(Widget w)
 {
-int i;
+    Cardinal i;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmAddTearOffEventHandlers()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmAddTearOffEventHandlers()\n"));
     XtAddEventHandler(w, FocusChangeMask, False, _XmTearOffFocusChangeEventHandler, NULL);
     /*
     XtAddEventHandler(w, ButtonPressMask, False, _XmTearOffBtnDownEventHandler, NULL);
@@ -399,7 +399,7 @@ int i;
 Boolean
 _XmIsTearOffShellDescendant(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmIsTearOffShellDescendant()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmIsTearOffShellDescendant()\n"));
 
     return False;
 }
@@ -408,7 +408,7 @@ void
 _XmLowerTearOffObscuringPoppingDownPanes(Widget ancestor,
 					 Widget tearOff)
 {
-    DEBUGOUT(XdbDebug2(__FILE__, ancestor, tearOff,
+    DEBUGOUT(_LtDebug2(__FILE__, ancestor, tearOff,
 		       "_XmLowerTearOffObscuringPoppingDownPanes()\n"));
 }
 
@@ -416,7 +416,7 @@ void
 _XmRestoreExcludedTearOffToToplevelShell(Widget w,
 					 XEvent *event)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmRestoreExcludedTearOffToToplevelShell()\n"));
 }
 
@@ -431,7 +431,7 @@ CreateTopLevelShell(Widget w)
     Atom delete_atom;
     Widget parent_shell;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "CreateTopLevelShell()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "CreateTopLevelShell()\n"));
 
     /* create the tear off shell's name */
     to_shell_name = XtMalloc(strlen(TEAR_OFF_SHELL_NAME) +
@@ -530,7 +530,7 @@ _XmRestoreTearOffToToplevelShell(Widget w, XEvent *event)
     /* w represents the row column */
     Widget menu_shell = XtParent(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmRestoreTearOffToToplevelShell()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmRestoreTearOffToToplevelShell()\n"));
 
     /* Tear off buttons should not appear in torn off shells */
     if (RC_TearOffControl(w))
@@ -601,7 +601,7 @@ _XmRestoreTearOffToToplevelShell(Widget w, XEvent *event)
     RC_SetTornOff(w, 1);
     RC_SetFromInit(w, 0);
     RC_ParentShell(w) = menu_shell;	/* save off the menu shell */
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmRestoreTearOffToToplevelShell() new parent %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmRestoreTearOffToToplevelShell() new parent %s\n",
 		XtName(XtParent(w))));
     _XmAddTearOffEventHandlers(w);
 }
@@ -614,13 +614,13 @@ _XmRestoreTearOffToMenuShell(Widget w,
     Widget transient = XtParent(w);
     Widget menu_shell;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmRestoreTearOffToMenuShell()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmRestoreTearOffToMenuShell()\n"));
 
     /* Tear off buttons should appear in menu shells */
     if (!RC_TearOffControl(w))
     {
 	/* FIX ME: just manage existing one (if any?) */
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmRestoreTearOffToMenuShell creating"
 			  " tear off control\n"));
 
@@ -645,7 +645,7 @@ _XmRestoreTearOffToMenuShell(Widget w,
     XGCValues values;
     unsigned long mask = 0;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmRestoreTearOffToMenuShell() - Grab a copy of the transientShell %s %s %d %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmRestoreTearOffToMenuShell() - Grab a copy of the transientShell %s %s %d %d\n",
 		XtIsManaged(transient) ? "managed" : "not managed",
 		XtIsManaged(w) ? "managed" : "not managed",
 		XtWidth(transient),
@@ -670,7 +670,7 @@ _XmRestoreTearOffToMenuShell(Widget w,
 			    XtHeight(transient),
 			    transient->core.depth);
 	{
-	int i;
+	Cardinal i;
 
 	    for (i = 0; i < MGR_NumChildren(w); i++)
 	    {
