@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Text.c,v 1.134 2000/12/20 14:11:16 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Text.c,v 1.151 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2000 LessTif Development Team
+ * Copyright (C) 1997-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Text.c,v 1.134 2000/12/20 14:11:16 amai Exp $";
+static const char rcsid[] = "$Id: Text.c,v 1.151 2001/07/27 18:51:57 dannybackx Exp $";
 
 #undef VERBOSE
 
@@ -50,11 +50,16 @@ static const char rcsid[] = "$Id: Text.c,v 1.134 2000/12/20 14:11:16 amai Exp $"
 
 #include <XmI/XmI.h>
 
+#include <Xm/AtomMgr.h>
+#include <Xm/DragC.h>
+#include <Xm/DropSMgr.h>
+#include <Xm/DropTrans.h>
+#include <XmI/AtomMgrI.h>
+#include <XmI/DragDropI.h>
+#include <X11/Xatom.h>
+
 #include <XmI/DebugUtil.h>
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
 
 #define _XmMin(a,b)  ((a) < (b)) ? (a) : (b)
 #define _XmMax(a,b)  ((a) > (b)) ? (a) : (b)
@@ -63,9 +68,9 @@ static const char rcsid[] = "$Id: Text.c,v 1.134 2000/12/20 14:11:16 amai Exp $"
 
 static void ClassInitialize(void);
 
-static void ClassPartInitialize(WidgetClass class);
+static void ClassPartInitialize(WidgetClass widget_class);
 
-static void Initialize(Widget request, Widget new,
+static void Initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
 
 static void Destroy(Widget w);
@@ -83,7 +88,7 @@ static XtGeometryResult query_geometry(Widget w,
 
 static void _XmTextSetEditable(Widget w, Boolean e);
 
-static Boolean SetValues(Widget current, Widget request, Widget new,
+static Boolean SetValues(Widget current, Widget request, Widget new_w,
 			 ArgList args, Cardinal *num_args);
 
 static void RefigureLines(XmTextWidget w);
@@ -99,9 +104,7 @@ static InputCreateProc input_create = _XmTextInputCreate;
 
 void _XmTextInvalidate(XmTextWidget w, XmTextPosition position,
 		       XmTextPosition topos, long delta);
-
 void _XmTextExportValue(Widget w, int offset, XtArgVal *value);
-
 static void TextGetValues(Widget w, ArgList args, Cardinal *num_args);
 
 
@@ -369,7 +372,7 @@ WidgetClass xmTextWidgetClass = (WidgetClass)&xmTextClassRec;
 static void
 InnerInitialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "InnerInitialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -378,7 +381,7 @@ InnerInitialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
 }
 
@@ -390,7 +393,7 @@ InnerDestroy(Widget w)
 {
     /* Destroy Output and Input */
     /* Nah - already done in XmText's destroy method (Destroy). */
-    DEBUGOUT(XdbDebug(__FILE__, w, "InnerDestroy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "InnerDestroy\n"));
 }
 
 /*
@@ -402,7 +405,7 @@ InnerSetValues(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "InnerSetValues: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -414,7 +417,7 @@ InnerSetValues(Widget old, Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     return refresh_needed;
 }
@@ -472,19 +475,10 @@ WidgetClass xmTextInnerObjectClass = (WidgetClass)&xmTextInnerClassRec;
  */
 
 
-
-extern XmFontList _XmFontListCreateDefault(Display *);
-
 static void
 ClassInitialize(void)
 {
-    int len1 = strlen(_XmTextIn_XmTextEventBindings1);
-    int len2 = strlen(_XmTextIn_XmTextEventBindings2);
-    int len3 = strlen(_XmTextIn_XmTextEventBindings3);
-    char *buf = XtMalloc((unsigned)(len1 + len2 + len3 + 1));
-    char *cp = buf;
-
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "ClassInitialize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "ClassInitialize\n"));
 
     textBaseClassExtRec.record_type = XmQmotif;
     xmTextClassRec.core_class.actions =
@@ -492,19 +486,10 @@ ClassInitialize(void)
 
     xmTextClassRec.core_class.num_actions = _XmdefaultTextActionsTableSize;
 
-    (void)strcpy(cp, _XmTextIn_XmTextEventBindings1);
-    cp += len1;
-
-    (void)strcpy(cp, _XmTextIn_XmTextEventBindings2);
-    cp += len2;
-
-    (void)strcpy(cp, _XmTextIn_XmTextEventBindings3);
-
-    xmTextClassRec.core_class.tm_table = buf;
-
 #if XmVERSION > 1
-    if (!XmeTraitSet(xmTextWidgetClass, XmQTaccessTextual, &_XmTextTraitRec)) {
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+    if (!XmeTraitSet((XtPointer)xmTextWidgetClass, XmQTaccessTextual,
+                     (XtPointer) &_XmTextTraitRec)) {
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 		"ClassInitialize: XmeTraitSet failed\n"));
     }
 #endif
@@ -514,36 +499,61 @@ ClassInitialize(void)
 static void
 ClassPartInitialize(WidgetClass widget_class)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "ClassPartInitialize\n"));
+    int len1 = strlen(_XmTextIn_XmTextEventBindings1);
+    int len2 = strlen(_XmTextIn_XmTextEventBindings2);
+    int len3 = strlen(_XmTextIn_XmTextEventBindings3);
+    char *buf = XtMalloc((unsigned)(len1 + len2 + len3 + 1));
+    char *cp = buf;
+
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "ClassPartInitialize\n"));
+
+    /* Moved from ClassInitialize because the Xt routine
+     * CoreClassPartInitialize (Xt/Core.c) will overwrite
+     * the original core_class.tm_table, thus leaking any
+     * malloc'd buffer assigned to tm_table.
+     */
+    (void)strcpy(cp, _XmTextIn_XmTextEventBindings1);
+    cp += len1;
+    (void)strcpy(cp, _XmTextIn_XmTextEventBindings2);
+    cp += len2;
+    (void)strcpy(cp, _XmTextIn_XmTextEventBindings3);
+
+    xmTextClassRec.core_class.tm_table = (String)XtParseTranslationTable(buf);
+
+    XtFree(buf);
+
     _XmFastSubclassInit(widget_class, XmTEXT_BIT);
 }
 
 
 static void
-Initialize(Widget request, Widget new,
+Initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    XmTextWidget w = (XmTextWidget)new;
+    XmTextWidget w = (XmTextWidget)new_w;
     Boolean passedSourceAsArg;
+    Atom import_target[3];
+    Arg ds_args[6];
+    int n = 0;
 
-    DEBUGOUT(XdbDebug(__FILE__, new,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new   X %5i Y %5i W %5i H %5i\n",
 		      *num_args,
 		      XtX(request), XtY(request),
 		      XtWidth(request), XtHeight(request),
-		      XtX(new), XtY(new),
-		      XtWidth(new), XtHeight(new)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new, args, *num_args, False));
+		      XtX(new_w), XtY(new_w),
+		      XtWidth(new_w), XtHeight(new_w)));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     if (XtWidth(request) == 0)
     {
-	XtWidth(new) = 0;
+	XtWidth(new_w) = 0;
     }
     if (XtHeight(request) == 0)
     {
-	XtHeight(new) = 0;
+	XtHeight(new_w) = 0;
     }
 
 #if 0
@@ -555,7 +565,7 @@ Initialize(Widget request, Widget new,
 #endif
 
     w->text.inner_widget = XtCreateWidget("inner", xmTextInnerObjectClass,
-					  new, args, *num_args);
+					  new_w, args, *num_args);
 
     /* initialize the inner to sane values before fetching resources */
     memset((char *)(w->text.inner_widget) + XtOffsetOf(XmTextInnerRec, inner),
@@ -648,13 +658,28 @@ Initialize(Widget request, Widget new,
 
 	Text_Value(w) = NULL;
 	}
+
+    /* initialize default DropSite */
+    import_target[0] = XmInternAtom(XtDisplay(new_w), _XA_COMPOUND_TEXT, False);
+    import_target[1] = XmInternAtom(XtDisplay(new_w), _XA_TEXT, False);
+    import_target[2] = XA_STRING;
+    XtSetArg(ds_args[n], XmNimportTargets, import_target); n++;
+    XtSetArg(ds_args[n], XmNnumImportTargets, 3); n++;
+    XtSetArg(ds_args[n], XmNdropSiteOperations, XmDROP_COPY|XmDROP_MOVE); n++;
+    XtSetArg(ds_args[n], XmNdropProc, _Lttext_process_drop); n++;
+
+    XmDropSiteRegister(new_w, ds_args, n);
 }
 
 
 static void
 Destroy(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "Destroy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Destroy\n"));
+
+#if XmVERSION > 1
+    XmImCloseXIM(w);
+#endif
 
     /* rws 2 Oct 1998
      * This is odd, I thought Xt should be taking care of this
@@ -669,24 +694,28 @@ Destroy(Widget w)
 #if 1
     /* rws 1 Apr 1999
      */
-    XtFree((XtPointer)Text_LineTable(w));
+    XtFree((char *)Text_LineTable(w));
 #endif
-    if(Text_Line(w)) XtFree((XtPointer)Text_Line(w));
-    XtFree((XtPointer)Text_Highlight(w).list);
-    XtFree((XtPointer)Text_OldHighlight(w).list);
-    XtFree((XtPointer)Text_Repaint(w).range);
+    if(Text_Line(w)) XtFree((char *)Text_Line(w));
+    XtFree((char *)Text_Highlight(w).list);
+    XtFree((char *)Text_OldHighlight(w).list);
+    XtFree((char *)Text_Repaint(w).range);
+
+    /* amai: not sure this is necessary ...
+             Check out the register calls for more info.
+    XmDropSiteUnregister(w); */
 }
 
 
 static Boolean
-SetValues(Widget old, Widget request, Widget new,
+SetValues(Widget old, Widget request, Widget new_w,
 	  ArgList args, Cardinal *num_args)
 {
     Boolean refresh_needed = False;
-    XmTextWidget nw = (XmTextWidget)new;
+    XmTextWidget nw = (XmTextWidget)new_w;
     XmTextWidget ow = (XmTextWidget)old;
 
-    DEBUGOUT(XdbDebug(__FILE__, new,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -696,29 +725,29 @@ SetValues(Widget old, Widget request, Widget new,
 		      XtWidth(old), XtHeight(old),
 		      XtX(request), XtY(request),
 		      XtWidth(request), XtHeight(request),
-		      XtX(new), XtY(new),
-		      XtWidth(new), XtHeight(new)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new, args, *num_args, False));
+		      XtX(new_w), XtY(new_w),
+		      XtWidth(new_w), XtHeight(new_w)));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     Text_InSetValues(nw) = True;
 
     if (Text_Value(nw) != Text_Value(ow))
     {
-	XmTextSetString(new, Text_Value(new));
+	XmTextSetString(new_w, Text_Value(new_w));
 
 	refresh_needed = True;
     }
 
     if (Text_WcsValue(nw) != Text_WcsValue(ow))
     {
-	XmTextSetStringWcs(new, Text_WcsValue(new));
+	XmTextSetStringWcs(new_w, Text_WcsValue(new_w));
 
 	refresh_needed = True;
     }
 
     if (Text_Editable(nw) != Text_Editable(ow))
     {
-	_XmTextSetEditable(new, Text_Editable(nw));
+	_XmTextSetEditable(new_w, Text_Editable(nw));
 
 	refresh_needed = True;
     }
@@ -732,9 +761,9 @@ SetValues(Widget old, Widget request, Widget new,
     }
 
     /* Call the SetValues in the input/output objects */
-    (*Text_Input(new)->SetValues) (old, request, new, args, num_args);
+    (*Text_Input(new_w)->SetValues) (old, request, new_w, args, num_args);
 
-    if ((*Text_Output(new)->SetValues) (old, request, new, args, num_args))
+    if ((*Text_Output(new_w)->SetValues) (old, request, new_w, args, num_args))
     {
 	refresh_needed = True;
     }
@@ -797,7 +826,7 @@ Realize(Widget aw, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 {
     XmTextWidget w = (XmTextWidget)aw;
 
-    DEBUGOUT(XdbDebug(__FILE__, aw, "%s:Realize(%d) - valuemask 0x%X - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, aw, "%s:Realize(%d) - valuemask 0x%X - %dx%d\n",
     		__FILE__, __LINE__, *value_mask,
     		XtWidth(aw), XtHeight(aw)));
 
@@ -829,7 +858,7 @@ DoExpose(Widget aw, XEvent *event, Region region)
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, aw, "DoExpose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "DoExpose\n"));
     if (Text_DisableDepth(w) != 0)
 	return;		/* Should we be doing this ? FIX ME */
 
@@ -858,7 +887,7 @@ Resize(Widget aw)
 {
     XmTextWidget w = (XmTextWidget)aw;
 
-    DEBUGOUT(XdbDebug(__FILE__, aw, "%s:resize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, aw, "%s:resize(%d) - %dx%d\n",
     		__FILE__, __LINE__,
     		XtWidth(aw), XtHeight(aw)));
 
@@ -893,7 +922,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     XtWidgetGeometry a;
 
 #define Wants(x)   (proposed->request_mode & x)
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "query_geometry proposed width=%d height=%d mode=%X\n",
 		   proposed->width, proposed->height, proposed->request_mode));
 
@@ -944,7 +973,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 	return XtGeometryAlmost;
     }
 #else
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "query_geometry proposed width=%d height=%d mode=%X\n",
 		   proposed->width, proposed->height, proposed->request_mode));
 
@@ -961,7 +990,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 static void
 Redisplay(XmTextWidget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)w, "Redisplay\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "Redisplay\n"));
 
     if (Text_DisableDepth(w) != 0)
 	return;
@@ -1007,11 +1036,11 @@ GetSecResData(WidgetClass wc, XmSecondaryResourceData **resdata)
 static void
 LineIncrease(XmTextWidget w, LineNum num)
 {
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)w, "LineIncrease %d\n",num));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "LineIncrease %d\n",num));
     if (num > Text_LineMax(w))
     {
 	LineNum start = Text_LineMax(w);
-	int i;
+	Cardinal i;
 
 	Text_Line(w) = (Line)XtRealloc((char *)Text_Line(w),
 				       sizeof(LineRec) * num);
@@ -1046,13 +1075,14 @@ static void
 RefigureLines(XmTextWidget w)
 {
     XmTextPosition pos, next;
-    int nlines, i;
+    int nlines;
+    Cardinal i;
     Line line = NULL;
     XmTextLineTable lte;
     LineTableExtra extra;
     Boolean more;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)w, "RefigureLines\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "RefigureLines\n"));
 /*
  * DisableDepth is meant to optimize frequent updates to XmText.
  * This probably means we shouldn't do anything here ...
@@ -1075,7 +1105,7 @@ RefigureLines(XmTextWidget w)
 				   Text_LineTable(w)[i].start_pos != 0);
 	 i++)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "RefigureLines: [%d] start_pos %d virt %d\n",
 			  i, Text_LineTable(w)[i].start_pos,
 			  Text_LineTable(w)[i].virt_line));
@@ -1166,7 +1196,7 @@ RefigureLines(XmTextWidget w)
 
     /* This is too verbose to stay on */
 #ifdef VERBOSE
-    if (XdbInDebug(__FILE__, (Widget)w))
+    if (_LtDebugInDebug(__FILE__, (Widget)w))
     {
 	int i;
 
@@ -1176,13 +1206,13 @@ RefigureLines(XmTextWidget w)
 
 	    if (line->extra)
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 				"RefigureLines: line[%d]: start=%d width=%d\n",
 				  i, line->start, line->extra->width));
 	    }
 	    else
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 				"RefigureLines: line[%d]: start=%d width=NA\n",
 				  i, line->start));
 	    }
@@ -1190,7 +1220,7 @@ RefigureLines(XmTextWidget w)
     }
 
 #if VERBOSE
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "RefigureLines: top on line %d, bottompos %d\n",
 		      i, Text_BottomPos(w)));
 #endif
@@ -1264,7 +1294,7 @@ _XmTextUpdateLineTable(Widget w,
     unsigned int index;
     Boolean wrap = _XmTextShouldWordWrap(tw), next_is_virtual;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextUpdateLineTable start %d end %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextUpdateLineTable start %d end %d\n",
     		start, end));
     Text_NeedsRefigureLines(w) = True;
     Text_NeedsRedisplay(w) = True;
@@ -1293,9 +1323,9 @@ _XmTextUpdateLineTable(Widget w,
 
     end = Text_LastPos(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmTextUpdateLineTable(start %d end %d update %s) %s\n",
-		      start, end, XdbBoolean2String(update),
+		      start, end, _LtDebugBoolean2String(update),
 		      wrap ? "wrap" : ""));
 
 /* rws 10 Feb 1999
@@ -1347,7 +1377,7 @@ _XmTextUpdateLineTable(Widget w,
 	max_cols = max_cols < Out_ColumnsSet(od) ? Out_ColumnsSet(od) : max_cols;
 	max_lines = max_lines < Out_RowsSet(od) ? Out_RowsSet(od) : max_lines;
 
-	DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmTextUpdateLineTable - %d %d %d %d\n",
 		      max_lines, max_cols, Out_Rows(od), Out_Columns(od)));
     	XtFree(value);
@@ -1366,7 +1396,6 @@ _XmTextUpdateLineTable(Widget w,
     	}
     }
 
-
     if (wrap)
     {
 	/*
@@ -1376,11 +1405,11 @@ _XmTextUpdateLineTable(Widget w,
 	{
 	    if (index >= Text_TableSize(w))
 	    {
-		int i = Text_TableSize(w);
+		Cardinal i = Text_TableSize(w);
 
 		Text_TableSize(w) += LINETABLE_INCREMENT;
 		Text_LineTable(w) = (XmTextLineTable)
-		    XtRealloc((XtPointer)Text_LineTable(w),
+		    XtRealloc((char *)Text_LineTable(w),
 			      sizeof(XmTextLineTableRec) * Text_TableSize(w));
 
 		for (; i < Text_TableSize(w); i++)
@@ -1417,7 +1446,7 @@ _XmTextUpdateLineTable(Widget w,
 		    line->start_pos = start;
 		    line->virt_line = next_is_virtual;
 
-		    DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+		    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		       "_XmTextUpdateLineTable: line %d start %d virtual %d\n",
 				      index, line->start_pos, line->virt_line));
 
@@ -1440,7 +1469,7 @@ _XmTextUpdateLineTable(Widget w,
 	{
 	    if (index >= Text_TableSize(w))
 	    {
-		int i = Text_TableSize(w);
+		Cardinal i = Text_TableSize(w);
 
 		Text_TableSize(w) += LINETABLE_INCREMENT;
 		Text_LineTable(w) = (XmTextLineTable)
@@ -1529,7 +1558,7 @@ _XmTextGetTableIndex(XmTextWidget w, XmTextPosition pos)
     for (; current->start_pos > pos; current--, i--);
 
 #if VERBOSE
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "XmTextGetTableIndex Pos %d Index %d\n", pos, i));
 #endif
 
@@ -1580,7 +1609,7 @@ _XmTextInsert(Widget w, XmTextPosition position, char *string, XEvent *evp)
     XmTextBlockRec block;
     XmTextPosition startret, endret;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextInsert\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextInsert\n"));
 
     if (XtIsSubclass(w, xmTextFieldWidgetClass))
     {
@@ -1629,7 +1658,7 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
     cbs.doit = True;
     cbs.newInsert = position;
 
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmTextSetCursorPosition Pos %d \n",
 		      position));
 
@@ -1655,7 +1684,7 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
     if (cbs.doit)
     {
 #if VERBOSE
-	DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "Text_CursorPos before draw: %08x\n",
 			  Text_CursorPos(w)));
 #endif
@@ -1672,7 +1701,7 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
 #endif
 
 #if VERBOSE
-	DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "Text_CursorPos after draw: %08x\n",
 			  Text_CursorPos(w)));
 #endif
@@ -1692,13 +1721,14 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
 
 	(*Text_Output(w)->DrawInsertionPoint) (tw, Text_CursorPos(w), on);
     }
+    (void)_XmImSendSpot(w);
 }
 
 
 static void
 _XmTextSetEditable(Widget w, Boolean e)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextSetEditable()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextSetEditable()\n"));
 
     if (!XtIsRealized(w))
     {
@@ -1757,7 +1787,7 @@ extern void
 _XmTextInvalidate(XmTextWidget w, XmTextPosition position,
 		  XmTextPosition topos, long delta)
 {
-    int i;
+    Cardinal i;
 
     for (i = 0;
 	 i < Text_LineCount(w) && Text_Line(w)[i].start <= position;
@@ -1799,7 +1829,7 @@ XmCreateScrolledText(Widget parent, char *name, Arg *arglist, Cardinal argcount)
 {
     Widget sw, w;
     char *sname;
-    int i;
+    Cardinal i;
     Arg *al;
 
     if (name == NULL)
@@ -1825,7 +1855,7 @@ XmCreateScrolledText(Widget parent, char *name, Arg *arglist, Cardinal argcount)
 
     sw = XtCreateManagedWidget(sname, xmScrolledWindowWidgetClass, parent,
 			       al, i);
-    XtFree((XtPointer)sname);
+    XtFree((char *)sname);
 
     i = argcount;
     XtSetArg(al[i], XmNeditMode, XmMULTI_LINE_EDIT); i++;
@@ -1835,7 +1865,7 @@ XmCreateScrolledText(Widget parent, char *name, Arg *arglist, Cardinal argcount)
 		  _XmDestroyParentCallback,
 		  (XtPointer)w);
 
-    XtFree((XtPointer)al);
+    XtFree((char *)al);
 
     return w;
 }
@@ -2412,7 +2442,7 @@ XmTextPaste(Widget w)
 	    XtFree(buf);
 	    return False;
 	}
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	    "XmTextPaste: should be getting %ld bytes\n", nbytes));
 
 	while ((r = XmClipboardEndRetrieve(dpy, win)) == XmClipboardLocked)
@@ -2511,7 +2541,7 @@ XmTextReplace(Widget w, XmTextPosition from_pos, XmTextPosition to_pos, char *va
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmTextReplace(from %d to %d '%s'\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextReplace(from %d to %d '%s'\n",
 		      from_pos, to_pos, value));
 
     block.ptr = value;
@@ -2625,7 +2655,7 @@ XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighli
     if (left >= right || left < 0 )
     {
 	/* FIX ME */
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmTextSetHighlight %d >= %d, not sure what to do.\n",
 			  left, right));
 
@@ -2634,17 +2664,17 @@ XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighli
 
     if (XtIsSubclass(w, xmTextWidgetClass))
     {
-	int		i, j, k, l;
+	Cardinal i, j, k, l;
 	XmHighlightMode lm, rm;
 
 #if 0
 	fprintf(stderr,
 			  "XmTextSetHighlight(%d,%d,%s)\n",
-			  left, right, XdbHighlightMode2String(mode));
+			  left, right, _LtDebugHighlightMode2String(mode));
 #endif
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmTextSetHighlight(%d,%d,%s)\n",
-			  left, right, XdbHighlightMode2String(mode)));
+			  left, right, _LtDebugHighlightMode2String(mode)));
 
 	/* Provide for initial entries if there's none */
 	if (Text_Highlight(w).number == 0) 
@@ -2701,7 +2731,7 @@ XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighli
 		{
 		    Text_Highlight(w).maximum += 32;
 		    Text_Highlight(w).list = (_XmHighlightRec *)XtRealloc(
-				(XtPointer)Text_Highlight(w).list,
+				(char *)Text_Highlight(w).list,
 				Text_Highlight(w).maximum * sizeof(_XmHighlightRec));
 		}
 
@@ -2737,7 +2767,7 @@ XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighli
 	    {
 		Text_Highlight(w).maximum += 32;
 		Text_Highlight(w).list = (_XmHighlightRec *)XtRealloc(
-			    (XtPointer)Text_Highlight(w).list,
+			    (char *)Text_Highlight(w).list,
 			    Text_Highlight(w).maximum * sizeof(_XmHighlightRec));
 	    }
 	    for (k=Text_Highlight(w).number; k>i; k--) 
@@ -2754,7 +2784,7 @@ XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighli
 		fprintf(stderr,
 			  "\tXmTextSetHighlight -> [%d] %d %s\n",
 			  i, Text_Highlight(w).list[i].position,
-			  XdbHighlightMode2String(Text_Highlight(w).list[i].mode));
+			  _LtDebugHighlightMode2String(Text_Highlight(w).list[i].mode));
 #endif
 
 	if (XtIsRealized(w))
@@ -2814,7 +2844,7 @@ extern void
 XmTextSetSelection(Widget w, XmTextPosition first, XmTextPosition last,
 		   Time time)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmTextSetSelection(%d,%d)\n", first, last));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextSetSelection(%d,%d)\n", first, last));
 
     if (XtIsSubclass(w, xmTextWidgetClass))
     {
@@ -2861,7 +2891,7 @@ XmTextSetString(Widget w, char *value)
 #endif
 	Text_CursorPos(w) = 0;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "XmTextSetString(%s), lastpos %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmTextSetString(%s), lastpos %d\n",
 		value, Text_LastPos(w)));
 
 	_XmTextUpdateLineTable(w, 0, 0, NULL, False);
@@ -2928,7 +2958,7 @@ XmTextSetSource(Widget w, XmTextSource s,
 {
     XmTextWidget tw = (XmTextWidget)w;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmTextSetSource\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextSetSource\n"));
 
     if (s == NULL)
     {
@@ -2978,7 +3008,7 @@ XmTextScroll(Widget aw, int n)
    we would rather like to be able to scroll down to the last line */
 		       Text_TotalLines(w) ) - Text_LineCount(w) + 1;
     }
-    DEBUGOUT(XdbDebug(__FILE__, aw, "XmTextScroll index=%d n=%d\n", index, n));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "XmTextScroll index=%d n=%d\n", index, n));
 
     Text_TableIndex(w) = index;
     XmTextSetTopCharacter(aw, Text_LineTable(w)[index].start_pos);
@@ -2995,7 +3025,7 @@ XmTextSetTopCharacter(Widget w, XmTextPosition top_character)
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmTextSetTopCharacter top_character=%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextSetTopCharacter top_character=%d\n",
 		      top_character));
 
     if (Text_EditMode(w) == XmSINGLE_LINE_EDIT)
@@ -3031,7 +3061,7 @@ XmTextShowPosition(Widget aw, XmTextPosition position)
     XmTextWidget w = (XmTextWidget)aw;
     unsigned int top_index, index, bottom_index;
 
-    DEBUGOUT(XdbDebug(__FILE__, aw, "XmTextShowPosition pos=%d\n", position));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "XmTextShowPosition pos=%d\n", position));
 
     if (XtIsSubclass(aw, xmTextFieldWidgetClass))
     {
@@ -3081,7 +3111,7 @@ XmTextShowPosition(Widget aw, XmTextPosition position)
 extern XmTextPosition
 XmTextXYToPos(Widget w, Position x, Position y)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmTextXYToPos x=%d y=%d\n", x, y));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextXYToPos x=%d y=%d\n", x, y));
 
     if (XtIsSubclass(w, xmTextFieldWidgetClass))
     {
@@ -3103,7 +3133,7 @@ _XmTextExportValue(Widget w, int offset, XtArgVal *value)
 {
     *value = (XtArgVal)XmTextGetString(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmTextExportValue: value '%s'\n",
 		      (char *)*value));
 }
@@ -3138,8 +3168,8 @@ TextGetValues(Widget w, ArgList args, Cardinal *num_args)
     }
 
     /* Be verbose about what they're trying to find out */
-    DEBUGOUT(XdbDebug(__FILE__, w, "TextGetValues :\n"));
-    DEBUGOUT(XdbPrintArgList(__FILE__, w, args, *num_args, True));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TextGetValues :\n"));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, w, args, *num_args, True));
 }
 
 
@@ -3194,14 +3224,14 @@ _XmTextNumLines(XmTextWidget widget)
 static XtPointer
 _XmText_TraitGetValue(Widget w, int format)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmText_TraitGetValue(%s)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmText_TraitGetValue(%s)\n",
 		(format == XmFORMAT_XmSTRING) ? "XmFORMAT_XmSTRING" :
 		(format == XmFORMAT_MBYTE) ? "XmFORMAT_MBYTE" :
 		(format == XmFORMAT_WCS) ? "XmFORMAT_WCS" : "??"));
 
 	switch (format) {
 	case XmFORMAT_XmSTRING:
-		return XmStringCreateSimple(Text_Value(w));
+		return (XtPointer)XmStringCreateSimple(Text_Value(w));
 	case XmFORMAT_MBYTE:
 		return XtNewString(XmTextGetString(w)); /* FIX ME */
 	case XmFORMAT_WCS:
@@ -3217,7 +3247,7 @@ _XmText_TraitSetValue(Widget w, XtPointer value, int format)
 {
 	char    *s;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmText_TraitSetValue(%s)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmText_TraitSetValue(%s)\n",
 		(format == XmFORMAT_XmSTRING) ? "XmFORMAT_XmSTRING" :
 		(format == XmFORMAT_MBYTE) ? "XmFORMAT_MBYTE" :
 		(format == XmFORMAT_WCS) ? "XmFORMAT_WCS" : "??"));
@@ -3230,11 +3260,11 @@ _XmText_TraitSetValue(Widget w, XtPointer value, int format)
 	    return;
 	case XmFORMAT_MBYTE:
 	    /* FIX ME */
-	    XmTextSetString(w, value);
+	    XmTextSetString(w, (char *)value);
 	    return;
 	case XmFORMAT_WCS:
 	    /* FIX ME */
-	    XmTextSetString(w, value);
+	    XmTextSetString(w, (char *)value);
 	    return;
 	default:
 	    return;
@@ -3245,7 +3275,7 @@ _XmText_TraitSetValue(Widget w, XtPointer value, int format)
 static int
 _XmText_TraitPreferredFormat(Widget w)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmText_TraitPreferredFormat\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmText_TraitPreferredFormat\n"));
 
 	return XmFORMAT_WCS;
 }
