@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextStrSo.c,v 1.52 2000/12/07 17:57:31 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextStrSo.c,v 1.56 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: TextStrSo.c,v 1.52 2000/12/07 17:57:31 amai Exp $";
+static const char rcsid[] = "$Id: TextStrSo.c,v 1.56 2001/07/27 18:51:57 dannybackx Exp $";
 
 /*
  * Empirical evidence (fooling around with the structures found in Motif
@@ -40,7 +40,7 @@ static const char rcsid[] = "$Id: TextStrSo.c,v 1.52 2000/12/07 17:57:31 amai Ex
 #define	DO_SANITY
 
 /* Defining this is a bit too verbose for my liking ... */
-#undef VERBOSE_XdbDebug
+#undef VERBOSE__LtDebug
 
 #include <LTconfig.h>
 
@@ -50,6 +50,7 @@ static const char rcsid[] = "$Id: TextStrSo.c,v 1.52 2000/12/07 17:57:31 amai Ex
 #include <Xm/XmP.h>
 #include <Xm/TextP.h>
 #include <Xm/VendorSEP.h>
+#include <Xm/AtomMgr.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -272,7 +273,7 @@ CheckSize(XmSourceData d, int len)
 	d->maxlength += i + 1;
 	d->ptr = XtRealloc(d->ptr, d->maxlength);
 
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "*source->CheckSize: Alloced new space\n"));
     }
 }
@@ -516,7 +517,7 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
     XmSourceData d = source->data;
     Boolean found = False;
     char *ptr;
-#ifdef VERBOSE_XdbDebug
+#ifdef VERBOSE__LtDebug
     XmTextPosition ipos = pos;
 #endif
 
@@ -611,8 +612,8 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 
 	    if (found)
 	    {
-#ifdef VERBOSE_XdbDebug
-		DEBUGOUT(XdbDebug(__FILE__, (Widget)d->widgets[0],
+#ifdef VERBOSE__LtDebug
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
 				  "Scan(%d)=>%d\n", ipos, pos));
 #endif
 		count--;
@@ -673,8 +674,8 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 
 	    if (found)
 	    {
-#ifdef VERBOSE_XdbDebug
-		DEBUGOUT(XdbDebug(__FILE__, (Widget)d->widgets[0],
+#ifdef VERBOSE__LtDebug
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
 				  "Scan(%d)=>%d\n", ipos, pos));
 #endif
 		count--;
@@ -693,8 +694,8 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 	}
     }
 
-#ifdef VERBOSE_XdbDebug
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)d->widgets[0],
+#ifdef VERBOSE__LtDebug
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
 		      "Scan(%d)=>%d\n", ipos, pos));
 #endif
     if ( dir == XmsdRight && pos != d->length )
@@ -742,11 +743,10 @@ _XmTextConvertSelection(Widget w, Atom *selection, Atom *target, Atom *type,
 {
     XmSourceData d = Text_Source(w)->data;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextConvertSelection\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextConvertSelection\n"));
 
-    if (*target == XA_STRING && d->hasselection)
+    if (d->hasselection)
     {
-	*length = (long)(d->right - d->left);
 #if 0
 	/* rws 12 Dec 1997
 	   I think we need to make a copy of the value here. In ml if you
@@ -755,11 +755,49 @@ _XmTextConvertSelection(Widget w, Atom *selection, Atom *target, Atom *type,
 	   the contents of value.
 	 */
 	*value = &d->ptr[d->left];
-#else
-	*value = XtMalloc(d->right - d->left + 1);
-	strncpy(*value, &d->ptr[d->left], d->right - d->left);
 #endif
-	*type = XA_STRING;
+	Atom atom_comp_text;
+	Atom atom_text;
+
+	atom_comp_text =  XmInternAtom(XtDisplay(w), "COMPOUND_TEXT", False);
+	atom_text =  XmInternAtom(XtDisplay(w), "TEXT", False);
+	if (*target == XA_STRING){
+	    *length = (long)(d->right - d->left);
+	    *value = XtMalloc(d->right - d->left + 1);
+	    strncpy((char *)*value, &d->ptr[d->left], d->right - d->left);
+	    *type = XA_STRING;
+	}
+	else if (*target == atom_comp_text || *target == atom_text){
+
+	    XTextProperty prop;
+	    char *buf;
+	    int ret;
+
+	    buf = XtMalloc(d->right - d->left + 1);
+	    strncpy(buf, &d->ptr[d->left], d->right - d->left);
+	    buf[d->right - d->left] = '\0';
+
+	    ret = XmbTextListToTextProperty(XtDisplay(w), &buf, 1,
+	    			XCompoundTextStyle, &prop);
+
+	    XtFree(buf);
+	    if (ret != 0){
+	    	*length = 0;
+	    	*value  = NULL;
+	    }
+	    else{
+	    	buf = XtMalloc(prop.nitems + 1);
+		strncpy(buf, prop.value, prop.nitems);
+		buf[prop.nitems] = '\0';
+	    	*length = prop.nitems;
+	    	*value  = buf;
+	    }
+	    *type = atom_comp_text;
+
+	}
+	else
+	    return False;
+
 	*format = 8;
 	return True;
     }
@@ -778,7 +816,7 @@ _XmTextLoseSelection(Widget w, Atom *selection)
 
     if (*selection == XA_PRIMARY)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextLoseSelection(PRIMARY)\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextLoseSelection(PRIMARY)\n"));
 
 	XmTextSetHighlight(w, 0, XmTextGetLastPosition(w),
 			   XmHIGHLIGHT_NORMAL);
@@ -795,7 +833,7 @@ _XmTextLoseSelection(Widget w, Atom *selection)
     }
     else
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmTextLoseSelection(?)\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextLoseSelection(?)\n"));
 	/* ??? */
     }
 }
@@ -817,7 +855,7 @@ SetSelection(XmTextSource source, XmTextPosition left,
     int i;
     Boolean gain = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmTextStrSource SetSelection %d %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmTextStrSource SetSelection %d %d\n",
 		      left, right));
 
     if (left >= right)
@@ -854,7 +892,7 @@ SetSelection(XmTextSource source, XmTextPosition left,
     source->data->prim_time = time;
 
     /* Xt, callbacks */
-    DEBUGOUT(XdbDebug(__FILE__, (Widget)d->widgets[0],
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
 		      "XtOwnSelection(_, XA_PRIMARY, ...)\n"));
 
     if (!XtOwnSelection((Widget)d->widgets[0], XA_PRIMARY, time,
@@ -971,7 +1009,7 @@ _XmStringSourceGetValue(XmTextSource source, Boolean want_wchar)
 
     if (want_wchar)
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 	   "_XmStringSourceGetValue: wide characters not implemented yet.\n"));
 
 	/* Returning NULL seems to do strange things */
@@ -985,7 +1023,7 @@ _XmStringSourceGetValue(XmTextSource source, Boolean want_wchar)
     strncpy(txt, d->ptr, d->length);
     txt[d->length] = '\0';
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmStringSourceGetValue => %p '%s'\n", txt, txt));
 
     return txt;
@@ -1138,7 +1176,7 @@ _XmStringSourceGetString(XmTextWidget w,
 #else
     if (want_wchar)
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 	  "_XmStringSourceGetString: wide characters not implemented yet.\n"));
 
 	return NULL;
