@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ToggleB.c,v 1.74 2000/09/29 22:51:55 amai Exp $
+ * $Id: ToggleB.c,v 1.79 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ToggleB.c,v 1.74 2000/09/29 22:51:55 amai Exp $";
+static const char rcsid[] = "$Id: ToggleB.c,v 1.79 2001/07/27 18:51:57 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -39,11 +39,11 @@ static const char rcsid[] = "$Id: ToggleB.c,v 1.74 2000/09/29 22:51:55 amai Exp
 #include <Xm/CascadeBG.h>
 #include <Xm/RepType.h>
 #include <Xm/TransltnsP.h>
+#include <Xm/ToggleBGP.h>
 #include <X11/ShellP.h>
 
 #include <XmI/DebugUtil.h>
 
-#include <Xm/ToggleBGP.h>
 
 /* Some M*tif versions (e.g. 1.2.6 on Solaris 2.6) leave less room above and
  * below the indicator than others (e.g. 1.2.5 on HP-UX 10, my reference).
@@ -484,7 +484,7 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -493,7 +493,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     TB_Armed(new_w) = False;
 
@@ -669,7 +669,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "ToggleB set_values()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleB set_values()\n"));
 
     if (TB_IndType(old) != TB_IndType(new_w) &&
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
@@ -941,7 +941,7 @@ resize(Widget w)
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB Expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB Expose\n"));
     draw_toggle(w, event, region, True, 0);
 }
 
@@ -994,6 +994,8 @@ Select(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	{
 	    RC_MenuMenuCallback(w, &cbs);
 	}
+	/* Menu callback might cancel the set (radioAlwaysOne). */
+	cbs.set = TB_Set(w);
 	if (!Lab_SkipCallback(w) && TB_ValueChangedCallback(w))
 	{
 	    XFlush(XtDisplay(w));
@@ -1027,7 +1029,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     Boolean poppedUp;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:ArmAndActivate(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:ArmAndActivate(%d)\n",
     	__FILE__, __LINE__));
     Arm(w, event, params, num_params);
 
@@ -1046,7 +1048,7 @@ ButtonUp(Widget w, XEvent *event, String *params, Cardinal *num_params)
     Boolean validButton, poppedUp;
     XmToggleButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB ButtonUp()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB ButtonUp()\n"));
 
     /* queue events until the next button event */
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
@@ -1082,7 +1084,7 @@ ButtonUp(Widget w, XEvent *event, String *params, Cardinal *num_params)
     TB_Set(w) = NEXT_TOGGLE(w);
     draw_toggle(w, NULL, NULL, False, TB_Set(w));
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ButtonUp: HERE\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonUp: HERE\n"));
 
     cbs.reason = XmCR_VALUE_CHANGED;
     cbs.event = event;
@@ -1119,7 +1121,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
     /* queue events until the next button event. */
     XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB ButtonDown()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB ButtonDown()\n"));
 
     if (event && (event->type == ButtonPress))
     {
@@ -1134,7 +1136,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
     RC_MenuShellPopdown(w, event, &poppedUp);
     {
-	int i;
+	Cardinal i;
 	Widget menu = XtParent(w);
 
 	for (i = 0; i < MGR_NumChildren(menu); i++)
@@ -1183,7 +1185,7 @@ EnterWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmToggleButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB Enter\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB Enter\n"));
 
     if (!IN_MENU(w))
     {
@@ -1259,7 +1261,7 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 KeySelect(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "KeySelect\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KeySelect\n"));
 
     /* FIX ME */
 }
@@ -1776,7 +1778,7 @@ XmToggleButtonSetState(Widget w, Boolean state, Boolean notify)
 {
     XmToggleButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleB SetState: %d %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleB SetState: %d %d\n",
 		      state, notify));
 
     _XmObjectLock(w);
@@ -1800,6 +1802,8 @@ XmToggleButtonSetState(Widget w, Boolean state, Boolean notify)
 	    {
 		RC_MenuMenuCallback(w, &cbs);
 	    }
+	    /* Menu callback might cancel the set (radioAlwaysOne). */
+	    cbs.set = TB_Set(w);
 	    if (!Lab_SkipCallback(w) && TB_ValueChangedCallback(w))
 	    {
 		XFlush(XtDisplay(w));
