@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ToggleBG.c,v 1.74 2000/09/29 22:51:55 amai Exp $
+ * $Id: ToggleBG.c,v 1.79 2001/07/27 18:51:58 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ToggleBG.c,v 1.74 2000/09/29 22:51:55 amai Exp $";
+static const char rcsid[] = "$Id: ToggleBG.c,v 1.79 2001/07/27 18:51:58 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -470,9 +470,9 @@ secondary_object_create(Widget request,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "ToggleButtonGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -630,7 +630,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "ToggleBG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleBG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -835,7 +835,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -940,7 +940,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "ToggleBG set_values\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleBG set_values\n"));
 
     if (TBG_IndType(old) != TBG_IndType(new_w) &&
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
@@ -1181,7 +1181,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1273,7 +1273,7 @@ resize(Widget w)
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleBG Expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleBG Expose\n"));
     draw_toggle(w, event, region, True, 0);
 }
 
@@ -1334,6 +1334,8 @@ Select(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	{
 	    RC_MenuMenuCallback(w, &cbs);
 	}
+	/* Menu callback might cancel the set (radioAlwaysOne). */
+	cbs.set = TBG_Set(w);
 	if (!LabG_SkipCallback(w) && TBG_ValueChangedCallback(w))
 	{
 	    XFlush(XtDisplay(w));
@@ -1477,7 +1479,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	RC_MenuShellPopdown(w, event, &poppedUp);
     }
     {
-	int i;
+	Cardinal i;
 	Widget menu = XtParent(w);
 
 	for (i = 0; i < MGR_NumChildren(menu); i++)
@@ -1620,7 +1622,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     {
     case XmARM_EVENT:
     case XmMULTI_ARM_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget got arm event\n"));
 	if (IN_MENU(gadget))
 	{
@@ -1634,7 +1636,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 
     case XmACTIVATE_EVENT:
     case XmMULTI_ACTIVATE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget got activate event\n"));
 	if (IN_MENU(gadget))
 	{
@@ -1648,19 +1650,19 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmENTER_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget enter window\n"));
 	EnterWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmLEAVE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget leave window\n"));
 	LeaveWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmMOTION_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget motion event\n"));
 	break;
 
@@ -2238,6 +2240,8 @@ XmToggleButtonGadgetSetState(Widget w, Boolean state, Boolean notify)
 	    {
 		RC_MenuMenuCallback(w, &cbs);
 	    }
+	    /* Menu callback might cancel the set (radioAlwaysOne). */
+	    cbs.set = TBG_Set(w);
 	    if (!LabG_SkipCallback(w) && TBG_ValueChangedCallback(w))
 	    {
 		XFlush(XtDisplay(w));
