@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Vendor.c,v 1.68 2000/12/17 18:54:27 rwscott Exp $
+ * $Id: Vendor.c,v 1.80 2001/07/27 18:51:58 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996-2000 LessTif Development Team
+ * Copyright (C) 1996-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Vendor.c,v 1.68 2000/12/17 18:54:27 rwscott Exp $";
+static const char rcsid[] = "$Id: Vendor.c,v 1.80 2001/07/27 18:51:58 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -31,13 +31,25 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.68 2000/12/17 18:54:27 rwscott Ex
 #include <stdlib.h>
 #include <string.h>
 
+/* amai, 5/2001: (This is not very nice ...)
+   Later on we use some internal stuff from the Intrinsics which we 
+   should _not_ use. In rare conditions we may lack some stuff from the
+   headers if this setting is not done (-> e.g. _XtBoolean).
+   I hope that this does not hurt anywhere. */ 
+#ifndef FUNCPROTO
+#define FUNCPROTO 11
+#endif
+
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
 #include <X11/ShellP.h>
 #include <X11/Vendor.h>
 #include <X11/VendorP.h>
+
 #include <XmI/XmI.h>
+#include <XmI/AtomMgrI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/BulletinBP.h>
@@ -53,24 +65,22 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.68 2000/12/17 18:54:27 rwscott Ex
 #include <Xm/DialogSEP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/VendorS.h>
-#include <XmI/AtomMgrI.h>
-
-#include <XmI/DebugUtil.h>
-
 
 #if XmVERSION > 1
 #include <Xm/TraitP.h>
 #endif
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
+#include <XmI/DebugUtil.h>
 
+#ifdef __EMX__
+extern void _LtXmFixupVendorShell(void);
+unsigned long _DLL_InitTerm(unsigned long mod_handle, unsigned long flag);
+#endif
 
 /* We use a 'private', i.e. non-declared but actually
    exported call from OpenGroup's Intrinsic sources
-   (lib/Xt/Callback.c) in this file.
-   Note that we don't give the precise type here ...
+   (lib/Xt/Callback.c) here.
+   Note that we don't give the precise prototype:
  */
 extern void 
 _XtRemoveCallback (
@@ -86,56 +96,37 @@ _XtRemoveCallback (
  ***************************************************************************/
 
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget req, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static Boolean set_values(Widget old, Widget req, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
 static void destroy(Widget w);
-
 static void realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
-
 static void change_managed(Widget w);
-
 static void resize(Widget w);
-
 static void get_values_prehook(Widget widget,
 			       ArgList args, Cardinal *num_args);
-
 static void get_values_posthook(Widget widget,
 				ArgList args, Cardinal *num_args);
-
 static void initialize_prehook(Widget req, Widget new_w,
 			       ArgList args, Cardinal *num_args);
-
 static void initialize_posthook(Widget req, Widget new_w,
 				ArgList args, Cardinal *num_args);
-
 static Boolean set_values_prehook(Widget old, Widget req, Widget new_w,
 				  ArgList args, Cardinal *num_args);
-
 static Boolean set_values_posthook(Widget old, Widget req, Widget new_w,
 				   ArgList args, Cardinal *num_args);
-
 static void insert_child(Widget w);
-
 static void delete_child(Widget w);
-
 static XtGeometryResult geometry_manager(Widget wid,
 					 XtWidgetGeometry *request,
 					 XtWidgetGeometry *reply);
-
 static Cardinal get_sec_res_data(WidgetClass wc,
 				 XmSecondaryResourceData **data);
-
 static void secondary_object_create(Widget req, Widget new_w,
 				    ArgList args, Cardinal *num_args);
-
 static void WmProtocolHandler(Widget w, XtPointer client, XtPointer call);
 
 /*
@@ -144,7 +135,6 @@ static void WmProtocolHandler(Widget w, XtPointer client, XtPointer call);
 static void LTAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded,
 		      XmVendorShellExtObject ve,
 		      XmVendorShellExtObject grabber);
-
 static void LTRemoveGrab(Widget wid,
 			 XmVendorShellExtObject ve,
 			 Boolean remove_grab_physically);
@@ -157,17 +147,15 @@ static void LTShellPopupCallback(Widget w,
 static void LTShellPopdownCallback(Widget w,
 				   XtPointer ClientData,
 				   XtPointer CallbackData);
-
 static void VendorFromHorizontalPixels(Widget w, int offset, XtArgVal *value);
-
 static void VendorFromVerticalPixels(Widget w, int offset, XtArgVal *value);
-
 static XmImportOperator VendorToHorizontalPixels(Widget w, int offset,
 						 XtArgVal *value);
-
 static XmImportOperator VendorToVerticalPixels(Widget w, int offset,
 					       XtArgVal *value);
 
+static Bool ConfigEventForMe(Display *dpy, XEvent *event, char *arg);
+
 /*
  * the following is for the extension record for LessTif Vendor Shells
  * this is needed before the shell record as the shell's base class extension
@@ -175,12 +163,11 @@ static XmImportOperator VendorToVerticalPixels(Widget w, int offset,
  */
 static void _XmVendorExtInitialize(Widget req, Widget new_w,
 				   ArgList args, Cardinal *num_args);
-
 static Boolean _XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
 				     ArgList args, Cardinal *nargs);
-
 static void _XmVendorExtDestroy(Widget w);
 
+
 #define Offset(field) XtOffsetOf(XmVendorShellExtRec, vendor.field)
 static XtResource ext_resources[] =
 {
@@ -286,6 +273,7 @@ static XtResource ext_resources[] =
     },
 };
 
+
 static XmSyntheticResource ext_syn_resources[] =
 {
     {
@@ -352,7 +340,7 @@ static XmSyntheticResource ext_syn_resources[] =
 #endif
 };
 
-/* *INDENT-OFF* */
+
 XmVendorShellExtClassRec xmVendorShellExtClassRec = {
     /* Object Class Part */
     {
@@ -415,6 +403,7 @@ XmVendorShellExtClassRec xmVendorShellExtClassRec = {
     }
 };
 
+
 WidgetClass xmVendorShellExtObjectClass = (WidgetClass) &xmVendorShellExtClassRec;
 
 static int default_shell_int = XtUnspecifiedShellInt;
@@ -635,7 +624,7 @@ VendorShellClassRec vendorShellClassRec = {
         /* extension */ NULL
     }
 };
-/* *INDENT-ON* */
+
 
 WidgetClass vendorShellWidgetClass = (WidgetClass)(&vendorShellClassRec);
 
@@ -715,6 +704,7 @@ VendorFromHorizontalPixels(Widget w, int offset, XtArgVal *value)
     _XmFromHorizontalPixels(XtParent(w), offset, value);
 }
 
+
 static void
 VendorFromVerticalPixels(Widget w, int offset, XtArgVal *value)
 {
@@ -723,6 +713,7 @@ VendorFromVerticalPixels(Widget w, int offset, XtArgVal *value)
     _XmFromVerticalPixels(XtParent(w), offset, value);
 }
 
+
 static XmImportOperator
 VendorToHorizontalPixels(Widget w, int offset, XtArgVal *value)
 {
@@ -731,6 +722,7 @@ VendorToHorizontalPixels(Widget w, int offset, XtArgVal *value)
     return XmSYNTHETIC_NONE;
 }
 
+
 static XmImportOperator
 VendorToVerticalPixels(Widget w, int offset, XtArgVal *value)
 {
@@ -739,13 +731,14 @@ VendorToVerticalPixels(Widget w, int offset, XtArgVal *value)
     return XmSYNTHETIC_NONE;
 }
 
+
 static void
 class_part_initialize(WidgetClass widget_class)
 {
     CompositeClassExtension ext, *extptr;
     VendorShellWidgetClass vsclass = (VendorShellWidgetClass)widget_class;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "Vendor Shell's class_part_initialize()\n"));
 
     extptr = (CompositeClassExtension *)_XmGetClassExtensionPtr((XmGenericClassExt *)&(vsclass->composite_class.extension),
@@ -779,6 +772,7 @@ class_part_initialize(WidgetClass widget_class)
     }
 }
 
+
 /*
  * Helper function: checks whether a shell is a (real) popup shell or some
  * other kind of shell. We need this one lateron when we have do deal with
@@ -810,6 +804,7 @@ LTIsARealPopupShell(Widget wid)
     return False;
 }
 
+
 /*
  * Helper function: returns the next parental shell for any given shell
  * widget. If there isn't any parent shell (as we're might already be at the
@@ -825,6 +820,7 @@ LTGetParentShell(Widget w)
     return w;
 }
 
+
 /*
  * When given the current shell widget this function returns the desktop
  * extension object belonging to the parent shell of the shell given.
@@ -898,6 +894,7 @@ LTGetDesktopLogicalParentForShell(Widget w)
 
 }
 
+
 static void
 secondary_object_create(Widget req, Widget new_w,
 			ArgList args, Cardinal *num_args)
@@ -906,7 +903,7 @@ secondary_object_create(Widget req, Widget new_w,
     Widget desktopParent;
     XmDisplay d = (XmDisplay)XmGetXmDisplay(XtDisplay(new_w));
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec, rsec;
     extern void _XtAddCallback(XtCallbackList *, XtCallbackProc, XtPointer);
 
@@ -958,7 +955,7 @@ secondary_object_create(Widget req, Widget new_w,
 
     _XmPushWidgetExtData(new_w, ed, XmSHELL_EXTENSION);
 
-    _XmExtImportArgs(nsec, args, num_args);
+    _XmExtImportArgs((Widget)nsec, args, num_args);
 
     _XtAddCallback(&VSEP_RealizeCallback(ed->widget),
 		   _XmVendorExtRealize, NULL);
@@ -972,6 +969,7 @@ secondary_object_create(Widget req, Widget new_w,
 		  LTShellPopdownCallback, ed->widget);
 }
 
+
 static void
 initialize_prehook(Widget req, Widget new_w,
 		   ArgList args, Cardinal *num_args)
@@ -996,6 +994,7 @@ initialize_prehook(Widget req, Widget new_w,
     }
 }
 
+
 static void
 initialize_posthook(Widget req, Widget new_w,
 		    ArgList args, Cardinal *num_args)
@@ -1004,15 +1003,17 @@ initialize_posthook(Widget req, Widget new_w,
 
     if ((ext = _XmGetWidgetExtData(new_w, XmSHELL_EXTENSION)) != NULL)
     {
-	_XmExtObjFree(ext->reqWidget);
+	_XmExtObjFree((XtPointer)ext->reqWidget);
         ext->reqWidget = NULL;
     }
 }
 
+
 #define VSEPC_DeleteWindowHandler(w) \
     (((XmVendorShellExtClassRec *)XtClass(w))-> \
 					vendor_class.delete_window_handler)
 
+
 static void
 initialize(Widget req, Widget new_w,
 	   ArgList args, Cardinal *num_args)
@@ -1021,7 +1022,7 @@ initialize(Widget req, Widget new_w,
     XtEventHandler str_not;
     XmShellExtClassRec *shellc;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "####VendorShell %s initialize\n", XtName(new_w)));
 
     ((WMShellWidget)new_w)->wm.wait_for_wm = True;
@@ -1045,7 +1046,7 @@ initialize(Widget req, Widget new_w,
 			  (XtEventHandler)_XmNSEEditResCheckMessages, NULL);
 #endif
 
-	DEBUGOUT(XdbDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "Setting up virtual key bindings\n"));
 
 	XtSetKeyTranslator(XtDisplay(new_w), (XtKeyProc)XmTranslateKey);
@@ -1071,6 +1072,7 @@ initialize(Widget req, Widget new_w,
     }
 }
 
+
 /*
  * Don't forget to clean up: the shell extension data as well as the
  * extension object for example...
@@ -1080,12 +1082,12 @@ destroy(Widget w)
 {
     XmWidgetExtData data;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "VendorShell Destroy()\n"));
-    DEBUGOUT(XdbDebug("NEDIT", w, "VendorShell Destroy()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "VendorShell Destroy()\n"));
+    DEBUGOUT(_LtDebug("NEDIT", w, "VendorShell Destroy()\n"));
 
     _XmPopWidgetExtData(w, &data, XmSHELL_EXTENSION);
     if (data != NULL) {
-	DEBUGOUT(XdbDebug2(__FILE__, w, data->widget,
+	DEBUGOUT(_LtDebug2(__FILE__, w, data->widget,
 		"VendorShell Destroy: destroy child\n"));
 
 	/* mitch
@@ -1096,14 +1098,15 @@ destroy(Widget w)
     }
 }
 
+
 static void
 _XmVendorExtDestroy(Widget w)
 {
 	XmVendorShellExtObject ve = (XmVendorShellExtObject)w;
-    Atom wm_delete_window;
+	Atom wm_delete_window;
 	Widget shell = ExtObj_LogicalParent(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "VendorShellExt Destroy()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "VendorShellExt Destroy()\n"));
 
 	if (VSEP_DefaultFontList(ve))
 	{
@@ -1143,7 +1146,7 @@ realize(Widget w,
 	XtValueMask *value_mask,
 	XSetWindowAttributes *attributes)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "Realize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize\n"));
 
     if (XtWidth(w) == 0)
     	XtWidth(w) = 1;
@@ -1180,13 +1183,14 @@ realize(Widget w,
 #endif
 }
 
+
 static void
 WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
 {
     XmVendorShellExtObject ve = (XmVendorShellExtObject)client;
-    int i;
+    Cardinal i;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "WmProtocolHandler\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "WmProtocolHandler\n"));
 
     switch (VSEP_DeleteResponse(ve))
     {
@@ -1194,13 +1198,13 @@ WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
 	XtDestroyWidget(w);
 	if (XtIsApplicationShell(w))
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 			      "WmProtocolHandler(DeleteResponse XmDESTROY) "
 			      "- Exiting (WM_DELETE_WINDOW)\n"));
 	    XtDestroyApplicationContext(XtWidgetToApplicationContext(w));
 	    exit(0);
 	}
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WmProtocolHandler(DeleteResponse XmDESTROY)\n"));
 	break;
 
@@ -1209,7 +1213,7 @@ WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
 	for (i = 0; i < MGR_NumChildren(w); i++)
 	    if (XtIsManaged(MGR_Children(w)[i]))
 	    {
-		DEBUGOUT(XdbDebug2(__FILE__, w, MGR_Children(w)[i],
+		DEBUGOUT(_LtDebug2(__FILE__, w, MGR_Children(w)[i],
 				   "XtUnmanageChild(child)\n"));
 		XtUnmanageChild(MGR_Children(w)[i]);
 		return;		/* Shells have only one managed child */
@@ -1217,12 +1221,13 @@ WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
 	break;
 
     case XmDO_NOTHING:
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WmProtocolHandler(DeleteResponse XmNO_NOTHING)\n"));
 	return;
     }
 }
 
+
 static void
 resize(Widget w)
 {
@@ -1242,6 +1247,7 @@ resize(Widget w)
     }
 }
 
+
 /*
  * set_values_prehook
  */
@@ -1251,7 +1257,7 @@ set_values_prehook(Widget old, Widget req, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData data;
-    int size;
+    Cardinal size;
     XtPointer nsec, rsec;
     Widget ve;
 
@@ -1284,6 +1290,7 @@ set_values_prehook(Widget old, Widget req, Widget new_w,
     return False;
 }
 
+
 static Boolean
 set_values_posthook(Widget old, Widget req, Widget new_w,
 		    ArgList args, Cardinal *num_args)
@@ -1300,6 +1307,7 @@ set_values_posthook(Widget old, Widget req, Widget new_w,
     return False;
 }
 
+
 static Boolean
 set_values(Widget old, Widget req, Widget new_w,
 	   ArgList args, Cardinal *num_args)
@@ -1307,7 +1315,7 @@ set_values(Widget old, Widget req, Widget new_w,
     XmWidgetExtData data;
     Boolean refresh = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:set_values(%d): %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -1320,7 +1328,7 @@ set_values(Widget old, Widget req, Widget new_w,
 		      XtWidth(req), XtHeight(req),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     data = _XmGetWidgetExtData(new_w, XmSHELL_EXTENSION);
     if (data)
@@ -1332,6 +1340,7 @@ set_values(Widget old, Widget req, Widget new_w,
     return refresh;
 }
 
+
 static void
 get_values_prehook(Widget widget,
 		   ArgList args,
@@ -1339,7 +1348,7 @@ get_values_prehook(Widget widget,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData data;
-    int size;
+    Cardinal size;
     XtPointer nsec;
     Widget ve;
 
@@ -1365,6 +1374,7 @@ get_values_prehook(Widget widget,
     _XmExtGetValuesHook(data->widget, args, num_args);
 }
 
+
 static void
 get_values_posthook(Widget widget,
 		    ArgList args,
@@ -1379,12 +1389,13 @@ get_values_posthook(Widget widget,
     XtFree((char *)ext);
 }
 
+
 static void
 change_managed(Widget wid)
 {
     int i;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "change_managed()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "change_managed()\n"));
 #define superclass (&wmShellClassRec)
     (*superclass->composite_class.change_managed) (wid);
 #undef superclass
@@ -1399,10 +1410,11 @@ change_managed(Widget wid)
     }
 }
 
+
 static void
 insert_child(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "insert_child()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "insert_child()\n"));
     /* Keep those pesky objects OUT of the child list */
     if (!XtIsRectObj(w))
     {
@@ -1414,11 +1426,12 @@ insert_child(Widget w)
 #undef superclass
 }
 
+
 static void
 delete_child(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "delete_child()\n"));
-    DEBUGOUT(XdbDebug2("RWS", XtParent(w), w,"%s:delete_child(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "delete_child()\n"));
+    DEBUGOUT(_LtDebug2("RWS", XtParent(w), w,"%s:delete_child(%d)\n",
     	__FILE__, __LINE__
     	));
     /* Keep those pesky objects OUT of the child list */
@@ -1432,7 +1445,8 @@ delete_child(Widget w)
 #undef superclass
 }
 
-Cardinal
+
+extern Cardinal
 _XmFilterResources(XtResource *resources,
 		   Cardinal numResources,
 		   WidgetClass filterClass,
@@ -1442,17 +1456,18 @@ _XmFilterResources(XtResource *resources,
     return 0;
 }
 
+
 static void
 dump_grab_list(Widget w)
 {
-    int i;
+    Cardinal i;
 
-    if (XdbInDebug(__FILE__, w))
+    if (_LtDebugInDebug(__FILE__, w))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Current Grab List\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Current Grab List\n"));
 	for (i = 0; i < Display_NumModals(w); i++)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w, " Wid: %p (%s) ve: %p grabber: %p exclusive: %d sprung: %d\n",
+	    DEBUGOUT(_LtDebug(__FILE__, w, " Wid: %p (%s) ve: %p grabber: %p exclusive: %d sprung: %d\n",
 		   Display_Modals(w)[i].wid,
 		   XtName(Display_Modals(w)[i].wid),
 		   Display_Modals(w)[i].ve,
@@ -1462,6 +1477,7 @@ dump_grab_list(Widget w)
     }
 }
 
+
 /*
  * Put a widget on LessTif's grab list and issue an Intrinsics' grab.
  * The correct use of the function's parameters is a little bit tricky:
@@ -1479,7 +1495,7 @@ LTAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded,
     Widget d;
     XmModalData modal;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "LTAddGrab\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab\n"));
     /*
      * If there's no widget wid specified, we'll take the logical parent
      * of the vendor shell extension object as the grab destination instead.
@@ -1529,7 +1545,7 @@ LTAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded,
 
     Display_NumModals(d)++;
 
-    DEBUGOUT(XdbDebug("GRAB", wid, "%s:XtAddGrab(%d) - %s %s\n", 
+    DEBUGOUT(_LtDebug("GRAB", wid, "%s:XtAddGrab(%d) - %s %s\n", 
     	__FILE__, __LINE__,
     	exclusive ? "True" : "False",
     	spring_loaded ? "True" : "False"));
@@ -1542,10 +1558,11 @@ LTAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded,
     XtAddCallback(wid, XmNdestroyCallback,
 		  (XtCallbackProc)LTRemoveGrabCallback,
 		  (XtPointer)ve);
-    DEBUGOUT(XdbDebug(__FILE__, wid, "LTAddGrab - After it is added\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab - After it is added\n"));
     dump_grab_list(d);
 }
 
+
 /*
  * The "public" grab interface. Put a widget on LessTif's grab list. This
  * will also set an Intrinsic's grab on that widget. The tricky thing comes
@@ -1553,14 +1570,15 @@ LTAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded,
  * below for more information. Please note that you should always use
  * _XmAddGrab() instead of XtAddGrab() within LessTif.
  */
-void
+extern void
 _XmAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded)
 {
-    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmAddGrab()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmAddGrab()\n"));
     LTAddGrab(wid, exclusive, spring_loaded,
 	      (XmVendorShellExtObject)NULL, (XmVendorShellExtObject)NULL);
 }
 
+
 /*
  * The third parameter "remove_grab" is just a small optimization, so we
  * don't need to remove callbacks and grabs if the widget to be removed
@@ -1590,7 +1608,7 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
     XmModalData pd, ps;
     int i, skipped;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "LTRemoveGrab\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "LTRemoveGrab\n"));
     if (wid == NULL)
     {
 	wid = ExtObj_LogicalParent(ve);
@@ -1628,14 +1646,17 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 	to
            if ((ps->wid == wid) && remove_grab_physically)
 	
-	This 'fix' in turn triggered XtRemoveGrabs with bogu arguments, leading
+	This 'fix' in turn triggered XtRemoveGrabs with bogus arguments, leading
 	to Xt warning messages. See comments at beginning of LTRemoveGrab()!
 */
-	if ((XtParent(wid) == NULL) || ((ps->wid == wid) && !CoreBeingDestroyed(wid) && remove_grab_physically))
+	if ((XtParent(wid) == NULL) ||
+	    ((ps->wid == wid) && !CoreBeingDestroyed(wid) &&
+	     !XtIsTopLevelShell(wid) && remove_grab_physically))
 	{
-	    DEBUGOUT(XdbDebug2("GRAB", XtParent(wid), wid, "%s:XtRemoveGrab(%d) - %s %s\n", __FILE__, __LINE__,
-	    	XtIsShell(wid) ? "True" : "False",
-	    	CoreBeingDestroyed(wid) ? "True" : "False"));
+	    DEBUGOUT(_LtDebug2("GRAB", XtParent(wid), wid, "%s:XtRemoveGrab(%d) - %s %s\n",
+	                       __FILE__, __LINE__,
+			       XtIsShell(wid) ? "True" : "False",
+                               CoreBeingDestroyed(wid) ? "True" : "False"));
 	    XtRemoveGrab(wid);
 	}
     }
@@ -1682,7 +1703,7 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 	if (pd != ps)
 	{
 	    *pd = *ps;
-	    DEBUGOUT(XdbDebug("GRAB", pd->wid, "%s:XtAddGrab(%d) - %s %s\n", 
+	    DEBUGOUT(_LtDebug("GRAB", pd->wid, "%s:XtAddGrab(%d) - %s %s\n", 
 		__FILE__, __LINE__,
 		pd->exclusive ? "True" : "False",
 		pd->springLoaded ? "True" : "False"));
@@ -1693,6 +1714,7 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
     Display_NumModals(d) -= skipped;
 }
 
+
 /*
  * This is called whenever a widget issued a grab and is now being
  * destroyed. We then must remove the grab from LessTif's grab list
@@ -1705,8 +1727,8 @@ static void
 LTRemoveGrabCallback(Widget wid, XtPointer client_data,
 		     XtPointer callback_data)
 {
-    DEBUGOUT(XdbDebug(__FILE__, wid, "LTRemoveGrabCallback()\n"));
-    DEBUGOUT(XdbDebug("GRAB", wid, "LTRemoveGrabCallback()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "LTRemoveGrabCallback()\n"));
+    DEBUGOUT(_LtDebug("GRAB", wid, "LTRemoveGrabCallback()\n"));
 #if 0
     /* rws 14 Feb 1998
        This is the cause of the segfault in ddd when pressing OK from
@@ -1737,6 +1759,7 @@ LTRemoveGrabCallback(Widget wid, XtPointer client_data,
     }
 }
 
+
 /*
  * Simply remove a grab from a widget (identified by "wid"). This results
  * in: a) removal of the Intrinsics' grab,
@@ -1745,13 +1768,14 @@ LTRemoveGrabCallback(Widget wid, XtPointer client_data,
  * will be put back on their grab. So LessTif's grab list isn't a cascade
  * like the Intrinsics' grab list but rather a modality list.
  */
-void
+extern void
 _XmRemoveGrab(Widget wid)
 {
-    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmRemoveGrab()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmRemoveGrab()\n"));
     LTRemoveGrab(wid, NULL, True);
 }
 
+
 /*
  * Whenever a primary application modal dialog shows up we must add grabs
  * to all those shells which are not a parental shell of that dialog. This
@@ -1770,7 +1794,7 @@ LTGrabKids(XmVendorShellExtObject ve,
     WidgetList kids;
     Widget logParent;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "LTGrabKids()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "LTGrabKids()\n"));
     /*
      * Depending on the class of object within the shadow shell hierarchy
      * we've to choose one out of three different ways to get the object's
@@ -1847,6 +1871,7 @@ LTGrabKids(XmVendorShellExtObject ve,
     }
 }
 
+
 /*
  * Within this function we start at those vendor shell extension object
  * which has belongs to the dialog just about to pop up. Then we ascend
@@ -1859,7 +1884,7 @@ LTGrabRelatives(XmVendorShellExtObject grabber)
 {
     XmVendorShellExtObject eo, skip_branch;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "LTGrabRelatives()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "LTGrabRelatives()\n"));
     eo = (XmVendorShellExtObject)Desktop_Parent(grabber);
     skip_branch = grabber;
     for (;;)
@@ -1889,6 +1914,7 @@ LTGrabRelatives(XmVendorShellExtObject grabber)
     }
 }				/* LTGrabRelatives */
 
+
 /*
  * Whenever a shell widget pops up on the display of a surprised user this
  * callback handler makes sure the appropiate grabs are installed according
@@ -1902,7 +1928,7 @@ LTShellPopupCallback(Widget w, XtPointer ClientData, XtPointer CallbackData)
     XtGrabKind GrabKind = XtGrabNone;
     Boolean GrabRelatives = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ShellPopup callback\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ShellPopup callback\n"));
 
     ws = XmGetXmScreen(XtScreenOfObject(w));
 
@@ -1983,11 +2009,11 @@ LTShellPopdownCallback(Widget w, XtPointer ClientData, XtPointer CallbackData)
 {
     XmVendorShellExtObject ve = (XmVendorShellExtObject)ClientData;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ShellPopdown callback\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ShellPopdown callback\n"));
 
     if (VSEP_GrabKind(ve) != XtGrabNone)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Remove grab\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Remove grab\n"));
 
 	LTRemoveGrab(NULL, ve, True);
     }
@@ -1997,6 +2023,7 @@ LTShellPopdownCallback(Widget w, XtPointer ClientData, XtPointer CallbackData)
 #define DEFAULT_WM_TIMEOUT 500
 #endif
 
+
 static void
 ComputeWMSizeHints(WMShellWidget w, XSizeHints * hints)
 {
@@ -2052,6 +2079,7 @@ ComputeWMSizeHints(WMShellWidget w, XSizeHints * hints)
 #undef copy
 }
 
+
 static void
 SetWMSizeHints(WMShellWidget w)
 {
@@ -2203,7 +2231,8 @@ WaitForWM(ShellWidget w, XEvent *event, unsigned long request_num)
     }
 }
 
-XtGeometryResult
+
+extern XtGeometryResult
 _XmRootGeometryManager(Widget wid,
 		       XtWidgetGeometry *request,
 		       XtWidgetGeometry *reply)
@@ -2407,7 +2436,7 @@ _XmRootGeometryManager(Widget wid,
 		 * this way.
 		 */
 
-		DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 				  "Returning XtGeometryNo because config "
 				  "differed\n"));
 
@@ -2441,7 +2470,7 @@ _XmRootGeometryManager(Widget wid,
 	{
 	    PutBackGeometry();
 
-	    DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			      "Returning XtGeometryNo because config "
 			      "denied\n"));
 
@@ -2491,14 +2520,62 @@ QueryStruct;
 
 /* A prototype for a private libXt function ... */
 extern int _XtWaitForSomething(XtAppContext app,
-			       _XtBoolean ignoreEvents, _XtBoolean ignoreTimers,
+			       _XtBoolean ignoreEvents,
+			       _XtBoolean ignoreTimers,
 			       _XtBoolean ignoreInputs,
-			       _XtBoolean ignoreSignals, _XtBoolean block,
+			       _XtBoolean ignoreSignals,
+			       _XtBoolean block,
 #ifdef XTHREADS
 			       _XtBoolean drop_lock,
 #endif
 			       unsigned long *howlong);
 
+/* amai: citing the docs, e.g. from
+ *     ftp://ftp.x.org/pub/R6.6/xc/lib/Xt/NextEvent.c
+ * for that
+ * Routine to block in the toolkit.  This should be the only call to select.
+ *
+ * This routine returns when there is something to be done.
+ *
+ * Before calling this with ignoreInputs==False, app->outstandingQueue should
+ * be checked; this routine will not verify that an alternate input source
+ * has not already been enqueued.
+ *
+ *
+ * _XtWaitForSomething( appContext, 
+ *                      ignoreEvent, ignoreTimers, ignoreInputs, ignoreSignals,
+ *			block, drop_lock, howlong)
+ * XtAppContext app;	     (Displays to check wait on)
+ *
+ * Boolean ignoreEvents;     (Don't return if XEvents are available
+ *                              Also implies forget XEvents exist)
+ *
+ * Boolean ignoreTimers;     (Ditto for timers)
+ *
+ * Boolean ignoreInputs;     (Ditto for input callbacks )
+ *
+ * Boolean ignoreSignals;    (Ditto for signals)
+ *
+ * Boolean block;	     (Okay to block)
+ *
+ * Boolean drop_lock         (drop lock before going into select/poll)
+ *
+ * TimeVal howlong;	     (howlong to wait for if blocking and not
+ *				doing Timers... Null means forever.
+ *				Maybe should mean shortest of both)
+ * Returns display for which input is available, if any
+ * and if ignoreEvents==False, else returns -1
+ *
+ * if ignoring everything && block=True && howlong=NULL, you'll have
+ * lots of time for coffee; better not try it!  In fact, it probably
+ * makes little sense to do this regardless of the value of howlong
+ * (bottom line is, we don't bother checking here).
+ *
+ * If drop_lock is FALSE, the app->lock->mutex is not unlocked before
+ * entering select/poll. It is illegal for drop_lock to be FALSE if
+ * ignoreTimers, ignoreInputs, or ignoreSignals is FALSE.
+ */
+
 static Bool
 ConfigEventForMe(Display *dpy, XEvent *event, char *arg)
 {
@@ -2543,6 +2620,7 @@ ConfigEventForMe(Display *dpy, XEvent *event, char *arg)
     return FALSE;
 }
 
+
 static int
 WaitForWM(ShellWidget w, XEvent *event, unsigned long request_num)
 {
@@ -2575,10 +2653,27 @@ WaitForWM(ShellWidget w, XEvent *event, unsigned long request_num)
 	}
     }
 
+/*
+  amai: we have to get rid of this _XtWaitForSomething ASAP:
+    this call changes it's signature based on compile-time options
+    for the X libraries :-(
+    So beyond the pure annoying fact of using a non-documented, private call
+    from libXt we also break cross-compiling.
+    And no, a run-time if-clause is not a "real" solution IMHO.
+    A proposal is to install an even handler and a timer 
+       XtAppAddTimeOut()
+       XtAddEventHandler()
+    and then do the remaining job in the triggered callbacks.
+    WaitForWM() is only called once in the code, one has to check
+    what is done _there_.
+*/
     while (timeout > 0)
     {
 	if (_XtWaitForSomething(app,
-				FALSE, TRUE, TRUE, TRUE,
+				FALSE,
+				TRUE,
+				TRUE,
+				TRUE,
 				TRUE,
 #ifdef XTHREADS
 				FALSE,
@@ -2595,10 +2690,10 @@ WaitForWM(ShellWidget w, XEvent *event, unsigned long request_num)
 	    }
 	}
     }
-
     return FALSE;
 }
 
+
 XtGeometryResult
 _XmRootGeometryManager(Widget gw,
 		       XtWidgetGeometry *request,
@@ -2797,7 +2892,7 @@ _XmRootGeometryManager(Widget gw,
 		 * this way.
 		 */
 
-		DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 				  "Returning XtGeometryNo because config "
 				  "differed\n"));
 
@@ -2828,7 +2923,7 @@ _XmRootGeometryManager(Widget gw,
 	{
 	    PutBackGeometry();
 
-	    DEBUGOUT(XdbDebug(__FILE__, (Widget)w,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			      "Returning XtGeometryNo because not "
 			      "WMShell\n"));
 
@@ -2855,10 +2950,11 @@ _XmRootGeometryManager(Widget gw,
 
 #endif /* XtSpecificationRelease < 6 */
 
+
 /*
  * if this doesn't exist, the BaseClass geometry wrapper won't work.
  */
-XtGeometryResult
+static XtGeometryResult
 geometry_manager(Widget wid,
 		 XtWidgetGeometry *request,
 		 XtWidgetGeometry *reply)
@@ -2866,14 +2962,14 @@ geometry_manager(Widget wid,
     ShellWidget shell = (ShellWidget)XtParent(wid);
     XtWidgetGeometry req;
 
-    DEBUGOUT(XdbDebug2(__FILE__, XtParent(wid), wid, "%s:geometry_manager(%d) - request (%s)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(wid), wid, "%s:geometry_manager(%d) - request (%s)\n",
     	__FILE__, __LINE__,
-    	XdbWidgetGeometry2String(request)));
+    	_LtDebugWidgetGeometry2String(request)));
 
     if ((request->width == 0 && (request->request_mode & CWWidth)) ||
 	(request->height == 0 && (request->request_mode & CWHeight)))
     {
-	DEBUGOUT(XdbDebug(__FILE__, wid,
+	DEBUGOUT(_LtDebug(__FILE__, wid,
 		          "Returning XtGeometryNo because asked "
 		          "for 0 w/h\n"));
 
@@ -2882,7 +2978,7 @@ geometry_manager(Widget wid,
 
     if (shell->shell.allow_shell_resize == False && XtIsRealized(wid) && (request->request_mode & (CWWidth | CWHeight)))
     {
-	DEBUGOUT(XdbDebug(__FILE__, wid,
+	DEBUGOUT(_LtDebug(__FILE__, wid,
 		          "Returning XtGeometryNo because "
 		          "no shell resize\n"));
 
@@ -2893,7 +2989,7 @@ geometry_manager(Widget wid,
        mgs bubble help
     if (request->request_mode & (CWX | CWY))
     {
-	DEBUGOUT(XdbDebug(__FILE__, wid,
+	DEBUGOUT(_LtDebug(__FILE__, wid,
 		          "Returning XtGeometryNo because "
 		          "asked for x/y\n"));
 
@@ -2956,13 +3052,14 @@ geometry_manager(Widget wid,
 	return XtGeometryYes;
     }
 
-   DEBUGOUT(XdbDebug(__FILE__, wid,
+   DEBUGOUT(_LtDebug(__FILE__, wid,
 		     "Returning XtGeometryNo because "
 		     "XtMakeGeometryRequest failed\n"));
 
     return XtGeometryNo;
 }
 
+
 static void
 _XmVendorExtInitialize(Widget req,
 		       Widget new_w,
@@ -2972,7 +3069,7 @@ _XmVendorExtInitialize(Widget req,
     XmVendorShellExtObject ve = (XmVendorShellExtObject)new_w;
     Atom wm_delete_window;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "VendorShellExt %s initialize\n", XtName(new_w)));
 
     if (VSEP_DefaultFontList(ve) != NULL)
@@ -3072,6 +3169,7 @@ _XmVendorExtInitialize(Widget req,
 			 VSEPC_DeleteWindowHandler(new_w), (XtPointer)new_w);
 }
 
+
 static Boolean
 _XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
 		      ArgList args, Cardinal *nargs)
@@ -3079,7 +3177,7 @@ _XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
     Atom at;
     long prop32[5];
 
-    DEBUGOUT(XdbDebug(__FILE__, nw,
+    DEBUGOUT(_LtDebug(__FILE__, nw,
 		      "VendorShellExt %s SetValues\n", XtName(nw)));
 
     if (VSEP_ButtonFontList(nw) != VSEP_ButtonFontList(cw))
@@ -3166,15 +3264,16 @@ _XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
     return False;
 }
 
-void
+
+extern void
 _XmVendorExtRealize(Widget w, XtPointer closure, XtPointer call_data)
 {
     Atom at;
     Widget par;
-    int i;
+    Cardinal i;
     long prop32[5];
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmVendorExtRealize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmVendorExtRealize\n"));
 
     par = ExtObj_LogicalParent(w);
 
@@ -3183,7 +3282,7 @@ _XmVendorExtRealize(Widget w, XtPointer closure, XtPointer call_data)
 	_XmInstallProtocols(par);
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		 "_XmVendorExtRealize[flags %d, functions %d, decorations %d, "
 		      "input_mode %d, status %d\n",
 		      VSEP_MwmHints(w).flags,
@@ -3252,6 +3351,7 @@ _XmVendorExtRealize(Widget w, XtPointer closure, XtPointer call_data)
     }
 }
 
+
 static Cardinal
 get_sec_res_data(WidgetClass wc, XmSecondaryResourceData **data)
 {
@@ -3261,17 +3361,19 @@ get_sec_res_data(WidgetClass wc, XmSecondaryResourceData **data)
 				    data, NULL, NULL, NULL, NULL);
 }
 
-Display *
+
+extern Display *
 _XmGetDefaultDisplay(void)
 {
     return default_display;
 }
 
-unsigned char
+
+extern unsigned char
 _XmGetAudibleWarning(Widget w)
 {
     XmWidgetExtData data;
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmGetAudibleWarning\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetAudibleWarning\n"));
     if ( XmIsVendorShell (w) && ( data = _XmGetWidgetExtData(w, XmSHELL_EXTENSION ) ) )
 	{
 	XmVendorShellExtObject vSE = (XmVendorShellExtObject)data -> widget ;
@@ -3283,19 +3385,22 @@ _XmGetAudibleWarning(Widget w)
     return False;
 }
 
-char *
+
+extern char *
 _XmGetIconPixmapName(void)
 {
     return NULL;
 }
 
-void
+
+extern void
 _XmClearIconPixmapName(void)
 {
 }
 
+
 /* To be used elsewhere ... */
-Widget
+extern Widget
 _LtFindVendorExt(Widget w)
 {
     Widget p;
@@ -3323,57 +3428,71 @@ _LtFindVendorExt(Widget w)
     }
 }
 
+
 /*
-From: Martin Simmons <martin@harlequin.co.uk>
+  From: Martin Simmons:
+    Perhaps LessTif can guard against this common linking problem?  
+    E.g. the following function will check the VendorShell for consistency:
 
-  Perhaps LessTif can guard against this common linking problem?  
-  E.g. the following function will check the VendorShell for consistency:
-*/
-
-/* To be used for sanity checking */
-Boolean
+     returns     True if successful, i.e. everything's fine
+     returns     False if no widget was supplied as an argument
+     _XmError()s if linkage is/was wrong
+ */
+extern Boolean
 _LtCheckClassOfVendorShell(Widget w)
 {
-    WidgetClass class;
-
-    for (class = XtClass(w); class != NULL; class = class->core_class.superclass)
+    WidgetClass widget_class;
+    
+    if (!w)
+       return False;
+    for (widget_class = XtClass(w); widget_class != NULL; widget_class = widget_class->core_class.superclass)
     {
-        if (0 == strcmp(class->core_class.class_name, "VendorShell")) {
-            if (class->core_class.extension == (XtPointer)&_XmVendorSCoreClassExtRec)
-                return TRUE;
+        if (0 == strcmp(widget_class->core_class.class_name, "VendorShell")) {
+            if (widget_class->core_class.extension == (XtPointer)&_XmVendorSCoreClassExtRec)
+                return True;
             else
-                _XmError(w, "Application not linked correctly: try putting Xm before Xt.");
+                _XmError(w, "Application not linked correctly: try putting -lXm before -lXt.");
         }
     }
 
-    return FALSE;
+    return False;
 }
 
-/* This corrects for the different shared library loading mechanism in OS/2 
-   compared to the standard Unix OS's.
+
+/*
+   This corrects for the (shared) library loading mechanism in OS/2 
+   which differs from those on many standard Unix systems.
    The routine should be called before any other function,
-   done by the _DLL_InitTerm-function under OS/2.
+   done by the _DLL_InitTerm-function.
    On un*x/ELF systems this seems to be ensured by specifying the
-   libs in correct, canonical order on the linker command line
+   libs in correct, canonical order on the linker command line.
+   amai (20010112): Well, I once decided to make it static, but
+     this was an error: to call it from a static libXm one
+     may need this symbol.
  */
 #ifdef __EMX__
-static void
-_XmFixupVendorShell(void)
+extern void
+_LtXmFixupVendorShell(void)
 {
+
     transientShellWidgetClass->core_class.superclass =
 	(WidgetClass)&vendorShellClassRec;
     topLevelShellWidgetClass->core_class.superclass =
 	(WidgetClass)&vendorShellClassRec;
 }
 
+
 unsigned long
 _DLL_InitTerm(unsigned long mod_handle, unsigned long flag)
 {
-    if (flag == 0)  /* initialize DLL */
+    if (flag == 0UL)  /* initialize DLL */
     {
-	_XmFixupVendorShell();
+	_LtXmFixupVendorShell();
+	return 1; /* success */
+    }
+    else     /* terminate DLL */
+    {
+        return 1; /* success */
     }
-    /* sucess */
-    return 1;
 }
-#endif
+#endif /* __EMX__ */
