@@ -1,9 +1,9 @@
 /*
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.60 2000/11/10 12:40:51 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.70 2001/07/27 18:51:58 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.60 2000/11/10 12:40:51 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.70 2001/07/27 18:51:58 dannybackx Exp $";
 
 /*
  * ** Danny had added a flag here, but I think the behavior he added is always
@@ -55,10 +55,11 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c
 #include <XmI/MacrosI.h>
 #include <Xm/XmP.h>
 #include <X11/IntrinsicP.h>
-#include <XmI/DebugUtil.h>
 
 #include "LTmisc.h"
 
+#include <XmI/DebugUtil.h>
+
 /*
  * for information on the external encoding, see doc/XmStrings.txt
  */
@@ -71,12 +72,12 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c
  */
 #define XmSTRING_HEADER_SIZE	(ASN1_HEADER_SIZE * 2)
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
+/* don't need this in a production build */
+#ifndef LESSTIF_PRODUCTION
+#ifndef XMSTRING_DEBUG
+#define XMSTRING_DEBUG
+#endif
 #endif
-
-
-#undef XMSTRING_DEBUG
 
 /**************************** PRIVATE FUNCTIONS ****************************/
 
@@ -424,10 +425,11 @@ __XmStringComponentCopy(struct __XmStringComponentRec *dest,
     dest->data = XtNewString(src->data);
 }
 
+
 static _XmString
 __XmStringFromASN1(XmString string)
 {
-    unsigned length, i, nlen;
+    unsigned i, nlen, nlength, length;
     struct __XmStringExtRec *str = (struct __XmStringExtRec *)string;
     unsigned char *next;
     char *charset;
@@ -924,7 +926,7 @@ __XmStringSegmentExtent(XmFontList flist, _XmStringComponent comp,
 	 comp->type != XmSTRING_COMPONENT_LOCALE_TEXT) ||
 	comp->font == XmUNSPECIFIED)
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "__XmStringSegmentExtent: got NULL Font/bad text\n"));
 
 	return False;
@@ -938,7 +940,7 @@ __XmStringSegmentExtent(XmFontList flist, _XmStringComponent comp,
     switch (flist[comp->font].type)
     {
     case XmFONT_IS_FONT:
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 		"_XmStringSegmentExtent(XmFONT_IS_FONT)\n"));
 	{
 	    XFontStruct *fontstruct = (XFontStruct *)flist[comp->font].font;
@@ -960,7 +962,7 @@ __XmStringSegmentExtent(XmFontList flist, _XmStringComponent comp,
 			     comp->data, comp->length,
 			     &dc, &amax, &dmax, &ov);
 
-		DEBUGOUT(XdbDebug(__FILE__, NULL,
+		DEBUGOUT(_LtDebug(__FILE__, NULL,
 		    "_XmStringSegmentExtent: '%s' len %d\n",
 			comp->data, comp->length));
 	    }
@@ -972,7 +974,7 @@ __XmStringSegmentExtent(XmFontList flist, _XmStringComponent comp,
 	break;
 
     case XmFONT_IS_FONTSET:
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 		"_XmStringSegmentExtent(XmFONT_IS_FONTSET)\n"));
 
 	XmbTextExtents((XFontSet)flist[comp->font].font,
@@ -985,7 +987,7 @@ __XmStringSegmentExtent(XmFontList flist, _XmStringComponent comp,
 	break;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 	"_XmStringSegmentExtent => width %d height %d\n",
 	*width, *height));
 
@@ -1031,7 +1033,7 @@ _XmFontListGetDefaultFont(XmFontList fontlist,
 
     if (fontlist == NULL)
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "_XmFontListGetDefaultFont(NULL, ...)\n"));
 	*font_struct = NULL;
 	return False;
@@ -1143,14 +1145,14 @@ _XmStringIsXmString(XmString string)
 
     if (!string)
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "_XmStringIsXmString: string is NULL\n"));
 
 	return False;
     }
     if (str->tag != XmSTRING_TAG || str->len != XmSTRING_LENGTH)
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "_XmStringIsXmString: tag or len is invalid\n"));
 
 	return False;
@@ -1470,12 +1472,11 @@ _XmStringHasSubstring(_XmString string, _XmString substring)
     for (i = 0; i < string->number_of_components; i++)
     {
 	if (string->components[i]->type == substring->components[0]->type &&
-	    string->components[i]->length == substring->components[0]->length &&
+	    string->components[i]->length >= substring->components[0]->length &&
 	    ((string->components[i]->data != NULL &&
 	      substring->components[0]->data != NULL &&
-	      strncmp(string->components[i]->data,
-		      substring->components[0]->data,
-		      substring->components[0]->length) == 0) ||
+               strstr( string->components[i]->data,
+                       substring->components[0]->data ) != NULL) ||
 	     (string->components[i]->data == NULL &&
 	      substring->components[0] == NULL)))
 	{
@@ -1485,13 +1486,12 @@ _XmStringHasSubstring(_XmString string, _XmString substring)
 	    {
 		if (string->components[j]->type !=
 		    substring->components[k]->type ||
-		    string->components[j]->length !=
+		    string->components[j]->length <
 		    substring->components[k]->length ||
 		    ((string->components[j]->data != NULL &&
 		      substring->components[k]->data != NULL &&
-		      strncmp(string->components[j]->data,
-			      substring->components[k]->data,
-			      substring->components[k]->length) != 0) ||
+		      strstr(string->components[j]->data,
+			      substring->components[k]->data) == NULL) ||
 		     (string->components[j]->data != NULL &&
 		      substring->components[k] == NULL) ||
 		     (string->components[j]->data == NULL &&
@@ -1820,7 +1820,7 @@ _XmStringExtent(XmFontList fontlist, _XmString string,
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmStringExtent start\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmStringExtent start\n"));
 
     _XmStringUpdate(fontlist, string);
 
@@ -1847,12 +1847,12 @@ _XmStringExtent(XmFontList fontlist, _XmString string,
 	    }
 	    current_width += wd;
 
-	    DEBUGOUT(XdbDebug(__FILE__, NULL,
+	    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		"_XmStringExtent: text segment, line height %d\n", ht));
 	}
 	else if (comp->type == XmSTRING_COMPONENT_SEPARATOR)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmStringExtent: separator\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmStringExtent: separator\n"));
 
 	/* What if we don't have a height ... ? */
 	    if (line_height == 0) {
@@ -1869,7 +1869,7 @@ _XmStringExtent(XmFontList fontlist, _XmString string,
 		    __XmStringSegmentExtent(fontlist, blankcomp,
 				&wd, &default_line_height, &amax, &dmax);
 
-		    DEBUGOUT(XdbDebug(__FILE__, NULL,
+		    DEBUGOUT(_LtDebug(__FILE__, NULL,
 			"_XmStringExtent: separator found height %d\n",
 			default_line_height));
 		}
@@ -1904,7 +1904,7 @@ _XmStringExtent(XmFontList fontlist, _XmString string,
 	    {
 		current_height += default_line_height;
 
-		DEBUGOUT(XdbDebug(__FILE__, NULL,
+		DEBUGOUT(_LtDebug(__FILE__, NULL,
 		  "_XmStringExtent-separator: default_line_height %d added\n",
 		  default_line_height));
 	    }
@@ -1912,7 +1912,7 @@ _XmStringExtent(XmFontList fontlist, _XmString string,
 	    {
 		current_height += line_height;
 
-		DEBUGOUT(XdbDebug(__FILE__, NULL,
+		DEBUGOUT(_LtDebug(__FILE__, NULL,
 		  "_XmStringExtent-separator: line_height %d added\n",
 		  line_height));
 	    }
@@ -2065,7 +2065,7 @@ _XmStringDraw(Display *d, Window w, XmFontList fontlist, _XmString string,
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, XtWindowToWidget(d, w),
+    DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(d, w),
 		      "_XmStringDraw x %d y %d wid %d\n",
 		      x, y, width));
 
@@ -2529,12 +2529,12 @@ _XmStringDrawUnderline(Display *d, Window w, XmFontList fontlist,
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, XtWindowToWidget(d, w),
+    DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(d, w),
 		      "_XmStringDrawUnderline x %d y %d wid %d\n",
 		      x, y, width));
     if (!underline)
     {
-	DEBUGOUT(XdbDebug(__FILE__, XtWindowToWidget(d, w),
+	DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(d, w),
 		       "_XmStringDrawUnderline, underlined string is NULL\n"));
     }
 
@@ -2875,9 +2875,9 @@ _XmStringDrawMnemonic(Display *d,
     XmString und;
     _XmString _und;
 
-    DEBUGOUT(XdbDebug(__FILE__, XtWindowToWidget(d, w),
+    DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(d, w),
 		      "_XmStringDrawMnemonic(%s, %s)\n",
-		      XdbXmString2String((XmString)string), mnemonic));
+		      _LtDebugXmString2String((XmString)string), mnemonic));
 
     if (mnemonic == NULL)
     {
@@ -3130,7 +3130,7 @@ XmStringConcat(XmString str1, XmString str2)
     int i, base, total;
     XmString ret;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmStringConcat() entering\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmStringConcat() entering\n"));
 
     if (!_XmStringIsXmString(str1) && !_XmStringIsXmString(str2))
     {
@@ -3183,7 +3183,7 @@ XmStringConcat(XmString str1, XmString str2)
 
     _XmStringFree(newString);
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmStringConcat() leaving\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmStringConcat() leaving\n"));
 
     return ret;
 }
@@ -3922,7 +3922,7 @@ XmStringExtent(XmFontList fontlist,
 
     if (!string)
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "XmStringExtent() string is NULL\n"));
     }
 
@@ -4282,6 +4282,8 @@ XmStringCreateFontList( XFontStruct *font, XmStringCharSet charset)
 }
 
 
+#if XmVERSION >= 2
+
 extern XmString
 XmStringConcatAndFree(XmString str1, XmString str2)
 {
@@ -4292,7 +4294,6 @@ XmStringConcatAndFree(XmString str1, XmString str2)
   return tmp;
 }
 
-#if XmVERSION >= 2
 
 /*
  * MxFTP uses this as
@@ -4352,7 +4353,7 @@ XmStringUnparse(XmString string, XmStringTag tag, XmTextType tag_type,
 #endif
 		if (comp->data) {
 			if (res) {
-				res = realloc(res, strlen(res) + 1 + strlen(comp->data));
+				res = (char *)realloc(res, strlen(res) + 1 + strlen(comp->data));
 				strcat(res, comp->data);
 			} else {
 				res = (char *)malloc(strlen(comp->data)+1);
