@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Xmos.c,v 1.40 2000/11/06 23:25:44 amai Exp $
+ * $Id: Xmos.c,v 1.43 2001/07/27 18:51:58 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Xmos.c,v 1.40 2000/11/06 23:25:44 amai Exp $";
+static const char rcsid[] = "$Id: Xmos.c,v 1.43 2001/07/27 18:51:58 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -57,8 +57,6 @@ static const char rcsid[] = "$Id: Xmos.c,v 1.40 2000/11/06 23:25:44 amai Exp $";
 #include <Xm/XmosP.h>
 #include <LTglob.h>
 
-#include <XmI/DebugUtil.h>
-
 #include "LTmisc.h"
 
 
@@ -67,9 +65,12 @@ static const char rcsid[] = "$Id: Xmos.c,v 1.40 2000/11/06 23:25:44 amai Exp $";
 #define  INCL_DOSMISC
 #define  INCL_ERRORS
 #include <os2.h>
-static const char *GetDriveMap(void); /* local prototype */
+static const char *GetDriveMap(void);
 #endif
 
+#include <XmI/DebugUtil.h>
+
+
 /*
  * this is OS dependent, but this should catch most OS's.
  */
@@ -597,13 +598,19 @@ _XmOSGetDirEntries(String qualifiedDir,
 		   unsigned int *pNumEntries,
 		   unsigned int *pNumAlloc)
 {
+/* OS/2 status, pre 20010511:
+    - no driver letters
+    - no ".." in / dir list 
+    (.. in file list in "/" !)
+    */
+ 
     glob_t result;
     char buf[2048];
     int i, cnt, max;
     String slash, tmp, *ret = NULL;
     int flags = GLOB_MARK | (matchDotsLiterally ? 0 : GLOB_PERIOD);
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		   "_XmOSGetDirEntries(%s,%s)\n", qualifiedDir, matchPattern));
 
     _XmOSGetDotDot(qualifiedDir);
@@ -646,7 +653,7 @@ _XmOSGetDirEntries(String qualifiedDir,
 	strcat(buf, matchPattern);
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmOSGetDirEntries -> work on '%s'\n", buf));
 
     memset((void *)&result, 0, sizeof(result));
@@ -772,15 +779,15 @@ _XmOSGetDirEntries(String qualifiedDir,
 	*pEntries = ret;
     }
 
-    if (XdbInDebug(__FILE__, NULL))
+    if (_LtDebugInDebug(__FILE__, NULL))
     {
 	int i;
 
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "_XmOSGetDirEntries: %d results\n", cnt));
 	for (i = 0; i < cnt; i++)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "\t[%d] - %s\n", i, ret[i]));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "\t[%d] - %s\n", i, ret[i]));
 	}
     }
 }
@@ -794,13 +801,16 @@ _XmOSBuildFileList(String dirPath,
 		   unsigned int *pNumEntries,
 		   unsigned int *pNumAlloc)
 {
+/* OS/2 status, pre 20010511:
+    - .. in file list in "/" !
+*/
     glob_t result;
     char buf[2048];
     int i, cnt, max;
     String *ret = NULL;
     int flags = GLOB_MARK | GLOB_PERIOD | GLOB_NOSORT;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmOSBuildFileList(%s,%s)\n", dirPath, pattern));
 
     *pEntries = NULL;
@@ -829,7 +839,7 @@ _XmOSBuildFileList(String dirPath,
     if (i)
 	return;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL,
+    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 	"WARNING: _XmOSBuildFileList: Resetting initial list\n"));
     *pNumAlloc = *pNumEntries = 0;
     *pEntries = NULL;
@@ -898,15 +908,15 @@ _XmOSBuildFileList(String dirPath,
 	*/
     }
 
-    if (XdbInDebug(__FILE__, NULL))
+    if (_LtDebugInDebug(__FILE__, NULL))
     {
 	int i;
 
-	DEBUGOUT(XdbDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "_XmOSBuildFileList: %d results\n", cnt));
 	for (i = 0; i < cnt; i++)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "\t[%d] - %s\n", i, ret[i]));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "\t[%d] - %s\n", i, ret[i]));
 	}
     }
 }
@@ -982,8 +992,8 @@ static const char
   ULONG  CurDrive;
   ULONG  DriveMap;
   int    dnum;
-  int    start = 3;  /* this should correspond to a hard coded limit
-                        to 'C', i.e. no check for floppy disk ?! */
+  int    start = 3;  /* this should correspond to a hard-coded limit
+                        to 'C', i.e. no check for floppy disks "A: B" ?! */
   static const char offset = 'A' -1;
   char *retstr;
 
