@@ -12,7 +12,9 @@
 #include <Xm/ScrolledW.h>
 #include <Xm/List.h>
 
-#include "DumpLayout.h"
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
 
 void Quit(Widget w, XtPointer client, XtPointer call)
 {
@@ -120,16 +122,16 @@ main(int argc, char **argv)
   XtRealizeWidget(toplevel);
   {
   static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,		0,	0,	450,	300,	0,0,0,	/* Form */
-  	CWWidth | CWHeight | CWX | CWY,	0,	0,	450,	31,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	5,	5,	28,	21,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	31,	450,	31,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	62,	150,	238,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	0,	150,	238,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	150,	62,	300,	238,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	223,	300,	15,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	0,	300,	219,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	0,	0,	0,	0,0,0,	/* two */
+  	{CWWidth | CWHeight,		0,	0,	450,	300,	0,0,0,	/* Form */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	0,	450,	31,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	5,	5,	28,	21,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	31,	450,	31,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	62,	150,	238,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	0,	150,	238,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	150,	62,	300,	238,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	223,	300,	15,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	0,	300,	219,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	0,	0,	0,	0,0,0,	/* two */},
 };
 
   PrintDetails(toplevel, Expected);
